BF3_KIT = {1: "Assault", 2: "Engineer", 8: "Recon", 32: "Support"}
BF4_KIT = {
    1: "Assault",
    2: "Engineer",
    32: "Support",
    8: "Recon",
    2048: "Commander",
}
BFH_KIT = {
    2048: "Commander",
    4096: "Enforcer",
    8192: "Mechanic",
    16384: "Operator",
    32768: "Professional",
}
GAMEMODE = {
    1: "CONQUEST",
    2: "RUSH",
    4: "SQRUSH",
    8: "SQDM",
    16: "ONSLAUGHT",
    32: "TEAMDEATHMATCH",
    64: "CONQUESTLARGE",
    128: "CONQUESTASSAULTLARGE",
    256: "CONQUESTASSAULTSMALL",
    512: "GUNMASTER",
    1024: "DOMINATION",
    2048: "TEAMDEATHMATCHC",
    4096: "TEAMDEATHMATCH_FIRETEAM",
    8192: "COMBATMISSION",
    16384: "SECTORCONTROL",
    32768: "FIRETEAM_SURVIVOR",
    65536: "SPORT",
    131072: "TANKSUPERIORITY",
    262144: "OBJECTIVERAID",
    524288: "CAPTURETHEFLAG",
    1048576: "BOMBSQUAD",
    2097152: "OBLITERATION",
    4194304: "SCAVENGER",
    8388608: "AIRSUPERIORITY",
    16777216: "ELIMINATION",
    33554432: "CARRIERASSAULT",
    67108864: "CARRIERASSAULTLARGE",
    134217728: "CARRIERASSAULTSMALL",
    34359738368: "CHAINLINK",
    268435456: "BLOODMONEY",
    2147483648: "HEIST",
    4294967296: "HOTWIRE",
    8589934592: "HIT",
    17179869184: "HOSTAGE",
    536870912: "TURFWARSMALL",
    1073741824: "TURFWARLARGE",
    68719476736: "CONQUESTLADDER",
    137438953472: "SQUADOBLITERATION",
    274877906944: "BOUNTYHUNTER",
    549755813888: "SQUADHEIST",
}
GAMES = ["bfh", "bf4", "bf3"]
GAME_NUMBERS = {
    "bfbc2": 1,
    "bf3": 2,
    "bf1942": 4,
    "bf1943": 8,
    "bfvietnam": 16,
    "bf2": 32,
    "bf2142": 64,
    "bfbc": 128,
    "bfheroes": 256,
    "bfmc": 512,
    "bfp4f": 1024,
    "bf4": 2048,
    "mohw": 4096,
    "bfh": 8192,
}
PLATFORM_NUMBERS = {
    "pc": 1,
    "xbox360": 2,
    "ps3": 4,
    "xbox": 8,
    "ps2": 16,
    "ps4": 32,
    "xboxone": 64,
    "cem_ea_id": 1,
}
REGIONS = {
    1: "NAm",
    2: "SAm",
    4: "AU",
    8: "Africa",
    16: "EU",
    32: "Asia",
    64: "OC",
}
SMALLMODE = {
    1: "CQ",
    2: "RS",
    4: "SQR",
    8: "SQM",
    16: "OS",
    32: "TDM",
    64: "CQL",
    128: "CAL",
    256: "CAS",
    512: "GM",
    1024: "DM",
    2048: "TDC",
    4096: "TDF",
    8192: "CM",
    16384: "SC",
    32768: "FTS",
    65536: "SPRT",
    131072: "TS",
    262144: "ORD",
    524288: "CTF",
    1048576: "BSQ",
    2097152: "OBL",
    4194304: "SCA",
    8388608: "AS",
    16777216: "EL",
    33554432: "CA",
    67108864: "CAL",
    134217728: "CAS",
    34359738368: "CL",
    268435456: "BM",
    2147483648: "HST",
    4294967296: "HW",
    8589934592: "HIT",
    17179869184: "HSTG",
    536870912: "TWS",
    1073741824: "TWL",
    68719476736: "QL",
    137438953472: "SOB",
}
STATS_TEMPLATES = {
    "overviewpopulatestats": "profile.bf3overviewstats",
    "weaponspopulatestats": "profile.bf3weaponsstats",
    "vehiclespopulatestats": "profile.bf3vehiclesstats",
    "warsawdetailedstatspopulate": "profile.warsawdetailedstatspopulate",
    "warsawoverviewpopulate": "profile.warsawoverviewpopulate",
    "warsawweaponspopulatestats": "profile.warsawweaponsstats",
    "warsawvehiclespopulatestats": "profile.warsawvehiclesstats",
    "bfhoverviewpopulate": "profile.bfhoverviewpopulate",
    "bfhweaponspopulatestats": "profile.bfhweaponsstats",
    "bfhvehiclespopulatestats": "profile.bfhvehiclesstats",
}
SLOTS = {
    16: "Full",
    1: "1-5",
    2: "6-10",
    4: "10+",
    8: "Empty",
}
TO_BATTLELOG_PLATFORMS = {
    "pc": "cem_ea_id",
    "psn": "ps3",
    "ps4": "ps3",
    "xboxone": "xbox",
    "xbox": "xbox",
}
