KITS = [
    "Anti-Tank",
    "Assault",
    "Engineer",
    "Medic",
    "Spec-Ops",
    "Support",
    "Sniper",
]
MAPS = [
    "Dalian Plant",
    "Daqing Oilfields",
    "Dragon Valley",
    "Fushe Pass",
    "Greatwall",
    "Gulf Of Oman",
    "Highway Tampa",
    "Kubra Dam",
    "Mashtuur City",
    "Midnight Sun",
    "Operation Blue Pearl",
    "Operation Clean Sweep",
    "Operation Harvest",
    "Operation Road Rage",
    "Operation Smoke Screen",
    "Road To Jalalabad",
    "Sharqi Peninsula",
    "Songhua Stalemate",
    "Strike At Karkand",
    "Taraba Quarry",
    "Wake Island 2007",
    "Zatar Wetlands",
]
MODE = {"gpm_cq": "Conquest", "gpm_coop": "Co-op"}
SMALLMODE = {"gpm_cq": "CQ", "gpm_coop": "COOP"}
VEHICLES = ["Armor", "Jet", "Helicopter", "Transport", "Anti-Air", "Ground-Def."]
WEAPONS = [
    "Assault-Rifle",
    "Grenade-Launcher",
    "Carbine",
    "Light Machine Gun",
    "Sniper Rifle",
    "Pistol",
    "Anti-Tank",
    "Sub-Machine Gun",
    "Shotgun",
    "Knife",
    "Defibrillator",
    "Explosives",
    "Grenade",
]