
KITS = {
    "assault": "Assault",
    "demo": "Engineer",
    "recon": "Recon",
    "support": "Medic",
}
MAPS = {
    "levels/bc1_harvest_day": "Harvest Day",
    "levels/bc1_oasis": "Oasis",
    "levels/mp_001": "Panama Canal",
    "levels/mp_002": "Valparaiso",
    "levels/mp_003": "Laguna Alta",
    "levels/mp_004": "Isla Inocentes",
    "levels/mp_005": "Atacama Desert",
    "levels/mp_006": "Arica Harbour",
    "levels/mp_007": "White Pass",
    "levels/mp_008": "Nelson Bay",
    "levels/mp_009": "Laguna Presa",
    "levels/mp_012": "Port Valdez",
    "levels/mp_sp_002": "Cold War",
    "levels/mp_sp_005": "Heavy Metal",
    "levels/nam_mp_002": "Vantage Point",
    "levels/nam_mp_003": "Hill 137",
    "levels/nam_mp_005": "Cai Son Temple",
    "levels/nam_mp_006": "Phu Bai Valley",
    "levels/nam_mp_007": "Operation Hastings",
}
MODES = {
    "conquest": "Conquest",
    "rush": "Rush",
    "sqdm": "Squad Deathmatch",
    "sqrush": "Squad Rush",
}
RANKS = [
    "Brigadier General I",
    "1st Lieutenant II",
    "Master Sergeant II",
    "Private II",
    "Chief Warrant Officer I",
    "Colonel III",
    "Warrant Officer III",
    "Sergeant I",
    "Sergeant III",
    "Staff Sergeant III",
    "Sergeant II",
    "First Sergeant I",
    "2nd Lieutenant III",
    "First Sergeant II",
    "Corporal III",
    "Specialist III",
    "Captain II",
    "2nd Lieutenant II",
    "General",
    "Specialist II",
    "Staff Sergeant II",
    "1st Lieutenant I",
    "Corporal I",
    "Master Sergeant III",
    "Captain I",
    "Chief Warrant Officer II",
    "Chief Warrant Officer III",
    "Recruit",
    "Major II",
    "Lieutenant Colonel I",
    "Corporal II",
    "Lieutenant Colonel II",
    "Colonel I",
    "Warrant Officer I",
    "Staff Sergeant I",
    "Private I",
    "Lieutenant Colonel III",
    "Colonel II",
    "Specialist I",
    "Brigadier General II",
    "Major III",
    "Warrant Officer II",
    "Private III",
    "Master Sergeant I",
    "Major I",
    "First Sergeant III",
    "1st Lieutenant III",
    "Brigadier General III",
    "2nd Lieutenant I",
    "Captain III",
    "General of the Army",
]
SMALLMODES = {"conquest": "CQ", "rush": "RS", "sqdm": "SQDM", "sqrush": "SQRS"}
VEHICLES = {
    "aav": {"name": "Anti-Air Gun", "class": "stationary"},
    "ah60": {"name": "UH-60 Transport", "class": "air"},
    "ah64": {"name": "AH-64 Apache", "class": "air"},
    "bmd3": {"name": "BMD-3 Bakhcha", "class": "heavy"},
    "bmda": {"name": "BMD-3 Bakhcha AA", "class": "heavy"},
    "cav": {"name": "Cav", "class": "light"},
    "cobr": {"name": "COBRA 4WD", "class": "light"},
    "havoc": {"name": "Mi-24 Hind", "class": "air"},
    "hmv": {"name": "HMMWV 4WD", "class": "light"},
    "jets": {"name": "Personal Water Craft", "class": "water"},
    "kord": {"name": "KORD HMG", "class": "stationary"},
    "korn": {"name": "KORNET AT", "class": "stationary"},
    "m1a2": {"name": "M1A2 Abrams", "class": "heavy"},
    "m3a3": {"name": "M3A3 Bradley", "class": "heavy"},
    "mi28": {"name": "MI-28 Havoc", "class": "air"},
    "pblb": {"name": "Patrol Boat", "class": "water"},
    "pbrv": {"name": "PBR Vietnam", "class": "water"},
    "qlz8": {"name": "QLZ8 GL", "class": "stationary"},
    "quad": {"name": "Quad Bike", "class": "light"},
    "t90": {"name": "T-90 MBT", "class": "heavy"},
    "tow2": {"name": "TOW2 AT", "class": "stationary"},
    "tru": {"name": "M939 Truck", "class": "light"},
    "uav": {"name": "UAV", "class": "air"},
    "vads": {"name": "VADS", "class": "stationary"},
    "vodn": {"name": "VODNIK 4WD", "class": "light"},
    "xm307": {"name": "XM307 GL", "class": "stationary"},
    "xm312": {"name": "XM312 HMG", "class": "stationary"},
}
WEAPONS = {
    "40mmgl": "40mm Grenade",
    "40mmsg": "40mm Shotgun",
    "9a91": "9A-91 Avtomat",
    "aek": "AEK-971 Vintovka",
    "ak47v": "AK 47 Vietnam",
    "aks74u": "AKS-74U Krinkov",
    "an94": "AN-94 Abakan",
    "atm": "Anti-Tank Mine",
    "aug": "Stg.77 AUG",
    "c4": "C4 Explosive",
    "defi": "Defibrillator",
    "f2000": "F2000 Assault",
    "g3": "G3",
    "gol": "GOL Sniper Magnum",
    "hgr": "Hand Grenade",
    "knv": "Combat Knife",
    "m1": "M1",
    "m136": "M136 AT4",
    "m14v": "M14 Vietnam",
    "m16": "M16A2",
    "m16a1v": "M16A1 Vietnam",
    "m16k": "M16A2 SPECACT",
    "m1911": "WWII M1911 .45",
    "m1a1": "WWII M1A1 Thompson",
    "m21v": "M21 Vietnam",
    "m24": "M24 Sniper",
    "m249": "M249 Saw",
    "m2cg": "M2 Carl Gustav AT",
    "m2v": "M2 Flamethrower Vietnam",
    "m40v": "M40 Vietnam",
    "m416": "M416",
    "m60": "M60 LMG",
    "m60v": "M60 Vietnam",
    "m9": "M9 Pistol",
    "m93r": "M93R Burst",
    "m95": "M95 Sniper",
    "m95k": "M95 Sniper SPECACT",
    "mac10v": "M10 Vietnam",
    "mcs": "870 MCS",
    "mg3": "MG3",
    "mg36": "MG36",
    "mg3k": "MG3 SPECACT",
    "mk14ebr": "M14 Mod 0 Enhanced",
    "mots": "Motion Sensor",
    "mp412": "MP-412 Rex",
    "mp443": "MP-443 Grach",
    "mst": "Mortar Strike",
    "n2k": "NEOSTEAD 2000 Combat",
    "pkm": "PKM LMG",
    "pp2": "PP-2000 Avtomat",
    "ppshv": "PPSh Vietnam",
    "qbu88": "Type 88 Sniper",
    "qju88": "Type 88 LMG",
    "rept": "Repair Tool",
    "rpg7": "RPG-7 AT",
    "rpkv": "RPK Vietnam",
    "s12k": "Saiga 20k Semi",
    "scar": "SCAR-L Carbine",
    "smol": "40mm Smoke Launcher",
    "spas12": "SPAS-12 Combat",
    "sv98": "SV98 Snaiperskaya",
    "svdv": "SVD Sniper Vietnam",
    "svu": "SVU Snaiperskaya Short",
    "trad": "Tracer Dart Gun",
    "tt33v": "TT33 Vietnam",
    "u12": "USAS-12 Auto",
    "ump": "UMP-45",
    "umpk": "UMP-45 SPECACT",
    "uzi": "UZI",
    "uziv": "UZI Vietnam",
    "vss": "VSS Snaiperskaya Special",
    "xm22v": "XM22 Vietnam",
    "xm8": "XM8 Prototype",
    "xm8c": "XM8 Compact",
    "xm8lmg": "XM8 LMG",
}