MODES = {
    "CONQ": "Conquest",
    "FRONTLINE": "Frontlines",
    "RUSH": "Rush",
    "DOMI": "Domination",
    "TDM": "Teamdeathmatch",
    "GunGameFFA": "Gungame free-for-all",
    "INFCONQ": "Infantry Conquest",
    "FFA": "Free-for-all",
    "GunGameTeam": "Gungame team",
    "ELI": "Elimination",
}
SMALLMODES = {
    "CONQ": "CQ",
    "FRONTLINE": "FL",
    "RUSH": "RS",
    "DOMI": "DM",
    "TDM": "TDM",
    "INFCONQ": "IQ",
    "GunGameFFA": "GGF",
    "FFA": "FFA",
    "GunGameTeam": "GGT",
    "ELI": "ELI",
}
REGIONS = {
    "Europe_Central": "Europe",
    "America_Central": "America",
    "Japan_Central": "Japan",
    "Australia_Central": "Australia",
    "Brazil_Central": "Brazil",
}
