MAP_LIST = [
    "Belgrade",
    "Bridge_at_Remagen",
    "Camp_Gibraltar",
    "Cebere_Landing",
    "Fall_of_Berlin",
    "Highway_Tampa",
    "Liberation_of_Leipzig",
    "Minsk",
    "Molokai",
    "Northern_Mountai_Pass",
    "Operation_Blue_Pearl",
    "Operation_Shingle",
    "Port_Bavaria",
    "Shihua_Taiba",
    "Sidi_Power_Plant",
    "Strike_at_Karkand",
    "Suez_Canal",
    "Tunis_Harbor",
    "Verdun",
    "Wake_Island",
    "Yellow_Knife",
]
MODE = {
    "gpm_cq": "Conquest",
    "gpm_coop": "Conquest Co-op",
    "gpm_sl": "Assault Lines",
    "gpm_ti": "Titan",
    "gpm_ca": "Conquest Assault",
    "gpm_nv": "No Vehicles",
}
SMALLMODE = {
    "gpm_cq": "CQ",
    "gpm_coop": "COOP",
    "gpm_sl": "AL",
    "gpm_ti": "Ti",
    "gpm_ca": "CA",
    "gpm_nv": "NV",
}