MAPS = {
    "mp_bank": "Bank job",
    "mp_bloodout": "The block",
    "mp_desert": "Dust bowl",
    "mp_downtown": "Downtown",
    "mp_eastside": "Derailed",
    "mp_everglades": "Everglades",
    "mp_growhouse": "Growhouse",
    "mp_hills": "Hollywood heights",
    "mp_offshore": "Riptide",
    "omaha_sp_assault": "Ep. 10: legacy",
    "omaha_sp_chopshop": "Ep. 6: out of business",
    "omaha_sp_copfantasy": "Ep. 1: back to school",
    "omaha_sp_dealgonebad": "Ep. 2: checking out",
    "omaha_sp_desert": "Ep. 8: sovereign land",
    "omaha_sp_escape": "Ep. 5: gauntlet",
    "omaha_sp_everglades": "Ep. 3: gator bait",
    "omaha_sp_heist": "Ep. 9: independence day",
    "omaha_sp_hollywoodhills": "Ep. 7: glass houses",
    "omaha_sp_prologue": "Prologue",
    "omaha_sp_theturn": "Ep. 4: case closed",
    "xp1_mallcops": "Black friday",
    "xp1_nights": "Code blue",
    "xp1_projects": "The beat",
    "xp1_sawmill": "Backwoods",
    "xp25_bank": "Night job",
    "xp25_sawmill": "Night woods",
    "xp2_cargoship": "The docks",
    "xp2_coastal": "Break pointe",
    "xp2_nh_museum": "Museum",
    "xp2_precinct7": "Precinct 7",
    "xp3_border": "Double cross",
    "xp3_cistern": "Diversion",
    "xp3_highway": "Pacific highway",
    "xp3_traindodge": "Train dodge",
    "xp4_alcatraz": "Alcatraz",
    "xp4_cemetery": "Cemetery",
    "xp4_chinatown": "Chinatown",
    "xp4_snowcrash": "Thin ice",
}
MAP_IMAGES = {
    "xp4_cemetery": "https://cdn.gametools.network/maps/bfh/xp4_cemetery-1fc8ff60.png",
    "xp2_cargoship": "https://cdn.gametools.network/maps/bfh/xp2_cargoship-14f35dd7.png",
    "xp25_bank": "https://cdn.gametools.network/maps/bfh/xp25_bank-426c90a6.png",
    "xp1_projects": "https://cdn.gametools.network/maps/bfh/xp1_projects-106b1fa8.png",
    "mp_growhouse": "https://cdn.gametools.network/maps/bfh/mp_growhouse-155870ed.png",
    "xp2_coastal": "https://cdn.gametools.network/maps/bfh/xp2_coastal-cd4ad811.png",
    "mp_offshore": "https://cdn.gametools.network/maps/bfh/mp_offshore-0c4f283b.png",
    "xp25_sawmill": "https://cdn.gametools.network/maps/bfh/xp25_sawmill-82e681f4.png",
    "mp_hills": "https://cdn.gametools.network/maps/bfh/mp_hills-bd854e5f.png",
    "xp3_cistern02": "https://cdn.gametools.network/maps/bfh/xp3_cistern02-89ec81ee.png",
    "mp_bank": "https://cdn.gametools.network/maps/bfh/mp_bank-68ebec2e.png",
    "xp4_snowcrash": "https://cdn.gametools.network/maps/bfh/xp4_snowcrash-3217d5a2.png",
    "xp2_precinct7": "https://cdn.gametools.network/maps/bfh/xp2_precinct7-a8a3e9dc.png",
    "mp_eastside": "https://cdn.gametools.network/maps/bfh/mp_eastside-4f6ff4cb.png",
    "mp_desert05": "https://cdn.gametools.network/maps/bfh/mp_desert05-53ca95fe.png",
    "xp3_highway": "https://cdn.gametools.network/maps/bfh/xp3_highway-461437fb.png",
    "xp1_nights": "https://cdn.gametools.network/maps/bfh/xp1_nights-080a9921.png",
    "mp_glades": "https://cdn.gametools.network/maps/bfh/mp_glades-223b2377.png",
    "xp2_museum02": "https://cdn.gametools.network/maps/bfh/xp2_museum02-6084c272.png",
    "xp4_chinatown": "https://cdn.gametools.network/maps/bfh/xp4_chinatown-45f8cbac.png",
    "xp1_sawmill": "https://cdn.gametools.network/maps/bfh/xp1_sawmill-bfddbf43.png",
    "xp3_traindodge": "https://cdn.gametools.network/maps/bfh/xp3_traindodge-f361cac0.png",
    "mp_downtown": "https://cdn.gametools.network/maps/bfh/mp_downtown-c69bbe19.png",
    "xp3_border": "https://cdn.gametools.network/maps/bfh/xp3_border-68d4906e.png",
    "xp4_alcatraz": "https://cdn.gametools.network/maps/bfh/xp4_alcatraz-1d50f297.png",
    "xp1_mallcops": "https://cdn.gametools.network/maps/bfh/xp1_mallcops-cfeffff8.png",
    "mp_bloodout": "https://cdn.gametools.network/maps/bfh/mp_bloodout-85a5a078.png",
}
WEAPONS = [
    "ro933",
    "mp7",
    "m67-frag",
    "baseball-bat",
    "gold-baton",
    "fn57",
    "scorpion",
    "bowie",
    "arm",
    "gold-hammer",
    "gold-lead-pipe",
    "388-recon",
    "cleaver",
    "golf-club",
    "rpk",
    "m39-emr",
    "gold-scout",
    "decoy",
    "93r",
    "seal",
    "300-knockout",
    "tracking-dart",
    "uzi",
    "trench",
    "karambit",
    "38-snub",
    "410-jury",
    "ro933-300-blk",
    "saiga-12",
    "camera",
    "fmg9",
    "acb-90",
    "hk51",
    "scout-elite",
    "gold-survival",
    "m1a1",
    "44-magnum",
    "nightstick",
    "carbon-fiber",
    "gold-crowbar",
    "throwing-knife",
    "sledge-hammer",
    "870p-magnum",
    "gold-golf-club",
    "ballistic-shield",
    "scar-h",
    "ksg12",
    "p226",
    "shovel",
    "bald-eagle",
    "m5-navy",
    "gold-knife",
    "gold-sledge-hammer",
    "g17-race-pistol",
    "m12s",
    "m320-he",
    "scout",
    "mpx",
    "m79",
    "laser-tripmine",
    "m1903",
    "defibrillator",
    "mammoth-gun",
    "crowbar",
    "mdc",
    "spas-12",
    "improvised-gun",
    "awm",
    "akm",
    "sr-25-ecc",
    "p90",
    "aug-para",
    "ump-9",
    "blackjack",
    "1887",
    "sg553",
    "m320-cs-gas",
    "sp-ar",
    "survival",
    "l85a2",
    "knife",
    "fal",
    "m79-cs-gas",
    "45t",
    "inquisition-sword-red",
    "shank",
    "inquisition-sword-gold",
    "grappling-hook",
    "40-pro",
    "sar-21",
    "m16a3",
    "gas-grenade",
    "hcar",
    "mp9",
    "police-baton",
    "cz-75",
    "357-rs",
    "g17",
    "double-barrel-shotgun",
    "gold-boot",
    "m-45",
    "mx4",
    "lead-pipe",
    "m110k5",
    "sa-58-osw",
    "m5sd",
    "37-stakeout",
    "fire-axe",
    "gold-seal",
    "gold-trench",
    "ro933-m1",
    "ptr-91",
    "m82-416",
    "acwr",
    "92fs",
    "famas",
    "t62-cew",
    "revive",
    "m416",
    "gold-shovel",
    "machete",
    "collapsible-baton",
    "breaching-hammer",
    "m1",
    "k10",
    "ump-45",
    "m98b",
    "aug-a3",
    "molotov",
    "m4",
    "f2000",
    "dual-vz-61",
    "sg510",
    "devil-s-toothpick",
    "mac-10",
    "syndicate-gun",
    "r700-ltr",
    "car-556",
    "breaching-charge",
    "aks-74u",
    "tec-9",
    "sabotage",
    "g36c",
    "gold-machete",
    "boot",
    "aws",
    "a-8s",
    "zipline",
    "rpk-74",
    "repair-tool",
    "incendiary-device",
    "inquisition-sword",
    "socom16",
    "g18c",
    "throwing-knife-gold",
    "gold-fire-axe",
    "saiga-308",
    "mp5k",
    "m1911a1",
]
