WEAPONS = {
    "wtypemg42": {
        "type": "Mmg",
        "weaponName": "MG 42",
        "image": "https://cdn.gametools.network/weapons/bfv/MG42-1ca6b52d.png",
    },
    "wtypemg34": {
        "type": "Mmg",
        "weaponName": "MG 34",
        "image": "https://cdn.gametools.network/weapons/bfv/MG34-f447ad5e.png",
    },
    "wtypedarne": {
        "type": "Mmg",
        "weaponName": "M1922 MG",
        "image": "https://cdn.gametools.network/weapons/bfv/Darne-f35be432.png",
    },
    "wtypeg43": {
        "type": "Semi-auto rifle",
        "weaponName": "Gewehr 43",
        "image": "https://cdn.gametools.network/weapons/bfv/Gewehr43-cb742d1a.png",
    },
    "wtypem1car": {
        "type": "Semi-auto rifle",
        "weaponName": "M1A1 Carbine",
        "image": "https://cdn.gametools.network/weapons/bfv/M1A1Carbine-0e72e354.png",
    },
    "wtypetsmlesar": {
        "type": "Semi-auto rifle",
        "weaponName": "Turner SMLE",
        "image": "https://cdn.gametools.network/weapons/bfv/TurnerSMLE-75621421.png",
    },
    "wtypems1916": {
        "type": "Semi-auto rifle",
        "weaponName": "Selbstlader 1916",
        "image": "https://cdn.gametools.network/weapons/bfv/Selbstlader1916-f5dcd71a.png",
    },
    "wtypegusvolsar": {
        "type": "Semi-auto rifle",
        "weaponName": "Gewehr 1-5",
        "image": "https://cdn.gametools.network/weapons/bfv/Gewehr15-688f09a9.png",
    },
    "wtypeam42": {
        "type": "Semi-auto rifle",
        "weaponName": "Ag m/42",
        "image": "https://cdn.gametools.network/weapons/bfv/M42-7befb739.png",
    },
    "wtypemasm1944": {
        "type": "Semi-auto rifle",
        "weaponName": "MAS 44",
        "image": "https://cdn.gametools.network/weapons/bfv/Mas44-70764a58.png",
    },
    "wtypewz38": {
        "type": "Semi-auto rifle",
        "weaponName": "Karabin 1938M",
        "image": "https://cdn.gametools.network/weapons/bfv/Wz38M-01b8c70d.png",
    },
    "wtypem1gar": {
        "type": "Semi-auto rifle",
        "weaponName": "M1 Garand",
        "image": "https://cdn.gametools.network/weapons/bfv/M1Garand-3e2b5802.png",
    },
    "wtypem3infraredsniper": {
        "type": "Semi-auto rifle",
        "weaponName": "M3 Infrared",
        "image": "https://cdn.gametools.network/weapons/bfv/M3_Infrared_SniperCarbine-a3fa218b.png",
    },
    "wtypem1941johnsonrifle": {
        "type": "Semi-auto rifle",
        "weaponName": "M1941 Johnson",
        "image": "https://cdn.gametools.network/weapons/bfv/M1941_JohnsonRifle-374730d3.png",
    },
    "wtypemscoutm1916": {
        "type": "Melee",
        "weaponName": "Scout Knife M1916",
        "image": "https://cdn.gametools.network/weapons/bfv/ScoutKnifeM1916-6c8b69f9.png",
    },
    "wtypemkukri": {
        "type": "Melee",
        "weaponName": "Kukri",
        "image": "https://cdn.gametools.network/weapons/bfv/Kukri-63cd4e8e.png",
    },
    "wtypembrarmyknife": {
        "type": "Melee",
        "weaponName": "British Army Jack Knife",
        "image": "https://cdn.gametools.network/weapons/bfv/BritishArmyJackKnife-c6623eae.png",
    },
    "wtypembolousmc": {
        "type": "Melee",
        "weaponName": "Bolo-Guna",
        "image": "https://cdn.gametools.network/weapons/bfv/BoloKnife-5420b66c.png",
    },
    "wtypemislepickaxe": {
        "type": "Melee",
        "weaponName": "Ilse's Pickaxe",
        "image": "https://cdn.gametools.network/weapons/bfv/Pickaxe-17bf1b74.png",
    },
    "wtypeboysat": {
        "type": "Anti-materiel rifle",
        "weaponName": "Boys AT Rifle",
        "image": "https://cdn.gametools.network/weapons/bfv/BoysAT-d8f83999.png",
    },
    "wtypepanzerbuchseat": {
        "type": "Anti-materiel rifle",
        "weaponName": "Panzerbüchse 39",
        "image": "https://cdn.gametools.network/weapons/bfv/Panzerbuchse_39-aab3bc76.png",
    },
    "gctlgrenrifle": {
        "type": "Gadget",
        "weaponName": "Frag Grenade Rifle",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_SMLE_Grenade-1be05d77.png",
    },
    "gctlrpf": {
        "type": "Gadget",
        "weaponName": "Panzerfaust",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_AntiTank_Rocket_Frag_01-05de7537.png",
    },
    "gctdac": {
        "type": "Gadget",
        "weaponName": "Ammo Crate",
        "image": "https://cdn.gametools.network/weapons/bfv/Supply_Ammo_Crate-40503eb3.png",
    },
    "gcttbin": {
        "type": "Gadget",
        "weaponName": "Spotting Scope",
        "image": "https://cdn.gametools.network/weapons/bfv/Intel_Scope-a931f9f1.png",
    },
    "gctlfla": {
        "type": "Gadget",
        "weaponName": "Flare Gun",
        "image": "https://cdn.gametools.network/weapons/bfv/Intel_FlareGun-d99b0424.png",
    },
    "gctdsb": {
        "type": "Gadget",
        "weaponName": "Spawn Beacon",
        "image": "https://cdn.gametools.network/weapons/bfv/Deployable_SpawnBeacon_Single-f2c0bc51.png",
    },
    "gctthrwgsmo": {
        "type": "Gadget",
        "weaponName": "Smoke Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_AntiPersonal_Smoke-150b5665.png",
    },
    "gctthrwgfrag": {
        "type": "Gadget",
        "weaponName": "Frag Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_AntiPersonal_Frag_Fuse_UK-51667306.png",
    },
    "gctthrwgfi": {
        "type": "Gadget",
        "weaponName": "Incendiary Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_AntiPersonal_Fire-3bbc4243.png",
    },
    "gctlrpiat": {
        "type": "Gadget",
        "weaponName": "PIAT",
        "image": "https://cdn.gametools.network/weapons/bfv/Launchers_AntiTank_Rocket_Frag_03-b86e6998.png",
    },
    "gctlgrenpistol": {
        "type": "Gadget",
        "weaponName": "AT Grenade Pistol",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_AntiTank_Pistol_Frag-7938b179.png",
    },
    "gctlgrensmoke": {
        "type": "Gadget",
        "weaponName": "Smoke Grenade Rifle",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_SMLE_Grenade-1be05d77.png",
    },
    "gctthrwgimp": {
        "type": "Gadget",
        "weaponName": "Impact Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_AntiPersonal_Frag_Impact_UK-4f81ac0f.png",
    },
    "gctlrf": {
        "type": "Gadget",
        "weaponName": "Fliegerfaust",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_AntiAir_Rocket_Frag-b252fba3.png",
    },
    "gctlrbaz": {
        "type": "Gadget",
        "weaponName": "M1A1 Bazooka",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_AntiTank_Rocket_Frag_04-883dd48a.png",
    },
    "gctlgrenpistolcmp": {
        "type": "Gadget",
        "weaponName": "Kampfpistole",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_AntiTank_Pistol_CMP-3f090ca4.png",
    },
    "wtypelewis": {
        "type": "Lmg",
        "weaponName": "Lewis Gun",
        "image": "https://cdn.gametools.network/weapons/bfv/LewisLMG-e0d04932.png",
    },
    "wtypesigke7": {
        "type": "Lmg",
        "weaponName": "KE7",
        "image": "https://cdn.gametools.network/weapons/bfv/SIGKE7-8aa6fea9.png",
    },
    "wtypebren": {
        "type": "Lmg",
        "weaponName": "Bren Gun",
        "image": "https://cdn.gametools.network/weapons/bfv/BRENGun-4c2753f2.png",
    },
    "wtypefg42": {
        "type": "Lmg",
        "weaponName": "FG-42",
        "image": "https://cdn.gametools.network/weapons/bfv/FG42-c6c82ba2.png",
    },
    "wtypels26": {
        "type": "Lmg",
        "weaponName": "LS/26",
        "image": "https://cdn.gametools.network/weapons/bfv/LS26-c1883823.png",
    },
    "wtypemadsenmg": {
        "type": "Lmg",
        "weaponName": "Madsen MG",
        "image": "https://cdn.gametools.network/weapons/bfv/MiniMadsen-b8e2e5c4.png",
    },
    "wtypechau": {
        "type": "Lmg",
        "weaponName": "Chauchat",
        "image": "https://cdn.gametools.network/weapons/bfv/Chauchat-10361a12.png",
    },
    "wtypeBAR1918A2": {
        "type": "Lmg",
        "weaponName": "BAR M1918A2",
        "image": "https://cdn.gametools.network/weapons/bfv/Bar1918_A2-b44ff667.png",
    },
    "wtypetype97MG": {
        "type": "Lmg",
        "weaponName": "Type 97 MG",
        "image": "https://cdn.gametools.network/weapons/bfv/Type97MG-01b69c34.png",
    },
    "wtypetype11lmg": {
        "type": "Lmg",
        "weaponName": "Type 11 LMG",
        "image": "https://cdn.gametools.network/weapons/bfv/Nambu_Type11-166b8aa9.png",
    },
    "wtypebauto5": {
        "type": "Shotgun",
        "weaponName": "12g Automatic",
        "image": "https://cdn.gametools.network/weapons/bfv/12gAutomatic-4344bfef.png",
    },
    "wtypew1897sho": {
        "type": "Shotgun",
        "weaponName": "M1897",
        "image": "https://cdn.gametools.network/weapons/bfv/M1897Shotgun-381578b2.png",
    },
    "wtypeith37sho": {
        "type": "Shotgun",
        "weaponName": "Model 37",
        "image": "https://cdn.gametools.network/weapons/bfv/Model37-e2aff9bb.png",
    },
    "wtypesisho": {
        "type": "Shotgun",
        "weaponName": "Sjögren Shotgun",
        "image": "https://cdn.gametools.network/weapons/bfv/SjogrenShotgun-43cfe31f.png",
    },
    "wtypec96rifle": {
        "type": "Pistol carbine",
        "weaponName": "Trench Carbine",
        "image": "https://cdn.gametools.network/weapons/bfv/C96_Carbine-af56338e.png",
    },
    "wtypep08rifle": {
        "type": "Pistol carbine",
        "weaponName": "P08 Carbine",
        "image": "https://cdn.gametools.network/weapons/bfv/P08Carbine-5c6a750b.png",
    },
    "wtypefp45l": {
        "type": "Sidearm",
        "weaponName": "Liberator",
        "image": "https://cdn.gametools.network/weapons/bfv/FP45Liberator-0e952d0b.png",
    },
    "wtypewmkiv": {
        "type": "Sidearm",
        "weaponName": "Mk VI Revolver",
        "image": "https://cdn.gametools.network/weapons/bfv/MKVIRevolver-982f4b4b.png",
    },
    "wtypm1911": {
        "type": "Sidearm",
        "weaponName": "M1911",
        "image": "https://cdn.gametools.network/weapons/bfv/M1911-0fd23c61.png",
    },
    "wtypewp38": {
        "type": "Sidearm",
        "weaponName": "P38 Pistol",
        "image": "https://cdn.gametools.network/weapons/bfv/WaltherP38-3813c59d.png",
    },
    "wtyperuby": {
        "type": "Sidearm",
        "weaponName": "Ruby",
        "image": "https://cdn.gametools.network/weapons/bfv/RubyPistol-02727dd8.png",
    },
    "wtypep08": {
        "type": "Sidearm",
        "weaponName": "P08 Pistol",
        "image": "https://cdn.gametools.network/weapons/bfv/LugerP8-ec3e2eca.png",
    },
    "wtypemodel27": {
        "type": "Sidearm",
        "weaponName": "Model 27",
        "image": "https://cdn.gametools.network/weapons/bfv/Model27_Long-4a3efef6.png",
    },
    "wtypm1911s": {
        "type": "Sidearm",
        "weaponName": "M1911 Suppressed",
        "image": "https://cdn.gametools.network/weapons/bfv/M1911_suppressed-ea0651d2.png",
    },
    "wtypestg44": {
        "type": "Assault rifle",
        "weaponName": "StG 44",
        "image": "https://cdn.gametools.network/weapons/bfv/STG44MP44-97548575.png",
    },
    "wtypegusvolar": {
        "type": "Assault rifle",
        "weaponName": "Sturmgewehr 1-5",
        "image": "https://cdn.gametools.network/weapons/bfv/SturmGewehr15-a4740184.png",
    },
    "wtypew1907ar": {
        "type": "Assault rifle",
        "weaponName": "M1907 SF",
        "image": "https://cdn.gametools.network/weapons/bfv/M1907SF-f6ac6f26.png",
    },
    "wtyperib1918": {
        "type": "Assault rifle",
        "weaponName": "Ribeyrolles 1918",
        "image": "https://cdn.gametools.network/weapons/bfv/Ribeyrolles-eed41ed9.png",
    },
    "wtypebredapg": {
        "type": "Assault rifle",
        "weaponName": "Breda M1935 PG",
        "image": "https://cdn.gametools.network/weapons/bfv/BredaPG-a080089a.png",
    },
    "wtypem2car": {
        "type": "Assault rifle",
        "weaponName": "M2 Carbine",
        "image": "https://cdn.gametools.network/weapons/bfv/M2Carbine-d6d6efcb.png",
    },
    "wtypedelislerifle": {
        "type": "Bolt action carbine",
        "weaponName": "Commando Carbine",
        "image": "https://cdn.gametools.network/weapons/bfv/DeLisleCarabine-18a64a00.png",
    },
    "wtypesmle5": {
        "type": "Bolt action carbine",
        "weaponName": "Jungle Carbine",
        "image": "https://cdn.gametools.network/weapons/bfv/LeeEinfeldNo5-309d1cbe.png",
    },
    "wtypetm1928a1": {
        "type": "Smg",
        "weaponName": "M1928A1",
        "image": "https://cdn.gametools.network/weapons/bfv/Thompson-c31f1ac0.png",
    },
    "wtypemp28": {
        "type": "Smg",
        "weaponName": "MP28",
        "image": "https://cdn.gametools.network/weapons/bfv/MP28-f09c5670.png",
    },
    "wtypesten": {
        "type": "Smg",
        "weaponName": "STEN",
        "image": "https://cdn.gametools.network/weapons/bfv/STENGun-9138fc17.png",
    },
    "wtypeskp31": {
        "type": "Smg",
        "weaponName": "Suomi KP/-31",
        "image": "https://cdn.gametools.network/weapons/bfv/Suomi-2bf82a33.png",
    },
    "wtypmp40": {
        "type": "Smg",
        "weaponName": "MP40",
        "image": "https://cdn.gametools.network/weapons/bfv/MP40-0164787e.png",
    },
    "wtypezk383": {
        "type": "Smg",
        "weaponName": "ZK-383",
        "image": "https://cdn.gametools.network/weapons/bfv/ZK383-374279ef.png",
    },
    "wtypbermod38": {
        "type": "Smg",
        "weaponName": "MAB 38",
        "image": "https://cdn.gametools.network/weapons/bfv/MAB38-e1595a2e.png",
    },
    "wtypet100": {
        "type": "Smg",
        "weaponName": "Type 100",
        "image": "https://cdn.gametools.network/weapons/bfv/Type100_SMG-8b174d3a.png",
    },
    "wtypeM3SMG": {
        "type": "Smg",
        "weaponName": "M3 Grease Gun",
        "image": "https://cdn.gametools.network/weapons/bfv/M3SMG-6cb56d9d.png",
    },
    "wtypenambut2a": {
        "type": "Smg",
        "weaponName": "Type 2A",
        "image": "https://cdn.gametools.network/weapons/bfv/Nambu_Type2A-3b5090e2.png",
    },
    "wtypebwelgun": {
        "type": "Smg",
        "weaponName": "Welgun",
        "image": "https://cdn.gametools.network/weapons/bfv/Welgun-aeb91d41.png",
    },
    "wtypekrag": {
        "type": "Bolt action rifle",
        "weaponName": "Krag–Jørgensen",
        "image": "https://cdn.gametools.network/weapons/bfv/KragJorgensen-30895eb5.png",
    },
    "wtypegewm9530": {
        "type": "Bolt action rifle",
        "weaponName": "Gewehr M95/30",
        "image": "https://cdn.gametools.network/weapons/bfv/Gewehr9530-e1ce76f9.png",
    },
    "wtypesmle4": {
        "type": "Bolt action rifle",
        "weaponName": "Lee-Enfield No.4 Mk I",
        "image": "https://cdn.gametools.network/weapons/bfv/LeeEnfield-85ff8090.png",
    },
    "wtypekar98k": {
        "type": "Bolt action rifle",
        "weaponName": "Kar98k",
        "image": "https://cdn.gametools.network/weapons/bfv/Kar98K-01d381cd.png",
    },
    "wtyperosssrmk3": {
        "type": "Bolt action rifle",
        "weaponName": "Ross Rifle Mk III",
        "image": "https://cdn.gametools.network/weapons/bfv/RossRifle-c930c7e9.png",
    },
    "wtypet99arisaka": {
        "type": "Bolt action rifle",
        "weaponName": "Type 99 Arisaka",
        "image": "https://cdn.gametools.network/weapons/bfv/Type_99_Arisaka-cb8bc4ed.png",
    },
    "wtypek31": {
        "type": "Bolt action rifle",
        "weaponName": "K31/43",
        "image": "https://cdn.gametools.network/weapons/bfv/K3143-910cfbf7.png",
    },
    "wtypersc1918": {
        "type": "Self-loading rifle",
        "weaponName": "RSC",
        "image": "https://cdn.gametools.network/weapons/bfv/RSC-1f58be6c.png",
    },
    "wtypelugersar": {
        "type": "Self-loading rifle",
        "weaponName": "Selbstlader 1906",
        "image": "https://cdn.gametools.network/weapons/bfv/Selbstlader1906-b7f1cea4.png",
    },
    "wtyperemm8slr": {
        "type": "Self-loading rifle",
        "weaponName": "Model 8",
        "image": "https://cdn.gametools.network/weapons/bfv/RemingtonM8-10a6aa82.png",
    },
    "wtypezh29slr": {
        "type": "Self-loading rifle",
        "weaponName": "ZH-29",
        "image": "https://cdn.gametools.network/weapons/bfv/ZH29-62e6adf5.png",
    },
    "wtypes2200": {
        "type": "Mmg",
        "weaponName": "S2-200",
        "image": "https://cdn.gametools.network/weapons/bfv/S2200-d68665c9.png",
    },
    "wtypem1919a6": {
        "type": "Mmg",
        "weaponName": "M1919A6",
        "image": "https://cdn.gametools.network/weapons/bfv/M1919A6-b22db6be.png",
    },
    "wtypemhatchet": {
        "type": "Melee",
        "weaponName": "Hatchet",
        "image": "https://cdn.gametools.network/weapons/bfv/Hatchet-8da526ed.png",
    },
    "wtypemclub": {
        "type": "Melee",
        "weaponName": "Club",
        "image": "https://cdn.gametools.network/weapons/bfv/MeleeClub-41ce6631.png",
    },
    "wtypemshovel": {
        "type": "Melee",
        "weaponName": "Shovel",
        "image": "https://cdn.gametools.network/weapons/bfv/Shovel-767d811e.png",
    },
    "wtypempickaxe": {
        "type": "Melee",
        "weaponName": "Pickaxe",
        "image": "https://cdn.gametools.network/weapons/bfv/Pickaxe-17bf1b74.png",
    },
    "wtypemcricket": {
        "type": "Melee",
        "weaponName": "Cricket Bat",
        "image": "https://cdn.gametools.network/weapons/bfv/CricketBat-b1907335.png",
    },
    "wtypemfsjeager": {
        "type": "Melee",
        "weaponName": "Fallschirmjäger Switchblade",
        "image": "https://cdn.gametools.network/weapons/bfv/Switchblade-f03546ee.png",
    },
    "wtypemsai": {
        "type": "Melee",
        "weaponName": "Sai",
        "image": "https://cdn.gametools.network/weapons/bfv/IronSai-a7911f90.png",
    },
    "wtypemkatana": {
        "type": "Gadget",
        "weaponName": "Katana",
        "image": "https://cdn.gametools.network/weapons/bfv/Katana-273e8e24.png",
    },
    "wtypem30luftd": {
        "type": "Shotgun",
        "weaponName": "M30 Drilling",
        "image": "https://cdn.gametools.network/weapons/bfv/M30LuftwaffeDrilling-93d25c9c.png",
    },
    "wtypetromboncino": {
        "type": "Bolt action carbine",
        "weaponName": "M28 con Tromboncino",
        "image": "https://cdn.gametools.network/weapons/bfv/Tromboncino_M28-e19b76f7.png",
    },
    "wtypemp34s1": {
        "type": "Smg",
        "weaponName": "MP34",
        "image": "https://cdn.gametools.network/weapons/bfv/MP34-82e44afe.png",
    },
    "wtypeemp": {
        "type": "Smg",
        "weaponName": "EMP",
        "image": "https://cdn.gametools.network/weapons/bfv/EMP-5f3287c2.png",
    },
    "gctthrwgat": {
        "type": "Gadget",
        "weaponName": "Anti-Tank Bundle Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_AntiTank_Frag_Impact-8e011bdd.png",
    },
    "wtypemgdagger": {
        "type": "Melee",
        "weaponName": "German Naval Dagger",
        "image": "https://cdn.gametools.network/weapons/bfv/GermanNavalDagger-cdc209da.png",
    },
    "gctdfac": {
        "type": "Gadget",
        "weaponName": "Medical Crate",
        "image": "https://cdn.gametools.network/weapons/bfv/Supply_Medical_Crate-b3f2f42a.png",
    },
    "gctldoubleflare": {
        "type": "Gadget",
        "weaponName": "Doppel-Schuss",
        "image": "https://cdn.gametools.network/weapons/bfv/Intel_DoubleBarrelFlareGun-d783a371.png",
    },
    "gctthrwm80cmp": {
        "type": "Gadget",
        "weaponName": "Firecrackers",
        "image": "https://cdn.gametools.network/weapons/bfv/Throwable_M80-b0e5f292.png",
    },
    "gctlgrenrmncmp": {
        "type": "Gadget",
        "weaponName": "RMN50 Rifle Frag",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_RMN_Grenade-9cd222df.png",
    },
    "gctlflmpistol": {
        "type": "Gadget",
        "weaponName": "Pistol Flamethrower",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_AntiPersonal_Pistol_Fire-859644ba.png",
    },
    "wtypesm1912": {
        "type": "Sidearm",
        "weaponName": "Repetierpistole M1912",
        "image": "https://cdn.gametools.network/weapons/bfv/SteyrM1912-19c1c826.png",
    },
    "wtypetype94": {
        "type": "Sidearm",
        "weaponName": "Type 94",
        "image": "https://cdn.gametools.network/weapons/bfv/Type94_Pistol-50a47503.png",
    },
    "wtypewelrod": {
        "type": "Sidearm",
        "weaponName": "Welrod",
        "image": "https://cdn.gametools.network/weapons/bfv/Welrod-f4b59480.png",
    },
    "wtypevickers": {
        "type": "Mmg",
        "weaponName": "VGO",
        "image": "https://cdn.gametools.network/weapons/bfv/VickersK-11cb114e.png",
    },
    "wtypemsolveig": {
        "type": "Melee",
        "weaponName": "Solveig's Knife",
        "image": "https://cdn.gametools.network/weapons/bfv/SolveigKnife-9934570a.png",
    },
    "wtypempoignard": {
        "type": "Melee",
        "weaponName": "Poignard",
        "image": "https://cdn.gametools.network/weapons/bfv/Poignard-c8264c7b.png",
    },
    "gctdfap": {
        "type": "Gadget",
        "weaponName": "Bandages",
        "image": "https://cdn.gametools.network/weapons/bfv/Supply_Medical_Pouch-1db89f38.png",
    },
    "vwepbmb500lb": {
        "type": "Gadget",
        "weaponName": "AT Mine",
        "image": "https://cdn.gametools.network/weapons/bfv/Deployable_AT_Mine-4bf207e1.png",
    },
    "gctdboomstick": {
        "type": "Gadget",
        "weaponName": "Lunge Mine",
        "image": "https://cdn.gametools.network/weapons/bfv/Boomstick-68475909.png",
    },
    "gctlflm": {
        "type": "Gadget",
        "weaponName": "M2 Flamethrower",
        "image": "https://cdn.gametools.network/weapons/bfv/Flamethrower_M2-aa650aed.png",
    },
    "wtypeppks": {
        "type": "Sidearm",
        "weaponName": "PPKS",
        "image": "https://cdn.gametools.network/weapons/bfv/WaltherPPKSuppressed-b8bdb5d5.png",
    },
    "wtypecoupe": {
        "type": "Melee",
        "weaponName": "Coupe Coupe",
        "image": "https://cdn.gametools.network/weapons/bfv/CoupeCoupe-a08d5ff6.png",
    },
    "wtypemfireaxe": {
        "type": "Melee",
        "weaponName": "Fire Axe",
        "image": "https://cdn.gametools.network/weapons/bfv/FireAxe-4f17c94d.png",
    },
    "wtypemlpipe": {
        "type": "Melee",
        "weaponName": "Lever Pipe",
        "image": "https://cdn.gametools.network/weapons/bfv/LeverPipe-310bcfe7.png",
    },
    "wtypemm3sdagg": {
        "type": "Melee",
        "weaponName": "MKIII(S) Elite Combat Dagger",
        "image": "https://cdn.gametools.network/weapons/bfv/FirestormKnife-8a6cc848.png",
    },
    "wtypembottle": {
        "type": "Melee",
        "weaponName": "Broken Bottle",
        "image": "https://cdn.gametools.network/weapons/bfv/BrokenBottle-542adc4d.png",
    },
    "wtypemescapeaxe": {
        "type": "Melee",
        "weaponName": "Escape Axe",
        "image": "https://cdn.gametools.network/weapons/bfv/EscapeAxe-f2181991.png",
    },
    "wtypembarbedbat": {
        "type": "Melee",
        "weaponName": "Barbed Baseball Bat",
        "image": "https://cdn.gametools.network/weapons/bfv/BarbedBaseballBat-fdf73eab.png",
    },
    "wtypemarditi": {
        "type": "Melee",
        "weaponName": "Arditi Dagger",
        "image": "https://cdn.gametools.network/weapons/bfv/ArditiDagger-2883ed9b.png",
    },
    "wtypemokinawamachete": {
        "type": "Melee",
        "weaponName": "Commando Machete",
        "image": "https://cdn.gametools.network/weapons/bfv/OkinawaMachete-d66152d3.png",
    },
    "wtypemustrench": {
        "type": "Melee",
        "weaponName": "Knuckle Duster",
        "image": "https://cdn.gametools.network/weapons/bfv/USTrenchKnife-a80da6fb.png",
    },
    "wtypelionheadsword": {
        "type": "Melee",
        "weaponName": "Lion Head Sword",
        "image": "https://cdn.gametools.network/weapons/bfv/Saber-4e5571ac.png",
    },
    "gctthrwgtype99": {
        "type": "Gadget",
        "weaponName": "Type 99 Mine",
        "image": "https://cdn.gametools.network/weapons/bfv/Deployable_Type99_Mine-d96f6efd.png",
    },
    "wtypemkabar": {
        "type": "Melee",
        "weaponName": "Combat Knife",
        "image": "https://cdn.gametools.network/weapons/bfv/KABARKnife-7e48ad8b.png",
    },
    "wtypemhachiwari": {
        "type": "Melee",
        "weaponName": "Hachiwari",
        "image": "https://cdn.gametools.network/weapons/bfv/Hachiwari-a5f5884a.png",
    },
    "wtypembonesaw": {
        "type": "Melee",
        "weaponName": "Bone Saw",
        "image": "https://cdn.gametools.network/weapons/bfv/BoneSaw-df104409.png",
    },
    "wtypemuselite03": {
        "type": "Melee",
        "weaponName": "Golden Eagle",
        "image": "https://cdn.gametools.network/weapons/bfv/GoldenEagleKnife-33c9216a.png",
    },
    "gctthrwgsti": {
        "type": "Gadget",
        "weaponName": "Sticky Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_AntiTank_Frag_Sticky-3f809cbe.png",
    },
    "gctthrwgdemo": {
        "type": "Gadget",
        "weaponName": "Demolition Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_Demolition-b1577ee3.png",
    },
    "wtypeppk": {
        "type": "Sidearm",
        "weaponName": "PPK",
        "image": "https://cdn.gametools.network/weapons/bfv/WaltherPPK-6528d353.png",
    },
    "wtypembplank": {
        "type": "Melee",
        "weaponName": "Burned Plank",
        "image": "https://cdn.gametools.network/weapons/bfv/BurnedPlank-112da8c0.png",
    },
    "wtypemrustyk": {
        "type": "Melee",
        "weaponName": "EGW Survival Knife",
        "image": "https://cdn.gametools.network/weapons/bfv/RustyEGWSurvivalKnife-846cfb4d.png",
    },
    "wtypemflightstick": {
        "type": "Melee",
        "weaponName": "Control Stick",
        "image": "https://cdn.gametools.network/weapons/bfv/JapaneseFlightStick-199a01ec.png",
    },
    "gctthrwkn": {
        "type": "Gadget",
        "weaponName": "Kunai",
        "image": "https://cdn.gametools.network/weapons/bfv/Throwable_Kunai-9610d695.png",
    },
    "wtypemfair": {
        "type": "Gadget",
        "weaponName": "Firecrackers",
        "image": "https://cdn.gametools.network/weapons/bfv/Throwable_M80-b0e5f292.png",
    },
    "wtypemk98bay": {
        "type": "Melee",
        "weaponName": "K98 Bayonet",
        "image": "https://cdn.gametools.network/weapons/bfv/K98Bayonet-3d5a1a9a.png",
    },
    "wtypemshillelagh": {
        "type": "Melee",
        "weaponName": "Shillelagh",
        "image": "https://cdn.gametools.network/weapons/bfv/Shillelagh-f9dd5573.png",
    },
    "wtypemchristmasbat": {
        "type": "Melee",
        "weaponName": "The Unexpected Gift",
        "image": "https://cdn.gametools.network/weapons/bfv/ChristmasBaseballBat-a3965f86.png",
    },
    "veqlaunch": {
        "type": "Gadget",
        "weaponName": "Type 99 Mine",
        "image": "https://cdn.gametools.network/weapons/bfv/Deployable_Type99_Mine-d96f6efd.png",
    },
    "vweplaunchgr": {
        "type": "Gadget",
        "weaponName": "Frag Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_AntiPersonal_Frag_Fuse_UK-51667306.png",
    },
    "vwepshellheat": {
        "type": "Gadget",
        "weaponName": "Medical Crate",
        "image": "https://cdn.gametools.network/weapons/bfv/Supply_Medical_Crate-b3f2f42a.png",
    },
    "veqreptrack": {
        "type": "Gadget",
        "weaponName": "Spotting Scope",
        "image": "https://cdn.gametools.network/weapons/bfv/Intel_Scope-a931f9f1.png",
    },
    "rnwtypm1911": {
        "type": "Lmg",
        "weaponName": "Chauchat",
        "image": "https://cdn.gametools.network/weapons/bfv/Chauchat-10361a12.png",
    },
    "veqrepquick": {
        "type": "Gadget",
        "weaponName": "Frag Grenade Rifle",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_SMLE_Grenade-1be05d77.png",
    },
    "gcttndlssyrg": {
        "type": "Gadget",
        "weaponName": "Medical Syringe",
        "image": "https://cdn.gametools.network/weapons/bfv/Supply_Medical_Syringe-aee7e9fa.png",
    },
    "wtypemscout": {
        "type": "Gadget",
        "weaponName": "Type 99 Mine",
        "image": "https://cdn.gametools.network/weapons/bfv/Deployable_Type99_Mine-d96f6efd.png",
    },
    "vwepshellap": {
        "type": "Gadget",
        "weaponName": "Impact Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_AntiPersonal_Frag_Impact_UK-4f81ac0f.png",
    },
}
VEHICLES = {
    "taTigISturm": {
        "type": "Tanks",
        "vehicleName": "STURMTIGER",
        "image": "https://cdn.gametools.network/vehicles/bfv/Sturmtiger-3c762491.png",
    },
    "trM3Halft": {
        "type": "Transports",
        "vehicleName": "M3",
        "image": "https://cdn.gametools.network/vehicles/bfv/M3-5dc0e0e7.png",
    },
    "trT48GMC": {
        "type": "Transports",
        "vehicleName": "T48 GMC",
        "image": "https://cdn.gametools.network/vehicles/bfv/M3_T48-1bcaca18.png",
    },
    "trSdKfz": {
        "type": "Transports",
        "vehicleName": "SD. KFZ 251 HALFTRACK",
        "image": "https://cdn.gametools.network/vehicles/bfv/HanomagHalftrack-f86c7ef0.png",
    },
    "trPakWag": {
        "type": "Transports",
        "vehicleName": "SD. KFZ. 251 PAKWAGEN",
        "image": "https://cdn.gametools.network/vehicles/bfv/PakwagenHalftrack-17e871af.png",
    },
    "taChuCro": {
        "type": "Tanks",
        "vehicleName": "CHURCHILL CROCODILE",
        "image": "https://cdn.gametools.network/vehicles/bfv/ChurchillCrocodileTank-d0878564.png",
    },
    "stw6pound": {
        "type": "Stationary",
        "vehicleName": "6 POUNDER",
        "image": "https://cdn.gametools.network/vehicles/bfv/QF6Pounder-a98f3167.png",
    },
    "stwFlak": {
        "type": "Stationary",
        "vehicleName": "FLAK 38",
        "image": "https://cdn.gametools.network/vehicles/bfv/FLAK38AA-45078234.png",
    },
    "stwPak": {
        "type": "Stationary",
        "vehicleName": "PAK 40",
        "image": "https://cdn.gametools.network/vehicles/bfv/PAK40-39c3918d.png",
    },
    "stwMGmg34": {
        "type": "Stationary",
        "vehicleName": "STATIONARY MG34",
        "image": "https://cdn.gametools.network/vehicles/bfv/MG34_Stationary-0d84725f.png",
    },
    "stwMGtype93": {
        "type": "Stationary",
        "vehicleName": "TYPE 93 HMG",
        "image": "https://cdn.gametools.network/vehicles/bfv/Stationary_Type92_HMG-10e95b63.png",
    },
    "stwBofors": {
        "type": "Stationary",
        "vehicleName": "40MM AA",
        "image": "https://cdn.gametools.network/vehicles/bfv/Stationary_40mmAA-91ad1c10.png",
    },
    "stwType10": {
        "type": "Stationary",
        "vehicleName": "TYPE 10",
        "image": "https://cdn.gametools.network/vehicles/bfv/Stationary_Type10-5156b60a.png",
    },
    "taSturmIV0": {
        "type": "Tanks",
        "vehicleName": "STURMGESCHUTZ IV",
        "image": "https://cdn.gametools.network/vehicles/bfv/StugIV-133ce60b.png",
    },
    "taValMkVIII": {
        "type": "Tanks",
        "vehicleName": "VALENTINE MK VIII",
        "image": "https://cdn.gametools.network/vehicles/bfv/valentine-2837c094.png",
    },
    "chaA20": {
        "type": "Tanks",
        "vehicleName": "M8 GREYHOUND",
        "image": "https://cdn.gametools.network/vehicles/bfv/Greyhound-76b96c18.png",
    },
    "stwMGvick": {
        "type": "Stationary",
        "vehicleName": "VICKERS",
        "image": "https://cdn.gametools.network/vehicles/bfv/VickersStationaryMG-eb5f1bdb.png",
    },
    "taPazIV": {
        "type": "Tanks",
        "vehicleName": "PANZER IV",
        "image": "https://cdn.gametools.network/vehicles/bfv/PanzerIVTank_1-adc5c741.png",
    },
    "chaPazIV": {
        "type": "Transports",
        "vehicleName": "GPW",
        "image": "https://cdn.gametools.network/vehicles/bfv/Car_Willys-8ed5b812.png",
    },
    "stwMGm2": {
        "type": "Stationary",
        "vehicleName": "M2 HMG",
        "image": "https://cdn.gametools.network/vehicles/bfv/Stationary_M2_HMG-fd3d7264.png",
    },
    "chaMus": {
        "type": "Tanks",
        "vehicleName": "CHURCHILL GUN CARRIER",
        "image": "https://cdn.gametools.network/vehicles/bfv/ChurchillGunCarrierTank-0725b8c6.png",
    },
    "chaM3Halft": {
        "type": "Tanks",
        "vehicleName": "HACHI",
        "image": "https://cdn.gametools.network/vehicles/bfv/Chi-Ha_RocketLauncher_DeployVersion-13eacf14.png",
    },
    "chaTigI": {
        "type": "Tanks",
        "vehicleName": "PANZER IV",
        "image": "https://cdn.gametools.network/vehicles/bfv/PanzerIVTank_1-adc5c741.png",
    },
    "chaStuka": {
        "type": "Transports",
        "vehicleName": "TYPE 95 CAR",
        "image": "https://cdn.gametools.network/vehicles/bfv/Car_Type95_Kurogane-832fd07e.png",
    },
    "taStagT17E10": {
        "type": "Planes",
        "vehicleName": "P51K Fighter",
        "image": "https://cdn.gametools.network/vehicles/bfv/Mustang-0f157d3d.png",
    },
    "chaChu": {
        "type": "Transports",
        "vehicleName": "TYPE 95 CAR",
        "image": "https://cdn.gametools.network/vehicles/bfv/Car_Type95_Kurogane-832fd07e.png",
    },
    "chaSdKfz": {
        "type": "Planes",
        "vehicleName": "ZERO A6M2",
        "image": "https://cdn.gametools.network/vehicles/bfv/Pac_Zero-32f4d600.png",
    },
    "chaVal": {
        "type": "Planes",
        "vehicleName": "JU-88 C",
        "image": "https://cdn.gametools.network/vehicles/bfv/JU88_C-ad411a79.png",
    },
    "ta": {
        "type": "Tanks",
        "vehicleName": "M8 GREYHOUND",
        "image": "https://cdn.gametools.network/vehicles/bfv/Greyhound-76b96c18.png",
    },
    "chaSher": {
        "type": "Transports",
        "vehicleName": "LCVP",
        "image": "https://cdn.gametools.network/vehicles/bfv/Boat_Higgins-257e601c.png",
    },
    "trv": {
        "type": "Planes",
        "vehicleName": "BF 109 G-2",
        "image": "https://cdn.gametools.network/vehicles/bfv/BF109-c6bd45c6.png",
    },
    "av": {
        "type": "Tanks",
        "vehicleName": "VALENTINE AA MK I",
        "image": "https://cdn.gametools.network/vehicles/bfv/ValentineCrusaderAA-f7c31668.png",
    },
    "chaCor": {
        "type": "Tanks",
        "vehicleName": "CHURCHILL GUN CARRIER",
        "image": "https://cdn.gametools.network/vehicles/bfv/ChurchillGunCarrierTank-0725b8c6.png",
    },
    "alv": {
        "type": "Tanks",
        "vehicleName": "PANZER IV",
        "image": "https://cdn.gametools.network/vehicles/bfv/PanzerIVTank_1-adc5c741.png",
    },
    "wtypestw": {
        "type": "Transports",
        "vehicleName": "DINGHY",
        "image": "https://cdn.gametools.network/vehicles/bfv/Boat_Dinghy-7722932f.png",
    },
    "taStagT17E11": {
        "type": "Transports",
        "vehicleName": "KETTENKRAD",
        "image": "https://cdn.gametools.network/vehicles/bfv/KettenkradLightTransport-1cefde85.png",
    },
}
CLASSES = {
    "assault": {
        "className": "Assault",
        "image": "https://cdn.gametools.network/classes/bf5/white/Assault.png",
        "altImage": "https://cdn.gametools.network/classes/bf5/black/Assault.png",
    },
    "medic": {
        "className": "Medic",
        "image": "https://cdn.gametools.network/classes/bf5/white/Medic.png",
        "altImage": "https://cdn.gametools.network/classes/bf5/black/Medic.png",
    },
    "recon": {
        "className": "Recon",
        "image": "https://cdn.gametools.network/classes/bf5/white/Recon.png",
        "altImage": "https://cdn.gametools.network/classes/bf5/black/Recon.png",
    },
    "support": {
        "className": "Support",
        "image": "https://cdn.gametools.network/classes/bf5/white/Support.png",
        "altImage": "https://cdn.gametools.network/classes/bf5/black/Support.png",
    },
}
STAT_GAMEMODE = {
    "dom": {"gamemodeName": "Domination"},
    "rush": {"gamemodeName": "Rush"},
    "frontlines": {"gamemodeName": "Frontlines"},
    "tdm": {"gamemodeName": "Team Deathmatch"},
    "outp": {"gamemodeName": "Outpost"},
    "bth": {"gamemodeName": "Breakthrough"},
    "conq": {"gamemodeName": "Conquest"},
}
STAT_GAMEMODE_EXTR = {
    "dom": "gm_domination",
    "rush": "gm_rush",
    "frontlines": "gm_frontlines",
    "tdm": "gm_tdm",
    "outp": "gm_outpost",
    "bth": "gm_breakthrough",
    "conq": "gm_conquest",
}
STAT_MAPS = {
    "arcticfjell": {
        "mapName": "Fjell 652",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_ArcticFjell-df3c1290.jpg",
    },
    "arcticfjord": {
        "mapName": "Narvik",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_ArcticFjord-7ba29138.jpg",
    },
    "arras": {
        "mapName": "Arras",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Arras-4b610505.jpg",
    },
    "devastation": {
        "mapName": "Devastation",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Devastation-623dea60.jpg",
    },
    "escaut": {
        "mapName": "Twisted Steel",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Escaut-9764d1fb.jpg",
    },
    "foxhunt": {
        "mapName": "Aerodrome",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_AfricanFox-8ad380a5.jpg",
    },
    "halfaya": {
        "mapName": "Hamada",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_AfricanHalfaya-31165f9b.jpg",
    },
    "rotterdam": {
        "mapName": "Rotterdam",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Rotterdam-55632240.jpg",
    },
    "hannut": {
        "mapName": "Panzerstorm",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Hannut-ebbe7197.jpg",
    },
    "crete": {
        "mapName": "Mercury",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Crete-304a202d.jpg",
    },
    "kalamas": {
        "mapName": "Marita",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Kalamas-c64c8451.jpg",
    },
    "provence": {
        "mapName": "Provence",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_ProvenceXL-a950ad3e.jpg",
    },
    "sandandsea": {
        "mapName": "Al Sudan",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_SandAndSea-f071e6f7.jpg",
    },
    "bunker": {
        "mapName": "Operation Underground",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Bunker-7b518876.jpg",
    },
    "iwojima": {
        "mapName": "Iwo Jima",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_IwoJima-760850fc.jpg",
    },
    "tropicislands": {
        "mapName": "Pacific Storm",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_TropicIslands-9e0a41c3.jpg",
    },
    "wakeisland": {
        "mapName": "Wake Island",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_WakeIsland-3238b455.jpg",
    },
    "jungle": {
        "mapName": "Solomon Islands",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Jungle-714218ce.jpg",
    },
    "libya": {
        "mapName": "Al Marj Encampment",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Libya-bd54b090.jpg",
    },
    "norway": {
        "mapName": "Lofoten Islands",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Norway-7d6d6300.jpg",
    },
}
FACTIONS = {
    "BFFactionId_FactionGER": {
        "key": "GER",
        "name": "German Empire",
        "shortName": "GER",
        "image": "https://cdn.gametools.network/factions/bfv/BFFactionId_FactionGER.png",
    },
    "BFFactionId_FactionUK": {
        "key": "UK",
        "name": "British Empire",
        "shortName": "UK",
        "image": "https://cdn.gametools.network/factions/bfv/BFFactionId_FactionUK.png",
    },
    "BFFactionId_FactionUSA_Pacific": {
        "key": "USA_Pacific",
        "name": "UNITED STATES OF AMERICA",
        "shortName": "USA",
        "image": "https://cdn.gametools.network/factions/bfv/BFFactionId_FactionUSA_Pacific.png",
    },
    "BFFactionId_FactionJPN": {
        "key": "JPN",
        "name": "Empire of Japan",
        "shortName": "JPN",
        "image": "https://cdn.gametools.network/factions/bfv/BFFactionId_FactionJPN.png",
    },
}
INTERNAL_MAP_NAME = {
    "fjell 652": "MP_ArcticFjell",
    "narvik": "MP_ArcticFjord",
    "arras": "MP_Arras",
    "devastation": "MP_Devastation",
    "twisted steel": "MP_Escaut",
    "aerodrome": "MP_Foxhunt",
    "hamada": "MP_Halfaya",
    "rotterdam": "MP_Rotterdam",
    "panzerstorm": "MP_Hannut",
    "mercury": "MP_Crete",
    "marita": "MP_Kalamas",
    "provence": "MP_Provence",
    "al sudan": "MP_SandAndSea",
    "operation Underground": "MP_Bunker",
    "iwo jima": "MP_IwoJima",
    "pacific storm": "MP_TropicIslands",
    "wake island": "MP_WakeIsland",
    "solomon islands": "MP_Jungle",
    "al marj encampment": "MP_Libya",
    "lofoten islands": "MP_Norway",
}
MAP_FACTIONS = {
    "MP_ArcticFjell": ["BFFactionId_FactionUK", "BFFactionId_FactionGER"],
    "MP_ArcticFjord": ["BFFactionId_FactionUK", "BFFactionId_FactionGER"],
    "MP_Arras": ["BFFactionId_FactionGER", "BFFactionId_FactionUK"],
    "MP_Devastation": ["BFFactionId_FactionGER", "BFFactionId_FactionUK"],
    "MP_Escaut": ["BFFactionId_FactionGER", "BFFactionId_FactionUSA_Pacific"],
    "MP_Foxhunt": ["BFFactionId_FactionUK", "BFFactionId_FactionGER"],
    "MP_Halfaya": ["BFFactionId_FactionUK", "BFFactionId_FactionGER"],
    "MP_Rotterdam": ["BFFactionId_FactionGER", "BFFactionId_FactionUK"],
    "MP_Hannut": ["BFFactionId_FactionUSA_Pacific", "BFFactionId_FactionGER"],
    "MP_Crete": ["BFFactionId_FactionGER", "BFFactionId_FactionUK"],
    "MP_Kalamas": ["BFFactionId_FactionGER", "BFFactionId_FactionUK"],
    "MP_Provence": ["BFFactionId_FactionUSA_Pacific", "BFFactionId_FactionGER"],
    "MP_SandAndSea": ["BFFactionId_FactionUSA_Pacific", "BFFactionId_FactionGER"],
    "MP_Bunker": ["BFFactionId_FactionUK", "BFFactionId_FactionGER"],
    "MP_IwoJima": ["BFFactionId_FactionUSA_Pacific", "BFFactionId_FactionJPN"],
    "MP_TropicIslands": ["BFFactionId_FactionUSA_Pacific", "BFFactionId_FactionJPN"],
    "MP_WakeIsland": ["BFFactionId_FactionUSA_Pacific", "BFFactionId_FactionJPN"],
    "MP_Jungle": ["BFFactionId_FactionUSA_Pacific", "BFFactionId_FactionJPN"],
    "MP_Libya": ["BFFactionId_FactionUSA_Pacific", "BFFactionId_FactionGER"],
}
SMALLMODES = {
    "Conquest": "CQ",
    "Domination": "DM",
    "TugOfWar": "FL",
    "Rush": "RS",
    "BreakthroughLarge": "OP",
    "Breakthrough": "SO",
    "Possession": "WP",
    "TeamDeathMatch": "TM",
    "ZoneControl": "SD",
    "AirAssault": "AA",
}
WEAPON_LIST = [
    "M1919A6",
    "Gewehr 43",
    "M1A1 Carbine",
    "M1 Garand",
    "Scout Knife M1916",
    "Hatchet",
    "Club",
    "Pickaxe",
    "K98 Bayonet",
    "Frag Grenade Rifle",
    "Sticky Dynamite",
    "Panzerfaust",
    "Bandages",
    "AP Mine",
    "Medical Crate",
    "Spotting Scope",
    "Flare Gun",
    "Smoke Grenade",
    "Frag Grenade",
    "Incendiary Grenade",
    "Smoke Grenade Rifle",
    "Throwing Blade",
    "Medical Syringe",
    "Fliegerfaust",
    "Kunai",
    "KE7",
    "Bren Gun",
    "FG-42",
    "Chauchat",
    "M30 Drilling",
    "M1897",
    "Model 37",
    "Repetierpistole M1912",
    "M1911",
    "P38 Pistol",
    "Ruby",
    "P08 Pistol",
    "StG 44",
    "Sturmgewehr 1-5",
    "Ribeyrolles 1918",
    "M2 Carbine",
    "M1928A1",
    "MP28",
    "STEN",
    "Suomi KP/-31",
    "MP40",
    "Type 100",
    "Krag–Jørgensen",
    "Gewehr M95/30",
    "Lee-Enfield No.4 Mk I",
    "Kar98k",
    "Type 99 Arisaka",
    "Model 8",
    "ZH-29",
]
