ALL_BF_GAMES = ["bf2", "bf3", "bf4", "bfh", "bf1", "bf5"]
COOKIE = {"sid": "", "remid": ""}
FRONTEND_GAME_FULLNAME = {
    "tunguska": "Battlefield 1",
    "casablanca": "Battlefield V",
    "kingston": "Battlefield 2042",
    "bf4": "Battlefield 4",
    "bf3": "Battlefield 3",
    "bfh": "Battlefield Hardline",
    "bf2": "Battlefield 2",
    "bfbc2": "Battlefield Bad Company 2",
}
FRONTEND_GAME_TRANSLATION = {
    "tunguska": "bf1",
    "casablanca": "bfv",
    "kingston": "bf2042",
    "bf4": "bf4",
    "bfh": "bfh",
    "bf3": "bf3",
    "bf2": "bf2",
    "bfbc2": "bfbc2",
}
GAMEMODES = {
    "TugOfWar": "Frontlines",
    "Domination": "Domination",
    "Breakthrough": "Shock Operations",
    "Rush": "Rush",
    "BreakthroughLarge": "Operations",
    "Conquest": "Conquest",
    "Possession": "War pigeons",
    "TeamDeathMatch": "Team Deathmatch",
    "AirAssault": "Air assault",
    "ZoneControl": "Rush",
    "Airborne": "Airborne",
    "FinalStand": "Grand Operations",
    "Outpost": "Outpost",
    "RushLarge": "Rush large",
    "Frontlines": "Frontlines",
    "FrontlinesMedium": "Frontlines Medium",
    "SquadConquest": "Squad Conquest",
    "Conquestlarge": "Conquest large",
}
JOINME_GAMES = ["tunguska", "bf1"]
OLD_GAMES = ["bf2hub", "bfbc2"]
PLATOON_ROLES = {
    "role9": "General",
    "role6": "Colonel",
    "role3": "Lieutenant",
    "role0": "Private",
}
SMALLMODES = {
    "Conquest": "CQ",
    "Domination": "DM",
    "TugOfWar": "FL",
    "Rush": "RS",
    "BreakthroughLarge": "OP",
    "Breakthrough": "SO",
    "Possession": "WP",
    "TeamDeathMatch": "TM",
    "ZoneControl": "SD",
    "AirAssault": "AA",
}
SPARTA_COMMON_ALL_STATS_METHODS = [
    "Progression.getWeaponsByPersonaId",
    "Progression.getVehiclesByPersonaId",
    "Platoons.getActivePlatoon",
    "Platoons.getPlatoons",
    "Progression.getFilteredCodexByPersonaId",
    "Progression.getDogtagsByPersonaId",
    "Progression.getMedalsByPersonaId",
]
SPARTA_GAMES = ["tunguska", "casablanca"]
SPARTA_PLATFORMS = {"cem_ea_id": "pc", "ps3": "psn", "xbox": "xbox"}
SPARTA_REGIONS = ["Afr", "AU", "OC", "AC", "SAm", "EU", "NAm", "Asia"]
SPARTA_TITLES = ["pc", "xbox", "psn"]
TEAMNAMES = ["team 2", "team 1"]
