MAPS = {
    "MP_001": "Grand Bazaar",
    "MP_003": "Tehran Highway",
    "MP_007": "Caspian Border",
    "MP_011": "Seine Crossing",
    "MP_012": "Operation Firestorm",
    "MP_013": "Damavand Peak",
    "MP_017": "Noshahr Canals",
    "MP_018": "Kharg Island",
    "MP_Subway": "Operation Métro",
    "XP1_001": "Strike at Karkand",
    "XP1_002": "Gulf of Oman",
    "XP1_003": "Sharqi Peninsula",
    "XP1_004": "Wake Island",
    "XP2_Factory": "Scrapmetal",
    "XP2_Office": "Operation 925",
    "XP2_Palace": "Donya Fortress",
    "XP2_Skybar": "Ziba Tower",
    "XP3_Alborz": "Alborz Mountains",
    "XP3_Desert": "Bandar Desert",
    "XP3_Shield": "Armored Shield",
    "XP3_Valley": "Death Valley",
    "XP4_FD": "Markaz Monolith",
    "XP4_Parl": "Azadi Palace",
    "XP4_Quake": "Epicenter",
    "XP4_Rubble": "Talah Market",
    "XP5_001": "Operation Riverside",
    "XP5_002": "Nebandan Flats",
    "XP5_003": "Kiasar Railroad",
    "XP5_004": "Sabalan Pipeline",
}
RANK_NAME = {
    "BF3_ID_P_RANK00_NAME": "RECRUIT",
    "BF3_ID_P_RANK01_NAME": "PRIVATE FIRST CLASS",
    "BF3_ID_P_RANK02_NAME": "PRIVATE FIRST CLASS 1 STAR",
    "BF3_ID_P_RANK03_NAME": "PRIVATE FIRST CLASS 2 STAR",
    "BF3_ID_P_RANK04_NAME": "PRIVATE FIRST CLASS 3 STAR",
    "BF3_ID_P_RANK05_NAME": "LANCE CORPORAL",
    "BF3_ID_P_RANK06_NAME": "LANCE CORPORAL 1 STAR",
    "BF3_ID_P_RANK07_NAME": "LANCE CORPORAL 2 STAR",
    "BF3_ID_P_RANK08_NAME": "LANCE CORPORAL 3 STAR",
    "BF3_ID_P_RANK09_NAME": "CORPORAL",
    "BF3_ID_P_RANK100_NAME": "COLONEL SERVICE STAR 55",
    "BF3_ID_P_RANK101_NAME": "COLONEL SERVICE STAR 56",
    "BF3_ID_P_RANK102_NAME": "COLONEL SERVICE STAR 57",
    "BF3_ID_P_RANK103_NAME": "COLONEL SERVICE STAR 58",
    "BF3_ID_P_RANK104_NAME": "COLONEL SERVICE STAR 59",
    "BF3_ID_P_RANK105_NAME": "COLONEL SERVICE STAR 60",
    "BF3_ID_P_RANK106_NAME": "COLONEL SERVICE STAR 61",
    "BF3_ID_P_RANK107_NAME": "COLONEL SERVICE STAR 62",
    "BF3_ID_P_RANK108_NAME": "COLONEL SERVICE STAR 63",
    "BF3_ID_P_RANK109_NAME": "COLONEL SERVICE STAR 64",
    "BF3_ID_P_RANK10_NAME": "CORPORAL 1 STAR",
    "BF3_ID_P_RANK110_NAME": "COLONEL SERVICE STAR 65",
    "BF3_ID_P_RANK111_NAME": "COLONEL SERVICE STAR 66",
    "BF3_ID_P_RANK112_NAME": "COLONEL SERVICE STAR 67",
    "BF3_ID_P_RANK113_NAME": "COLONEL SERVICE STAR 68",
    "BF3_ID_P_RANK114_NAME": "COLONEL SERVICE STAR 69",
    "BF3_ID_P_RANK115_NAME": "COLONEL SERVICE STAR 70",
    "BF3_ID_P_RANK116_NAME": "COLONEL SERVICE STAR 71",
    "BF3_ID_P_RANK117_NAME": "COLONEL SERVICE STAR 72",
    "BF3_ID_P_RANK118_NAME": "COLONEL SERVICE STAR 73",
    "BF3_ID_P_RANK119_NAME": "COLONEL SERVICE STAR 74",
    "BF3_ID_P_RANK11_NAME": "CORPORAL 2 STAR",
    "BF3_ID_P_RANK120_NAME": "COLONEL SERVICE STAR 75",
    "BF3_ID_P_RANK121_NAME": "COLONEL SERVICE STAR 76",
    "BF3_ID_P_RANK122_NAME": "COLONEL SERVICE STAR 77",
    "BF3_ID_P_RANK123_NAME": "COLONEL SERVICE STAR 78",
    "BF3_ID_P_RANK124_NAME": "COLONEL SERVICE STAR 79",
    "BF3_ID_P_RANK125_NAME": "COLONEL SERVICE STAR 80",
    "BF3_ID_P_RANK126_NAME": "COLONEL SERVICE STAR 81",
    "BF3_ID_P_RANK127_NAME": "COLONEL SERVICE STAR 82",
    "BF3_ID_P_RANK128_NAME": "COLONEL SERVICE STAR 83",
    "BF3_ID_P_RANK129_NAME": "COLONEL SERVICE STAR 84",
    "BF3_ID_P_RANK12_NAME": "CORPORAL 3 STAR",
    "BF3_ID_P_RANK130_NAME": "COLONEL SERVICE STAR 85",
    "BF3_ID_P_RANK131_NAME": "COLONEL SERVICE STAR 86",
    "BF3_ID_P_RANK132_NAME": "COLONEL SERVICE STAR 87",
    "BF3_ID_P_RANK133_NAME": "COLONEL SERVICE STAR 88",
    "BF3_ID_P_RANK134_NAME": "COLONEL SERVICE STAR 89",
    "BF3_ID_P_RANK135_NAME": "COLONEL SERVICE STAR 90",
    "BF3_ID_P_RANK136_NAME": "COLONEL SERVICE STAR 91",
    "BF3_ID_P_RANK137_NAME": "COLONEL SERVICE STAR 92",
    "BF3_ID_P_RANK138_NAME": "COLONEL SERVICE STAR 93",
    "BF3_ID_P_RANK139_NAME": "COLONEL SERVICE STAR 94",
    "BF3_ID_P_RANK13_NAME": "SERGEANT",
    "BF3_ID_P_RANK140_NAME": "COLONEL SERVICE STAR 95",
    "BF3_ID_P_RANK141_NAME": "COLONEL SERVICE STAR 96",
    "BF3_ID_P_RANK142_NAME": "COLONEL SERVICE STAR 97",
    "BF3_ID_P_RANK143_NAME": "COLONEL SERVICE STAR 98",
    "BF3_ID_P_RANK144_NAME": "COLONEL SERVICE STAR 99",
    "BF3_ID_P_RANK145_NAME": "COLONEL SERVICE STAR 100",
    "BF3_ID_P_RANK14_NAME": "SERGEANT 1 STAR",
    "BF3_ID_P_RANK15_NAME": "SERGEANT 2 STAR",
    "BF3_ID_P_RANK16_NAME": "SERGEANT 3 STAR",
    "BF3_ID_P_RANK17_NAME": "STAFF SERGEANT",
    "BF3_ID_P_RANK18_NAME": "STAFF SERGEANT 1 STAR",
    "BF3_ID_P_RANK19_NAME": "STAFF SERGEANT 2 STAR",
    "BF3_ID_P_RANK20_NAME": "GUNNERY SERGEANT",
    "BF3_ID_P_RANK21_NAME": "GUNNERY SERGEANT 1 STAR",
    "BF3_ID_P_RANK22_NAME": "GUNNERY SERGEANT 2 STAR",
    "BF3_ID_P_RANK23_NAME": "MASTER SERGEANT",
    "BF3_ID_P_RANK24_NAME": "MASTER SERGEANT 1 STAR",
    "BF3_ID_P_RANK25_NAME": "MASTER SERGEANT 2 STAR",
    "BF3_ID_P_RANK26_NAME": "FIRST SERGEANT",
    "BF3_ID_P_RANK27_NAME": "FIRST SERGEANT 1 STAR",
    "BF3_ID_P_RANK28_NAME": "FIRST SERGEANT 2 STAR",
    "BF3_ID_P_RANK29_NAME": "MASTER GUNNERY SERGEANT",
    "BF3_ID_P_RANK30_NAME": "MASTER GUNNERY SERGEANT 1 STAR",
    "BF3_ID_P_RANK31_NAME": "MASTER GUNNERY SERGEANT 2 STAR",
    "BF3_ID_P_RANK32_NAME": "SERGEANT MAJOR",
    "BF3_ID_P_RANK33_NAME": "SERGEANT MAJOR 1 STAR",
    "BF3_ID_P_RANK34_NAME": "SERGEANT MAJOR 2 STAR",
    "BF3_ID_P_RANK35_NAME": "WARRANT OFFICER ONE",
    "BF3_ID_P_RANK36_NAME": "CHIEF WARRANT OFFICER TWO",
    "BF3_ID_P_RANK37_NAME": "CHIEF WARRANT OFFICER THREE",
    "BF3_ID_P_RANK38_NAME": "CHIEF WARRANT OFFICER FOUR",
    "BF3_ID_P_RANK39_NAME": "CHIEF WARRANT OFFICER FIVE",
    "BF3_ID_P_RANK40_NAME": "SECOND LIEUTENANT",
    "BF3_ID_P_RANK41_NAME": "FIRST LIEUTENANT",
    "BF3_ID_P_RANK42_NAME": "CAPTAIN",
    "BF3_ID_P_RANK43_NAME": "MAJOR",
    "BF3_ID_P_RANK44_NAME": "LIEUTENANT COLONEL",
    "BF3_ID_P_RANK45_NAME": "COLONEL",
    "BF3_ID_P_RANK46_NAME": "COLONEL SERVICE STAR 1",
    "BF3_ID_P_RANK47_NAME": "COLONEL SERVICE STAR 2",
    "BF3_ID_P_RANK48_NAME": "COLONEL SERVICE STAR 3",
    "BF3_ID_P_RANK49_NAME": "COLONEL SERVICE STAR 4",
    "BF3_ID_P_RANK50_NAME": "COLONEL SERVICE STAR 5",
    "BF3_ID_P_RANK51_NAME": "COLONEL SERVICE STAR 6",
    "BF3_ID_P_RANK52_NAME": "COLONEL SERVICE STAR 7",
    "BF3_ID_P_RANK53_NAME": "COLONEL SERVICE STAR 8",
    "BF3_ID_P_RANK54_NAME": "COLONEL SERVICE STAR 9",
    "BF3_ID_P_RANK55_NAME": "COLONEL SERVICE STAR 10",
    "BF3_ID_P_RANK56_NAME": "COLONEL SERVICE STAR 11",
    "BF3_ID_P_RANK57_NAME": "COLONEL SERVICE STAR 12",
    "BF3_ID_P_RANK58_NAME": "COLONEL SERVICE STAR 13",
    "BF3_ID_P_RANK59_NAME": "COLONEL SERVICE STAR 14",
    "BF3_ID_P_RANK60_NAME": "COLONEL SERVICE STAR 15",
    "BF3_ID_P_RANK61_NAME": "COLONEL SERVICE STAR 16",
    "BF3_ID_P_RANK62_NAME": "COLONEL SERVICE STAR 17",
    "BF3_ID_P_RANK63_NAME": "COLONEL SERVICE STAR 18",
    "BF3_ID_P_RANK64_NAME": "COLONEL SERVICE STAR 19",
    "BF3_ID_P_RANK65_NAME": "COLONEL SERVICE STAR 20",
    "BF3_ID_P_RANK66_NAME": "COLONEL SERVICE STAR 21",
    "BF3_ID_P_RANK67_NAME": "COLONEL SERVICE STAR 22",
    "BF3_ID_P_RANK68_NAME": "COLONEL SERVICE STAR 23",
    "BF3_ID_P_RANK69_NAME": "COLONEL SERVICE STAR 24",
    "BF3_ID_P_RANK70_NAME": "COLONEL SERVICE STAR 25",
    "BF3_ID_P_RANK71_NAME": "COLONEL SERVICE STAR 26",
    "BF3_ID_P_RANK72_NAME": "COLONEL SERVICE STAR 27",
    "BF3_ID_P_RANK73_NAME": "COLONEL SERVICE STAR 28",
    "BF3_ID_P_RANK74_NAME": "COLONEL SERVICE STAR 29",
    "BF3_ID_P_RANK75_NAME": "COLONEL SERVICE STAR 30",
    "BF3_ID_P_RANK76_NAME": "COLONEL SERVICE STAR 31",
    "BF3_ID_P_RANK77_NAME": "COLONEL SERVICE STAR 32",
    "BF3_ID_P_RANK78_NAME": "COLONEL SERVICE STAR 33",
    "BF3_ID_P_RANK79_NAME": "COLONEL SERVICE STAR 34",
    "BF3_ID_P_RANK80_NAME": "COLONEL SERVICE STAR 35",
    "BF3_ID_P_RANK81_NAME": "COLONEL SERVICE STAR 36",
    "BF3_ID_P_RANK82_NAME": "COLONEL SERVICE STAR 37",
    "BF3_ID_P_RANK83_NAME": "COLONEL SERVICE STAR 38",
    "BF3_ID_P_RANK84_NAME": "COLONEL SERVICE STAR 39",
    "BF3_ID_P_RANK85_NAME": "COLONEL SERVICE STAR 40",
    "BF3_ID_P_RANK86_NAME": "COLONEL SERVICE STAR 41",
    "BF3_ID_P_RANK87_NAME": "COLONEL SERVICE STAR 42",
    "BF3_ID_P_RANK88_NAME": "COLONEL SERVICE STAR 43",
    "BF3_ID_P_RANK89_NAME": "COLONEL SERVICE STAR 44",
    "BF3_ID_P_RANK90_NAME": "COLONEL SERVICE STAR 45",
    "BF3_ID_P_RANK91_NAME": "COLONEL SERVICE STAR 46",
    "BF3_ID_P_RANK92_NAME": "COLONEL SERVICE STAR 47",
    "BF3_ID_P_RANK93_NAME": "COLONEL SERVICE STAR 48",
    "BF3_ID_P_RANK94_NAME": "COLONEL SERVICE STAR 49",
    "BF3_ID_P_RANK95_NAME": "COLONEL SERVICE STAR 50",
    "BF3_ID_P_RANK96_NAME": "COLONEL SERVICE STAR 51",
    "BF3_ID_P_RANK97_NAME": "COLONEL SERVICE STAR 52",
    "BF3_ID_P_RANK98_NAME": "COLONEL SERVICE STAR 53",
    "BF3_ID_P_RANK99_NAME": "COLONEL SERVICE STAR 54",
}
WEAPONS = [
    "RPK",
    "FGM-148 JAVELIN",
    "SKS",
    "M39",
    "Pecheneg",
    "M416",
    "G36C",
    "M412 Rex",
    "SV98",
    "RPG-7",
    "Crossbow kobra",
    "Glock 17",
    "AN94",
    "M60",
    "M1911 LIT",
    "SCAR",
    "MK11",
    "Glock 18 Silenced",
    "UMP",
    "PDR",
    "M98B",
    "M9 Silenced",
    "XP2 L86A1",
    "M40A5",
    "USAS",
    "XP2 LSAT",
    "XP1 QBB95",
    "XP1 HK53",
    "M1911",
    "XP1 QBU88",
    "M16A4",
    "XP2 AUG",
    "M1014",
    "AEK971",
    "G3A4",
    "Taurus 44",
    "AKS74U",
    "Glock 17 Silenced",
    "Underslung Launcher",
    "Glock 18",
    "F2000",
    "M1911 SILENCED",
    "MP443 LIT",
    "Taurus 44 scoped",
    "XP1 L96",
    "XP1 FAMAS",
    "M249",
    "A91",
    "AS-VAL",
    "P90",
    "M93R",
    "XP1 PP19",
    "870",
    "XP2 HK417",
    "MP443 Silenced",
    "M9 Flashlight",
    "PP2000",
    "XP2 SPAS12",
    "MP7",
    "AK74M",
    "Underslung Shotgun",
    "MP 443",
    "Crossbow Scoped",
    "Saiga",
    "XP1 L85A2",
    "DAO",
    "M27",
    "SG553",
    "Type88",
    "SA-18 IGLA AA",
    "Knife",
    "M240",
    "XP2 MTAR-21",
    "SVD",
    "KH2002",
    "XP1 Jackhammer",
    "XP2 SCARL",
    "M1911 Tactical",
    "XP2 MP5K",
    "FIM-92 STINGER AA",
    "M9",
    "XP2 ACR",
    "M4A1",
    "XP2 JNG90",
    "XP1 QBZ95B",
    "XP1 MG36",
    "Mk153 SMAW",
]
INTERNAL_MAP_NAME = {
    "MP_001": "Grand Bazaar",
    "MP_003": "Tehran Highway",
    "MP_007": "Caspian Border",
    "MP_011": "Seine Crossing",
    "MP_012": "Operation Firestorm",
    "MP_013": "Damavand Peak",
    "MP_017": "Noshahr Canals",
    "MP_018": "Kharg Island",
    "MP_Subway": "Operation Métro",
    "XP1_001": "Strike at Karkand",
    "XP1_002": "Gulf of Oman",
    "XP1_003": "Sharqi Peninsula",
    "XP1_004": "Wake Island",
    "XP2_Factory": "Scrapmetal",
    "XP2_Office": "Operation 925",
    "XP2_Palace": "Donya Fortress",
    "XP2_Skybar": "Ziba Tower",
    "XP3_Alborz": "Alborz Mountains",
    "XP3_Desert": "Bandar Desert",
    "XP3_Shield": "Armored Shield",
    "XP3_Valley": "Death Valley",
    "XP4_FD": "Markaz Monolith",
    "XP4_Parl": "Azadi Palace",
    "XP4_Quake": "Epicenter",
    "XP4_Rubble": "Talah Market",
    "XP5_001": "Operation Riverside",
    "XP5_002": "Nebandan Flats",
    "XP5_003": "Kiasar Railroad",
    "XP5_004": "Sabalan Pipeline",
}
