CLASSES = {
    "ass_alpha": {
        "className": "Assault",
        "characterName": "Mackay",
        "statName": "Mackay (Assault)",
        "image": "https://cdn.gametools.network/classes/bf2042/IconAlpha-db5e8361.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/CharAlpha_M-9377c351.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/CharAlpha_M-9377c351.png",
        },
    },
    "sup_india": {
        "className": "Support",
        "characterName": "Angel",
        "statName": "Angel (Support)",
        "image": "https://cdn.gametools.network/classes/bf2042/IconIndia-d14545f9.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/CharIndia_M-354f160a.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/CharIndia_M-354f160a.png",
        },
    },
    "sup_foxtrot": {
        "className": "Support",
        "characterName": "Falck",
        "statName": "Falck (Support)",
        "image": "https://cdn.gametools.network/classes/bf2042/IconFoxtrot-18ea6540.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/CharFoxtrot_M-318f1124.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/CharFoxtrot_M-318f1124.png",
        },
    },
    "rec_echo": {
        "className": "Recon",
        "characterName": "Paik",
        "statName": "Paik (Recon)",
        "image": "https://cdn.gametools.network/classes/bf2042/IconEcho-891fd77b.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/CharEcho_M-38f70a40.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/CharEcho_M-38f70a40.png",
        },
    },
    "ass_charlie": {
        "className": "Assault",
        "characterName": "Sundance",
        "statName": "Sundance (Assault)",
        "image": "https://cdn.gametools.network/classes/bf2042/IconCharlie-d3876e21.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/CharCharlie_M-b95efa1a.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/CharCharlie_M-b95efa1a.png",
        },
    },
    "ass_delta": {
        "className": "Assault",
        "characterName": "Dozer",
        "statName": "Dozer (Assault)",
        "image": "https://cdn.gametools.network/classes/bf2042/IconDelta-7252512e.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/CharDelta_M-7a2bb7f1.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/CharDelta_M-7a2bb7f1.png",
        },
    },
    "rec_lima": {
        "className": "Recon",
        "characterName": "Rao",
        "statName": "Rao (Recon)",
        "image": "https://cdn.gametools.network/classes/bf2042/IconLima-1ba343fb.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/CharLima_M-8478cc5b.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/CharLima_M-8478cc5b.png",
        },
    },
    "eng_hotel": {
        "className": "Engineer",
        "characterName": "Lis",
        "statName": "Lis (Engineer)",
        "image": "https://cdn.gametools.network/classes/bf2042/IconHotel-f243ed4d.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/CharHotel_M-702acec0.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/CharHotel_M-702acec0.png",
        },
    },
    "eng_bravo": {
        "className": "Engineer",
        "characterName": "Irish",
        "statName": "Irish (Engineer)",
        "image": "https://cdn.gametools.network/classes/bf2042/IconBravo-2196c05d.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/CharBravo_M-aa905ed8.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/CharBravo_M-aa905ed8.png",
        },
    },
    "sup_mike": {
        "className": "Support",
        "characterName": "Crawford",
        "statName": "Crawford (Support)",
        "image": "https://cdn.gametools.network/classes/bf2042/IconMike-dc9fa665.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/CharAlpha_M-9377c351.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/CharAlpha_M-9377c351.png",
        },
        "avatarImage": "https://cdn.gametools.network/classes/bf2042/CharMike_M-726f8a53.png",
    },
    "eng_juliet": {
        "className": "Engineer",
        "characterName": "Boris",
        "statName": "Boris (Engineer)",
        "image": "https://cdn.gametools.network/classes/bf2042/IconJuliet-3656a6da.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/CharJuliet_M-4ae561fa.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/CharJuliet_M-4ae561fa.png",
        },
    },
    "ass_november": {
        "className": "Assault",
        "characterName": "Zain",
        "statName": "Zain (Assault)",
        "image": "https://cdn.gametools.network/classes/bf2042/IconNovember-f3251048.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/CharNovember_M-4cb65528.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/CharNovember_M-4cb65528.png",
        },
    },
    "rec_kilo": {
        "className": "Recon",
        "characterName": "Casper",
        "statName": "Casper (Recon)",
        "image": "https://cdn.gametools.network/classes/bf2042/IconKilo-9ffbea70.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/CharKilo_M-0e19f3d5.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/CharKilo_M-0e19f3d5.png",
        },
    },
    "rec_oscar": {
        "className": "Recon",
        "characterName": "Blasco",
        "statName": "Blasco (Recon)",
        "image": "https://cdn.gametools.network/classes/bf2042/IconOscar-2214e1f3.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/CharOscar_M-76506937.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/CharOscar_M-76506937.png",
        },
    },
    "rec_bf3": {
        "className": "Recon",
        "characterName": "BF3 Recon",
        "statName": "BF3 Recon",
        "image": "https://cdn.gametools.network/classes/bf2042/iconClassALX_Recon-c0b9e8d5.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/ALX_US_Recon_M-7e71219e.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/ALX_RU_Recon_M-78055d43.png",
        },
    },
    "ass_bf3": {
        "className": "Assault",
        "characterName": "BF3 Assault",
        "statName": "BF3 Assault",
        "image": "https://cdn.gametools.network/classes/bf2042/iconClassALX_Assault-af6b9941.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/ALX_US_Assault_M-f7f337bb.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/ALX_RU_Assault_M-fd459f1e.png",
        },
    },
    "sup_bf3": {
        "className": "Support",
        "characterName": "BF3 Support",
        "statName": "BF3 Support",
        "image": "https://cdn.gametools.network/classes/bf2042/iconClassALX_Support-ecdaca86.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/ALX_US_Support_M-9ee7f351.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/ALX_RU_Support_M-eaf297c9.png",
        },
    },
    "eng_bf3": {
        "className": "Engineer",
        "characterName": "BF3 Engineer",
        "statName": "BF3 Engineer",
        "image": "https://cdn.gametools.network/classes/bf2042/iconClassALX_Engineer-4a92d87f.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/ALX_US_Engineer_M-d987cde1.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/ALX_RU_Engineer_M-aff3c210.png",
        },
    },
    "rec_bc2": {
        "className": "Recon",
        "characterName": "BC2 Recon",
        "statName": "BC2 Recon",
        "image": "https://cdn.gametools.network/classes/bf2042/iconClassRUM_Recon-d3d2638f.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/RUM_US_Recon_M-eed05b82.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/RUM_RU_Recon_M-62b15dcf.png",
        },
    },
    "sup_bc2med": {
        "className": "Medic",
        "characterName": "BC2 Medic",
        "statName": "BC2 Medic",
        "image": "https://cdn.gametools.network/classes/bf2042/iconClassRUM_Medic-bb51e293.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/RUM_US_Medic_M-5c1d3f68.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/RUM_RU_Medic_M-91409f1f.png",
        },
    },
    "eng_bc2": {
        "className": "Engineer",
        "characterName": "BC2 Engineer",
        "statName": "BC2 Engineer",
        "image": "https://cdn.gametools.network/classes/bf2042/iconClassRUM_Engineer-4632bd24.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/RUM_US_Engineer_M-58699cad.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/RUM_RU_Engineer_M-37754032.png",
        },
    },
    "ass_bc2": {
        "className": "Assault",
        "characterName": "BC2 Assault",
        "statName": "BC2 Assault",
        "image": "https://cdn.gametools.network/classes/bf2042/iconClassRUM_Assault-2cd51131.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/RUM_US_Assult_M-b1201e75.png",
            "rus": "https://cdn.gametools.network/classes/bf2042/RUM_RU_Assult_M-5b38d4f4.png",
        },
    },
    "sup_1942med": {
        "className": "Anti-tank",
        "characterName": "1942 Anti-tank",
        "statName": "1942 Anti-tank",
        "image": "https://cdn.gametools.network/classes/bf2042/iconClassGRA_AntiTank-fbfa815a.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/GRA_US_AntiTank_M-7d4b0bd5.png",
            "uk": "https://cdn.gametools.network/classes/bf2042/GRA_UK_AntiTank_M-ae283256.png",
            "ger": "https://cdn.gametools.network/classes/bf2042/GRA_GER_AntiTank_M-16f931ab.png",
        },
    },
    "ass_1942": {
        "className": "Assault",
        "characterName": "1942 Assault",
        "statName": "1942 Assault",
        "image": "https://cdn.gametools.network/classes/bf2042/iconClassGRA_Assault-655085f0.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/GRA_US_Assault_M-2064c4a2.png",
            "uk": "https://cdn.gametools.network/classes/bf2042/GRA_UK_Assault_M-ab2e7b9b.png",
            "ger": "https://cdn.gametools.network/classes/bf2042/GRA_GER_Assault_M-4081d592.png",
        },
    },
    "eng_1942": {
        "className": "Engineer",
        "characterName": "1942 Engineer",
        "statName": "1942 Engineer",
        "image": "https://cdn.gametools.network/classes/bf2042/iconClassGRA_Engineer-d40f1026.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/GRA_US_Engineer_M-f0e1f883.png",
            "uk": "https://cdn.gametools.network/classes/bf2042/GRA_UK_Engineer_M-239fabb2.png",
            "ger": "https://cdn.gametools.network/classes/bf2042/GRA_GER_Engineer_M-5658b780.png",
        },
    },
    "eng_1942at": {
        "className": "Medic",
        "characterName": "1942 Medic",
        "statName": "1942 Medic",
        "image": "https://cdn.gametools.network/classes/bf2042/iconClassGRA_Medic-d7b0917e.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/GRA_US_Medic_M-a5ec1703.png",
            "uk": "https://cdn.gametools.network/classes/bf2042/GRA_UK_Medic_M-12bbb5d0.png",
            "ger": "https://cdn.gametools.network/classes/bf2042/GRA_GER_Medic_M-d8b825cd.png",
        },
    },
    "rec_1942sct": {
        "className": "Scout",
        "characterName": "1942 Scout",
        "statName": "1942 Scout",
        "image": "https://cdn.gametools.network/classes/bf2042/iconClassGRA_Scout-5c77e572.svg",
        "avatarImages": {
            "us": "https://cdn.gametools.network/classes/bf2042/GRA_US_Scout_M-63460ca3.png",
            "uk": "https://cdn.gametools.network/classes/bf2042/GRA_UK_Scout_M-1c4c3bfe.png",
            "ger": "https://cdn.gametools.network/classes/bf2042/GRA_GER_Scout_M-2671d6da.png",
        },
    },
}
FACTIONS = {
    "FactionUS": {
        "key": "US",
        "name": "United States of America",
        "shortName": "US",
        "image": "https://cdn.gametools.network/factions/bf2042/FactionUS.png",
    },
    "FactionRUS": {
        "key": "RU",
        "name": "Russian Federation",
        "shortName": "RU",
        "image": "https://cdn.gametools.network/factions/bf2042/FactionRUS.png",
    },
}
GADGETS = {
    "open_equip_c5": {
        "type": "Explosives",
        "gadgetName": "C5 Explosive [Kingston]",
        "image": "https://cdn.gametools.network/gadgets/bf2042/C4-6e2329da.png",
    },
    "char_shield": {
        "type": "Character",
        "gadgetName": "SOB-8 Ballistic Shield",
        "image": "https://cdn.gametools.network/gadgets/bf2042/DeployableCover-9a72c1fc.png",
    },
    "open_equip_rl_cgmk4": {
        "type": "Rocket Launcher",
        "gadgetName": "Carl Gustaf M5",
        "image": "https://cdn.gametools.network/gadgets/bf2042/CarlGustafMk4-460b101e.png",
    },
    "open_throw_gren_frag": {
        "type": "Grenade",
        "gadgetName": "Frag Grenade",
        "image": "https://cdn.gametools.network/gadgets/bf2042/FragGrenade-8eaf52c4.png",
    },
    "char_smart_antiarmor": {
        "type": "Smart Explosives",
        "gadgetName": "Anti Armor",
        "image": "https://cdn.gametools.network/gadgets/bf2042/SmartExplosive1-c93ac628.png",
    },
    "char_smart_scatter": {
        "type": "Smart Explosives",
        "gadgetName": "Scatter Grenade",
        "image": "https://cdn.gametools.network/gadgets/bf2042/SmartExplosive3-02e833c6.png",
    },
    "open_equip_repair": {
        "type": "Equipment",
        "gadgetName": "Repair Tool",
        "image": "https://cdn.gametools.network/gadgets/bf2042/RepairTool-ed6ee81f.png",
    },
    "char_sentrygun": {
        "type": "Character",
        "gadgetName": "SG-36 Sentry Gun",
        "image": "https://cdn.gametools.network/gadgets/bf2042/AutoTurret-94167140.png",
    },
    "open_throw_gren_emp": {
        "type": "Grenade",
        "gadgetName": "EMP Grenade",
        "image": "https://cdn.gametools.network/gadgets/bf2042/EMPGrenade-f5f1265e.png",
    },
    "open_throw_gren_at": {
        "type": "Throwable",
        "gadgetName": "Anti-Tank Grenade",
        "image": "https://cdn.gametools.network/gadgets/bf2042/GAD_ICO_Throwable_AntiTank-9a518e3b.png",
    },
    "open_throw_gren_mini": {
        "type": "Throwable",
        "gadgetName": "Mini Grenade",
        "image": "https://cdn.gametools.network/gadgets/bf2042/GAD_ICO_Throwable_Mini-30504512.png",
    },
    "char_amm_alx": {
        "type": "Ammo Box",
        "gadgetName": "Ammo Box BF3 (Portal)",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ALX__AmmoBox-8a4f44a4.png",
    },
    "char_amm_rum": {
        "type": "Ammo Box",
        "gadgetName": "Ammo Box BC2 (Portal)",
        "image": "https://cdn.gametools.network/gadgets/bf2042/RUM__Ammo-box-02b93059.png",
    },
    "char_grapple": {
        "type": "Character",
        "gadgetName": "Grappling Hook",
        "image": "https://cdn.gametools.network/gadgets/bf2042/GrappleGun-12f57257.png",
    },
    "char_hack": {
        "type": "Character",
        "gadgetName": "Cyber Warfare Suite (Signal Hacker)",
        "image": "https://cdn.gametools.network/gadgets/bf2042/SignalHacker-78998885.png",
    },
    "char_med_alx": {
        "type": "Medkit",
        "gadgetName": "Medkit BF3 (Portal)",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ALX__MedicBag-bb24ea02.png",
    },
    "char_med_gra": {
        "type": "Medkit",
        "gadgetName": "Medkit BF1942 (Portal)",
        "image": "https://cdn.gametools.network/gadgets/bf2042/GRA__Medkit-1801e49b.png",
    },
    "char_med_rum": {
        "type": "Medkit",
        "gadgetName": "Medkit BF2 (Portal)",
        "image": "https://cdn.gametools.network/gadgets/bf2042/RUM__MED-KIT-db0a4d20.png",
    },
    "char_motion": {
        "type": "Character",
        "gadgetName": "Motion Sensor (Portal)",
        "image": "https://cdn.gametools.network/gadgets/bf2042/RUM__Motion-Sensor-94ffc935.png",
    },
    "char_rdrone": {
        "type": "Character",
        "gadgetName": "OV-P Recon Drone",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ReconDrone-025b3091.png",
    },
    "char_repair_alx": {
        "type": "Repair Tool",
        "gadgetName": "Repair Tool BF3 (Portal)",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ALX__RepairTool_BlowTorch-cf0d99f8.png",
    },
    "char_repair_gra": {
        "type": "Repair Tool",
        "gadgetName": "Repair Tool BF1942 (Portal)",
        "image": "https://cdn.gametools.network/gadgets/bf2042/GRA__RepairTool_Wrench-0df0964f.png",
    },
    "char_repair_rum": {
        "type": "Repair Tool",
        "gadgetName": "Repair Tool BC2 (Portal)",
        "image": "https://cdn.gametools.network/gadgets/bf2042/RUM__Repair-Tool-a9c7ee75.png",
    },
    "char_syrettepistol": {
        "type": "Character",
        "gadgetName": "S21 Syrette Pistol",
        "image": "https://cdn.gametools.network/gadgets/bf2042/StimPistol-79f246f6.png",
    },
    "char_tugs": {
        "type": "Character",
        "gadgetName": "T-UGS (Portal)",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ALX__T-UGS-805c63da.png",
    },
    "open_equip_ammocr": {
        "type": "Equipment",
        "gadgetName": "Ammo Crate",
        "image": "https://cdn.gametools.network/gadgets/bf2042/AmmoCrate-46f6060c.png",
    },
    "open_equip_armor": {
        "type": "Equipment",
        "gadgetName": "IBA Armor Plate",
        "image": "https://cdn.gametools.network/gadgets/bf2042/Armor-4f61bc6a.png",
    },
    "open_equip_c4": {
        "type": "Explosives",
        "gadgetName": "C4 [Portal]",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ALX__C4-560f90c9.png",
    },
    "open_equip_claymore": {
        "type": "Explosives",
        "gadgetName": "M18 Claymore",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ALX__M18_Claymore-6e18b4dc.png",
    },
    "open_equip_mav": {
        "type": "Equipment",
        "gadgetName": "MAV",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ALX__MAV-68f661d6.png",
    },
    "open_equip_defib": {
        "type": "Equipment",
        "gadgetName": "Defibrillator",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ALX__Defibrillator-a0645d72.png",
    },
    "open_bc2_defib": {
        "type": "Equipment",
        "gadgetName": "Defibrillator (BC2)",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ALX__Defibrillator-a0645d72.png",
    },
    "open_bf3_defib": {
        "type": "Equipment",
        "gadgetName": "Defibrillator (BF3)",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ALX__Defibrillator-a0645d72.png",
    },
    "open_equip_javelin": {
        "type": "Rocket Launcher",
        "gadgetName": "FGM-148 Javelin",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ALX__FGM-148_Javelin-9aa9a62e.png",
    },
    "open_equip_medcr": {
        "type": "Equipment",
        "gadgetName": "Medical Crate",
        "image": "https://cdn.gametools.network/gadgets/bf2042/MedicCrate-7bb8b6dd.png",
    },
    "open_equip_medpen": {
        "type": "Equipment",
        "gadgetName": "Med-Pen (Self-heal)",
        "image": "https://cdn.gametools.network/gadgets/bf2042/SelfHeal-69f9e60e.png",
    },
    "open_equip_mine_at": {
        "type": "Explosives",
        "gadgetName": "AT Mine [Kingston]",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ATMine-b1dc1dbb.png",
    },
    "open_equip_mstrke": {
        "type": "Explosives",
        "gadgetName": "Mortar Strike",
        "image": "https://cdn.gametools.network/gadgets/bf2042/RUM__Mortar-Strike_Binoculars-a03f59a7.png",
    },
    "open_equip_radiob": {
        "type": "Equipment",
        "gadgetName": "Insertion Beacon (Spawn) (Portal)",
        "image": "https://cdn.gametools.network/gadgets/bf2042/SpawnBeacon-d9f22afe.png",
    },
    "open_equip_rpg": {
        "type": "Rocket Launcher",
        "gadgetName": "RPG-7",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ALX__RPG7-9e06e1f6.png",
    },
    "open_equip_smaw": {
        "type": "Rocket Launcher",
        "gadgetName": "SMAW",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ALX__SMAW-7a94c5a0.png",
    },
    "open_throw_dyn": {
        "type": "Throwable",
        "gadgetName": "ExpPack",
        "image": "https://cdn.gametools.network/gadgets/bf2042/GRA__Dynamite-27dc00ae.png",
    },
    "open_throw_gren_conc": {
        "type": "Grenade",
        "gadgetName": "Concussion Grenade",
        "image": "https://cdn.gametools.network/gadgets/bf2042/FlashBang-ea224d5f.png",
    },
    "open_throw_gren_inc": {
        "type": "Grenade",
        "gadgetName": "Incendiary Grenade",
        "image": "https://cdn.gametools.network/gadgets/bf2042/IncendiaryGrenade-ea934278.png",
    },
    "open_throw_gren_smo": {
        "type": "Grenade",
        "gadgetName": "Smoke Grenade",
        "image": "https://cdn.gametools.network/gadgets/bf2042/SmokeGrenade-ad6ed4ef.png",
    },
    "open_throw_motion": {
        "type": "Throwable",
        "gadgetName": "Prox Sensor (Motion)",
        "image": "https://cdn.gametools.network/gadgets/bf2042/MotionMine-2766d34f.png",
    },
    "open_throw_knife": {
        "type": "Throwable",
        "gadgetName": "Throwing Knife",
        "image": "https://cdn.gametools.network/gadgets/bf2042/GAD_Icon_throwingKnife-4b78bd1d.png",
    },
    "open_equip_soflam": {
        "type": "Equipment",
        "gadgetName": "Smoke Grenade Launcher",
        "image": "https://cdn.gametools.network/gadgets/bf2042/SOFLAM-3c23636f.png",
    },
    "open_1942_atmine": {
        "type": "Explosives",
        "gadgetName": "Lindmine",
        "image": "https://cdn.gametools.network/gadgets/bf2042/GRA__AT-Mine-d4052b6a.png",
    },
    "char_xm370a": {
        "type": "Character",
        "gadgetName": "XM370A",
        "image": "https://cdn.gametools.network/gadgets/bf2042/icon_gadget_XM370A-2d6514a4.png",
    },
    "open_equip_stinger": {
        "type": "Rocket Launcher",
        "gadgetName": "FXM-33 AA Missile",
        "image": "https://cdn.gametools.network/gadgets/bf2042/Stinger-630fbfbb.png",
    },
    "open_equip_smokegl": {
        "type": "Launchers",
        "gadgetName": "Smoke Grenade Launchers",
        "image": "https://cdn.gametools.network/gadgets/bf2042/GL_SmokeGL-3ad2ef03.png",
    },
    "open_equip_m136": {
        "type": "Rocket Launcher",
        "gadgetName": "M136 AT4",
        "image": "https://cdn.gametools.network/gadgets/bf2042/RUM__M136AT4-dcac494a.png",
    },
    "char_missiles": {
        "type": "Character",
        "gadgetName": "G-84 TGM",
        "image": "https://cdn.gametools.network/gadgets/bf2042/RL_HomingMissiles_TVGuided-2e52736c.png",
    },
    "open_equip_zook": {
        "type": "Rocket Launcher",
        "gadgetName": "Bazooka",
        "image": "https://cdn.gametools.network/weapons/bf2042/GRA__Weapons_default_Bazooka-ce1225d1.png",
    },
    "open_equip_igla": {
        "type": "Rocker Launcher",
        "gadgetName": "SA-18 Igla",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ALX__SA-18_IGLA-a09c38f1.png",
    },
    "char_bino": {
        "type": "Character",
        "gadgetName": "Binoculars BF1942",
        "image": "https://cdn.gametools.network/gadgets/bf2042/GRA__Binoculars-33bc2957.png",
    },
    "open_equip_shrek": {
        "type": "Rocket Launcher",
        "gadgetName": "Panzerschreck",
        "image": "https://cdn.gametools.network/weapons/bf2042/GRA__weapon_default_Panzerschrek-932d81bb.png",
    },
    "char_staticminigun": {
        "type": "Character",
        "gadgetName": "Mounted Vulcan",
        "image": "https://cdn.gametools.network/gadgets/bf2042/RL_Placed_Minigun-f9b2c5bf.png",
    },
    "open_equip_rpgv2": {
        "type": "Rocket Launcher",
        "gadgetName": "RPG-7v2",
        "image": "https://cdn.gametools.network/gadgets/bf2042/GAD_ICO_Launcher_RPG-30dde618.png",
    },
    "open_equip_stickygl": {
        "type": "Grenade",
        "gadgetName": "SPH Explosive Launcher",
        "image": "https://cdn.gametools.network/gadgets/bf2042/GAD_ICO_Open_StickyGrenade-1e3ea066.png",
    },
    "open_throw_gren_bb": {
        "type": "Grenade",
        "gadgetName": "Spring Grenade",
        "image": "https://cdn.gametools.network/gadgets/bf2042/GAD_ICO_Throwable_Impact-c22cff04.png",
    },
    "open_equip_eod": {
        "type": "Equipment",
        "gadgetName": "EOD Bot - BF3",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ALX__EODBot-38a9dbbe.png",
    },
    "char_suppbag_crate": {
        "type": "Supply Bag",
        "gadgetName": "Crate",
        "image": "https://cdn.gametools.network/gadgets/bf2042/SupplyBag-dfd654dc.png",
    },
    "char_suppbag_pouch": {
        "type": "Supply Bag",
        "gadgetName": "Pouch",
        "image": "https://cdn.gametools.network/gadgets/bf2042/SupplyBag-dfd654dc.png",
    },
    "open_equip_spawnb": {
        "type": "Equipment",
        "gadgetName": "Insertion Beacon (Spawn)",
        "image": "https://cdn.gametools.network/gadgets/bf2042/GAD_ICO_Classes_SpawnBeacon-b6bd1f20.png",
    },
    "open_equip_atmine": {
        "type": "Equipment",
        "gadgetName": "AT-Mine",
        "image": "https://cdn.gametools.network/gadgets/bf2042/GAD_ICO_Open_ATMine-8dda8182.png",
    },
    "open_equip_intscan": {
        "type": "Equipment",
        "gadgetName": "Intel Scanner",
        "image": "https://cdn.gametools.network/gadgets/bf2042/ARSignalScanner-9c656704.png",
    },
    "open_throw_gren_1942": {
        "type": "Grenade",
        "gadgetName": "BF1942 Grenade",
        "image": "",
    },
    "open_throw_gren_bc2": {
        "type": "Grenade",
        "gadgetName": "BC2 Grenade",
        "image": "",
    },
    "open_throw_gren_bf3": {
        "type": "Grenade",
        "gadgetName": "BF3 Grenade",
        "image": "",
    },
    "uni_callin": {
        "type": "Universal",
        "gadgetName": "Call In Tablet",
        "image": "",
    },
    "": {
        "type": "Throwable",
        "gadgetName": "Stick Grenade",
        "image": "https://cdn.gametools.network/gadgets/bf2042/GRA__StickGrenade_001-65531a5f.png",
    },
}
MAPS = {
    "MP_Harbor": "Arica Harbor",
    "MP_LightHouse": "Valparaiso",
    "MP_Frost": "Battle of the Bulge",
    "MP_Oasis": "El Alamein",
    "MP_Rural": "Caspian Border",
    "MP_Port": "Noshahr Canals",
    "MP_Orbital": "Orbital",
    "MP_Hourglass": "Hourglass",
    "MP_Kaleidoscope": "Kaleidoscope",
    "MP_Irreversible": "Breakaway",
    "MP_Discarded": "Discarded",
    "MP_LongHaul": "Manifest",
    "MP_TheWall": "Renewal",
    "MP_Ridge": "Exposure",
    "MP_Drained": "Stranded",
    "MP_LightsOut": "Spearhead",
    "MP_Boulder": "Flashpoint",
    "MP_Scarred": "Reclaimed",
    "MP_Salem": "Redacted",
    "MP_Cassava": "Haven",
    "MP_Stadium": "Stadium",
    "MP_IwoJima": "Iwo Jima",
}
MAP_TRANSLATION_IDS = {
    "MP_Harbor": "ID_LVL_MICA_HARBOR_NAME",
    "MP_LightHouse": "ID_LVL_MICA_LIGHTHOUSE_NAME",
    "MP_Frost": "ID_LVL_MICA_FROST_NAME",
    "MP_Oasis": "ID_LVL_MICA_OASIS_NAME",
    "MP_Rural": "ID_LVL_MICA_RURAL_NAME",
    "MP_Port": "ID_LVL_MICA_PORT_NAME",
    "MP_Orbital": "ID_LVL_ORBITAL_NAME",
    "MP_Hourglass": "ID_LVL_HOURGLASS_NAME",
    "MP_Kaleidoscope": "ID_LVL_KALEIDOSCOPE_NAME",
    "MP_Irreversible": "ID_LVL_IRREVERSIBLE_NAME",
    "MP_Discarded": "ID_LVL_DISCARDED_NAME",
    "MP_LongHaul": "ID_LVL_LONGHAUL_NAME",
    "MP_TheWall": "ID_LVL_THEWALL_NAME",
    "MP_Ridge": "ID_LVL_RIDGE_NAME",
    "MP_Drained": "ID_DRAINED_NAME",
    "MP_LightsOut": "ID_LVL_LIGHTSOUT_NAME",
    "MP_Boulder": "ID_BOULDER_NAME",
    "MP_Scarred": "ID_LVL_SCARRED_NAME",
    "MP_Salem": "ID_ARRIVAL_MAP_SALEM",
    "MP_Cassava": "ID_ARRIVAL_MAP_HAVEN",
    "MP_Stadium": "ID_ARRIVAL_MAP_STADIUM",
    "MP_IwoJima": "ID_ARRIVAL_MAP_IWO_JIMA",
}
MAP_FACTIONS = {
    "MP_Discarded": ["FactionUS", "FactionRUS"],
    "MP_Kaleidoscope": ["FactionUS", "FactionRUS"],
    "MP_Harbor": ["FactionUS", "FactionRUS"],
    "MP_Rural": ["FactionUS", "FactionRUS"],
    "MP_Port": ["FactionUS", "FactionRUS"],
    "MP_Oasis": ["FactionUS", "FactionRUS"],
    "MP_Ridge": ["FactionUS", "FactionRUS"],
    "MP_Orbital": ["FactionUS", "FactionRUS"],
    "MP_Drained": ["FactionUS", "FactionRUS"],
    "MP_Frost": ["FactionUS", "FactionRUS"],
    "MP_Hourglass": ["FactionUS", "FactionRUS"],
    "MP_LongHaul": ["FactionUS", "FactionRUS"],
    "MP_TheWall": ["FactionUS", "FactionRUS"],
    "MP_Irreversible": ["FactionUS", "FactionRUS"],
    "MP_LightHouse": ["FactionRUS", "FactionUS"],
    "MP_LightsOut": ["FactionUS", "FactionRUS"],
    "MP_Boulder": ["FactionUS", "FactionRUS"],
    "MP_Scarred": ["FactionUS", "FactionRUS"],
    "MP_Salem": ["FactionUS", "FactionRUS"],
    "MP_Cassava": ["FactionUS", "FactionRUS"],
    "MP_Stadium": ["FactionUS", "FactionRUS"],
    "MP_IwoJima": ["FactionUS", "FactionRUS"],
}
MAP_PICTURES = {
    "MP_Harbor": "https://cdn.gametools.network/maps/bf2042/Map_Art_BFBC2_AH_L-60b49760.png",
    "MP_LightHouse": "https://cdn.gametools.network/maps/bf2042/Map_Art_BFBC2_VP_L-600385e2.png",
    "MP_Frost": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF1942_BB_L-2559980c.png",
    "MP_Oasis": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF1942_EA_L-d7d3186f.png",
    "MP_Rural": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF3_CB_L-df505a1f.png",
    "MP_Port": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF3_NC_L-41a1e94f.png",
    "MP_Orbital": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_ORB_L-d15a84f6.png",
    "MP_Hourglass": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_HG_L-9535453c.png",
    "MP_Kaleidoscope": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_KS_L-6ba702e0.png",
    "MP_Irreversible": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_IRR_L-19eeef98.png",
    "MP_Discarded": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_DIS_L-764694ca.png",
    "MP_LongHaul": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_LH_L-22b32735.png",
    "MP_TheWall": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_TW_L-ad09f15f.png",
    "MP_Ridge": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_RID_L-66e845a2.png",
    "MP_Drained": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_DRA_L-d75f98a0.png",
    "MP_LightsOut": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_LO-ce4a8588.jpg",
    "MP_Boulder": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_BOL-215cc9e7.jpg",
    "MP_Scarred": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_SC-91339cd1.jpg",
    "MP_Salem": "https://cdn.gametools.network/maps/bf2042/Map_Image_BF2042_SA-d546e7ce.png",
    "MP_Cassava": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_CA-9320122e.jpg",
    "MP_Stadium": "https://cdn.gametools.network/maps/bf2042/StadiumVista01_600-ee33c77a.jpg",
    "MP_IwoJima": "https://cdn.gametools.network/maps/bf2042/MP_IwoJima_LoadingScreen-600x240-426bef08.png",
}
MODES = {
    "Breakthrough": "Breakthrough Large",
    "BreakthroughSmall": "Breakthrough",
    "ConquestSmall": "Conquest",
    "ModBuilderCustom": "Custom",
    "Rush": "Rush",
    "Conquest": "Conquest large",
}
PLATFORM = {
    0: "unknown",
    1: "pc",
    2: "ps4",
    3: "xboxone",
    4: "ps5",
    5: "xboxseries",
}
PLATFORM_FESL = {
    0: "pc",
    1: "pc",
    2: "ps4",
    3: "xboxone",
    4: "ps4",
    5: "xboxone",
}
PLATFORM_REVERSE = {
    "unknown": 0,
    "pc": 1,
    "ps4": 2,
    "xboxone": 3,
    "ps5": 4,
    "xboxseries": 5,
}
REGIONS = {
    "aws-bah": "Asia",
    "aws-bom": "Asia",
    "aws-brz": "South America",
    "aws-cdg": "Europe",
    "aws-cmh": "South America",
    "aws-cpt": "Africa",
    "aws-dub": "Europe",
    "aws-fra": "Europe",
    "aws-hkg": "Asia",
    "aws-iad": "North America",
    "aws-icn": "South America",
    "aws-lhr": "Europe",
    "aws-nrt": "Asia",
    "aws-pdx": "North America",
    "aws-sin": "Asia",
    "aws-sjc": "North America",
    "aws-syd": "Oceania",
}
REGIONSLIST = {
    "asia": ["aws-bah", "aws-bom", "aws-hkg", "aws-nrt", "aws-sin"],
    "nam": ["aws-iad", "aws-pdx", "aws-sjc"],
    "sam": ["aws-brz", "aws-cmh", "aws-icn"],
    "eu": ["aws-cdg", "aws-dub", "aws-fra", "aws-lhr"],
    "afr": ["aws-cpt"],
    "oc": ["aws-syd"],
    "all": [
        "aws-bah",
        "aws-bom",
        "aws-hkg",
        "aws-nrt",
        "aws-sin",
        "aws-iad",
        "aws-pdx",
        "aws-sjc",
        "aws-brz",
        "aws-cmh",
        "aws-icn",
        "aws-cdg",
        "aws-dub",
        "aws-fra",
        "aws-lhr",
        "aws-cpt",
        "aws-syd",
    ],
}
SHORT_REGIONS = {
    "aws-bah": "asia",
    "aws-bom": "asia",
    "aws-brz": "sam",
    "aws-cdg": "eu",
    "aws-cmh": "sam",
    "aws-cpt": "afr",
    "aws-dub": "eu",
    "aws-fra": "eu",
    "aws-hkg": "asia",
    "aws-iad": "nam",
    "aws-icn": "sam",
    "aws-lhr": "eu",
    "aws-nrt": "asia",
    "aws-pdx": "nam",
    "aws-sin": "asia",
    "aws-sjc": "nam",
    "aws-syd": "oc",
}
SMALLMODES = {
    "Breakthrough": "BT",
    "BreakthroughSmall": "BS",
    "ConquestSmall": "CQ",
    "ModBuilderCustom": "CM",
    "Rush": "RS",
    "Conquest": "CL",
}
STATS_PLATFORM = {0: "pc", 1: "xboxone", 2: "ps4"}
STATS_PLATFORM_REVERSE = {
    "pc": 0,
    "xboxone": 1,
    "ps4": 2,
    "xboxseries": 1,
    "ps5": 2,
    "xbox": 1,
    "psn": 2,
}
STAT_GAMEMODE = {
    "bt": {
        "gamemodeName": "Breakthrough Large",
        "image": "https://portal.battlefield.com/4141963/assets/icons/Icon_Breakthrough.svg",
    },
    "btsmall": {
        "gamemodeName": "Breakthrough",
        "image": "https://portal.battlefield.com/4141963/assets/icons/Icon_Breakthrough.svg",
    },
    "cq": {
        "gamemodeName": "Conquest Large",
        "image": "https://portal.battlefield.com/3396060/assets/icons/Icon_Conquest.svg",
    },
    "cqsmall": {
        "gamemodeName": "Conquest",
        "image": "https://portal.battlefield.com/3396060/assets/icons/Icon_Conquest_Small.svg",
    },
    "modbuilder": {
        "gamemodeName": "Custom",
        "image": "https://portal.battlefield.com/3396060/assets/icons/custom_wrench_hammer.svg",
    },
    "rush": {
        "gamemodeName": "Rush",
        "image": "https://portal.battlefield.com/3396060/assets/icons/Icon_Rush.svg",
    },
    "hz": {
        "gamemodeName": "Hazard Zone Large",
        "image": "https://cdn.gametools.network/hazard-zone.jpg",
    },
    "hzsmall": {
        "gamemodeName": "Hazard Zone",
        "image": "https://cdn.gametools.network/hazard-zone.jpg",
    },
}
STAT_MAPS = {
    "kin_renewal": {
        "mapName": "Renewal",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_TW_L-ad09f15f.png",
    },
    "kin_orbital": {
        "mapName": "Orbital",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_ORB_L-d15a84f6.png",
    },
    "kin_manifest": {
        "mapName": "Manifest",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_LH_L-22b32735.png",
    },
    "kin_discarded": {
        "mapName": "Discarded",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_DIS_L-764694ca.png",
    },
    "kin_kaleidescope": {
        "mapName": "Kaleidescope",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_KS_L-6ba702e0.png",
    },
    "kin_breakaway": {
        "mapName": "Breakaway",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_IRR_L-19eeef98.png",
    },
    "kin_hourglass": {
        "mapName": "Hourglass",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_HG_L-9535453c.png",
    },
    "kin_lightsout": {
        "mapName": "Spearhead",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_LO-ce4a8588.jpg",
    },
    "kin_exposure": {
        "mapName": "Exposure",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_RID_L-66e845a2.png",
    },
    "kin_drained": {
        "mapName": "Stranded",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_DRA_L-d75f98a0.png",
    },
    "mica_noshahr": {
        "mapName": "Noshahr Canals",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF3_NC_L-41a1e94f.png",
    },
    "mica_caspian": {
        "mapName": "Caspian Border",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF3_CB_L-df505a1f.png",
    },
    "mica_valparaiso": {
        "mapName": "Valparaiso",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BFBC2_VP_L-600385e2.png",
    },
    "mica_aricaharbor": {
        "mapName": "Arica Harbor",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BFBC2_AH_L-60b49760.png",
    },
    "mica_bulge": {
        "mapName": "Battle of the Bulge",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF1942_BB_L-2559980c.png",
    },
    "mica_elalamein": {
        "mapName": "El Alamein",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF1942_EA_L-d7d3186f.png",
    },
    "kin_flashpoint": {
        "mapName": "Flashpoint",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_BOL-215cc9e7.jpg",
    },
    "kin_reclaimed": {
        "mapName": "Reclaimed",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Art_BF2042_SC-91339cd1.jpg",
    },
    "kin_salem": {
        "mapName": "Redacted",
        "image": "https://cdn.gametools.network/maps/bf2042/Map_Image_BF2042_SA-d546e7ce.png",
    },
}
TO_GAME_MAPS = {
    "arica harbor": "MP_Harbor",
    "valparaiso": "MP_LightHouse",
    "battle of the bulge": "MP_Frost",
    "el alamein": "MP_Oasis",
    "caspian border": "MP_Rural",
    "noshahr canals": "MP_Port",
    "orbital": "MP_Orbital",
    "hourglass": "MP_Hourglass",
    "kaleidoscope": "MP_Kaleidoscope",
    "breakaway": "MP_Irreversible",
    "discarded": "MP_Discarded",
    "manifest": "MP_LongHaul",
    "renewal": "MP_TheWall",
    "exposure": "MP_Ridge",
    "stranded": "MP_Drained",
    "spearhead": "MP_LightsOut",
    "flashpoint": "MP_Boulder",
    "reclaimed": "MP_Scarred",
    "redacted": "MP_Salem",
    "haven": "MP_Cassava",
    "stadium": "MP_Stadium",
    "iwo jima": "MP_IwoJima",
}
TO_GAME_MODES = {
    "breakthrough large": "Breakthrough",
    "breakthrough": "BreakthroughSmall",
    "conquest": "ConquestSmall",
    "custom": "ModBuilderCustom",
    "rush": "Rush",
    "conquest large": "Conquest",
}
VEHICLES = {
    "air_heli_nightbird": {
        "type": "Helicopter",
        "vehicleName": "MD540 Nightbird",
        "image": "https://cdn.gametools.network/vehicles/bf2042/LittleBird-54f140e1.png",
    },
    "air_plane_f35e": {
        "type": "Plane",
        "vehicleName": "F-35E Panther",
        "image": "https://cdn.gametools.network/vehicles/bf2042/F35-6e81cc1d.png",
    },
    "sur_land_bolte": {
        "type": "Land",
        "vehicleName": "M5C Bolte",
        "image": "https://cdn.gametools.network/vehicles/bf2042/FNSSZAHA-673ae567.png",
    },
    "air_heli_apache": {
        "type": "Helicopter",
        "vehicleName": "AH-64GX Apache Warchief",
        "image": "https://cdn.gametools.network/vehicles/bf2042/Apache-6fd7d17c.png",
    },
    "air_heli_condor": {
        "type": "Helicopter",
        "vehicleName": "MV-38 Condor",
        "image": "https://cdn.gametools.network/vehicles/bf2042/Osprey-dc88f56b.png",
    },
    "sur_land_wildcat": {
        "type": "Land",
        "vehicleName": "EBAA Wildcat",
        "image": "https://cdn.gametools.network/vehicles/bf2042/Jaguar-00976ef9.png",
    },
    "sur_land_m1a5": {
        "type": "Land",
        "vehicleName": "M1A5",
        "image": "https://cdn.gametools.network/vehicles/bf2042/Abrams-666376b1.png",
    },
    "air_heli_huron": {
        "type": "Helicopter",
        "vehicleName": "RAH-68 Huron",
        "image": "https://cdn.gametools.network/vehicles/bf2042/Shoshone-770d49a8.png",
    },
    "sur_land_latv4": {
        "type": "Land",
        "vehicleName": "LATV4 Recon",
        "image": "https://cdn.gametools.network/vehicles/bf2042/HDTStorm-508855e2.png",
    },
    "air_heli_ah6j": {
        "type": "Helicopter",
        "vehicleName": "AH-6J Little Bird",
        "image": "https://cdn.gametools.network/vehicles/bf2042/ALX__AH-6_LittleBird-020fc28b.png",
    },
    "sur_amph_lcaa": {
        "type": "Amphibious",
        "vehicleName": "LCAA Hovercraft",
        "image": "https://cdn.gametools.network/vehicles/bf2042/HoverCraft-3b2863af.png",
    },
    "sur_land_crab": {
        "type": "Land",
        "vehicleName": "EBLC-Ram",
        "image": "https://cdn.gametools.network/vehicles/bf2042/CallIn_PanhardCrab-defd9d4c.png",
    },
    "sur_amph_mav": {
        "type": "Amphibious",
        "vehicleName": "MAV",
        "image": "https://cdn.gametools.network/vehicles/bf2042/Ripsaw-5d8b6a01.png",
    },
    "sur_land_emkv90": {
        "type": "Land",
        "vehicleName": "EMKV90-TOR",
        "image": "https://cdn.gametools.network/vehicles/bf2042/VEH_Icon_CV90_Tank-f5cd269c.png",
    },
    "air_heli_uh60": {
        "type": "Helicopter",
        "vehicleName": "UH-60",
        "image": "https://cdn.gametools.network/vehicles/bf2042/RUM__UH-60-85e1dc03.png",
    },
    "sur_amph_lavad": {
        "type": "Land",
        "vehicleName": "LAV-AD",
        "image": "https://cdn.gametools.network/vehicles/bf2042/ALX__LAV-AD-81ad7f0b.png",
    },
    "sur_land_m1a2": {
        "type": "Land",
        "vehicleName": "M1A2",
        "image": "https://cdn.gametools.network/vehicles/bf2042/ALX__M1A2_Abrams-c5c29b15.png",
    },
    "sur_land_m1114": {
        "type": "Land",
        "vehicleName": "M1114",
        "image": "https://cdn.gametools.network/vehicles/bf2042/ALX__HMMVW-3f72cce0.png",
    },
    "sur_land_m1161itv": {
        "type": "Land",
        "vehicleName": "M1161 ITV",
        "image": "https://cdn.gametools.network/vehicles/bf2042/ALX__Growler_ITV-495b7d78.png",
    },
    "sur_amph_lav25": {
        "type": "Land",
        "vehicleName": "LAV-25",
        "image": "https://cdn.gametools.network/vehicles/bf2042/ALX__LAV-25-5e26ccd6.png",
    },
    "air_heli_ah64": {
        "type": "Helicopter",
        "vehicleName": "AH-64 Apache",
        "image": "https://cdn.gametools.network/vehicles/bf2042/ALX__AH64E_Apache-95ea5891.png",
    },
    "sur_amph_amtrac": {
        "type": "Land",
        "vehicleName": "AAV-7A1 AMTRAC",
        "image": "https://cdn.gametools.network/vehicles/bf2042/ALX__AAV-7A1_AMTRAC-b0d97585.png",
    },
    "sur_amph_m3a3": {
        "type": "Land",
        "vehicleName": "M3A3 Bradley",
        "image": "https://cdn.gametools.network/vehicles/bf2042/RUM__M3A3-Bradley-c62fcd8a.png",
    },
    "sur_land_m4sherm": {
        "type": "Land",
        "vehicleName": "M4 Sherman",
        "image": "https://cdn.gametools.network/vehicles/bf2042/GRA__M4-Sherman-eadb90c6.png",
    },
    "sur_land_willys": {
        "type": "Land",
        "vehicleName": "Willys MB",
        "image": "https://cdn.gametools.network/vehicles/bf2042/GRA__WillysJeep-f813f4c0.png",
    },
    "sur_land_m10w": {
        "type": "Land",
        "vehicleName": "M10 Wolverine",
        "image": "https://cdn.gametools.network/vehicles/bf2042/GRA__M10Wolverine-617e2e5f.png",
    },
    "air_plane_spitfire": {
        "type": "Plane",
        "vehicleName": "Spitfire",
        "image": "https://cdn.gametools.network/vehicles/bf2042/GRA__SpitfirePlane_MX-Va-45ed6b74.png",
    },
    "air_plane_b17": {
        "type": "Plane",
        "vehicleName": "B-17 Bomber",
        "image": "https://cdn.gametools.network/vehicles/bf2042/GRA__B-17-Bomber-a32375cc.png",
    },
    "sur_land_m3ht": {
        "type": "Land",
        "vehicleName": "M3 Halftrack",
        "image": "https://cdn.gametools.network/vehicles/bf2042/GRA__M3-e8eabeb4.png",
    },
    "air_plane_fa18": {
        "type": "Plane",
        "vehicleName": "F/A-18",
        "image": "https://cdn.gametools.network/vehicles/bf2042/ALX__FA-18_Hornet-fbaeedb9.png",
    },
    "air_plane_a10": {
        "type": "Plane",
        "vehicleName": "A-10 Warthog",
        "image": "https://cdn.gametools.network/vehicles/bf2042/ALX__A-10_Thunderbolt-II-8fd06332.png",
    },
    "air_plane_su57": {
        "type": "Plane",
        "vehicleName": "SU-57 FELON",
        "image": "https://cdn.gametools.network/vehicles/bf2042/SU57-8c465ace.png",
    },
    "air_heli_mi240": {
        "type": "Helicopter",
        "vehicleName": "Mi-240 Super Hind",
        "image": "https://cdn.gametools.network/vehicles/bf2042/Mi24-f2f92880.png",
    },
    "air_heli_hannibal": {
        "type": "Helicopter",
        "vehicleName": "YG-99 Hannibal",
        "image": "https://cdn.gametools.network/vehicles/bf2042/Hannibal-3e287b57.png",
    },
    "air_plane_stuka": {
        "type": "Plane",
        "vehicleName": "Ju-87 Stuka",
        "image": "https://cdn.gametools.network/vehicles/bf2042/GRA__Stuka_JU-78_B-1-356f2845.png",
    },
    "air_plane_bf109": {
        "type": "Plane",
        "vehicleName": "Bf 109",
        "image": "https://cdn.gametools.network/vehicles/bf2042/GRA__BF109-388ac401.png",
    },
    "sur_amph_bmp2": {
        "type": "Amphibious",
        "vehicleName": "BMP-2",
        "image": "https://cdn.gametools.network/vehicles/bf2042/ALX__BMP-2-8ce5888b.png",
    },
    "air_plane_su35bm": {
        "type": "Plane",
        "vehicleName": "Su-35BM",
        "image": "https://cdn.gametools.network/vehicles/bf2042/ALX__SU-35BM-275a430d.png",
    },
    "sur_land_tigeri": {
        "type": "Land",
        "vehicleName": "Tiger I",
        "image": "https://cdn.gametools.network/vehicles/bf2042/GRA__tiger-74a6f11e.png",
    },
    "sur_land_vdv": {
        "type": "Land",
        "vehicleName": "VDV Buggy",
        "image": "https://cdn.gametools.network/vehicles/bf2042/ALX__VDV_Buggy-24a34e8f.png",
    },
    "sur_land_kfzht": {
        "type": "Land",
        "vehicleName": "Sd. Kfz 251 Halftrack",
        "image": "https://cdn.gametools.network/vehicles/bf2042/GRA__HanomagHalftrack-27a8128a.png",
    },
    "sur_land_kubel": {
        "type": "Land",
        "vehicleName": "Kubelwagen",
        "image": "https://cdn.gametools.network/vehicles/bf2042/GRA__KubelwagenTransport-536c4c14.png",
    },
    "sur_land_tunguska": {
        "type": "Land",
        "vehicleName": "9K22 Tunguska-M",
        "image": "https://cdn.gametools.network/vehicles/bf2042/ALX__9K22_Tunguska-26412514.png",
    },
    "sur_land_t90": {
        "type": "Land",
        "vehicleName": "T-90",
        "image": "https://cdn.gametools.network/vehicles/bf2042/RUM__T90-8a6f6d04.png",
    },
    "sur_amph_vodnik": {
        "type": "Amphibious",
        "vehicleName": "3937 Vodnik",
        "image": "https://cdn.gametools.network/vehicles/bf2042/ALX__GAZ-3937_Vodnik-70c94108.png",
    },
    "air_heli_z11w": {
        "type": "Helicopter",
        "vehicleName": "Z-11W",
        "image": "https://cdn.gametools.network/vehicles/bf2042/ALX__Z-11W_WZ-11-ab0849ef.png",
    },
    "air_heli_mi28": {
        "type": "Helicopter",
        "vehicleName": "Mi-28 Havoc",
        "image": "https://cdn.gametools.network/vehicles/bf2042/ALX__Mi-28_Havoc-0d683246.png",
    },
    "sur_land_panziv": {
        "type": "Land",
        "vehicleName": "Panzer IV",
        "image": "https://cdn.gametools.network/vehicles/bf2042/GRA__Panzer-IV-3721bd56.png",
    },
    "air_heli_ka52": {
        "type": "Helicopter",
        "vehicleName": "KA-520 Super Hokum",
        "image": "https://cdn.gametools.network/vehicles/bf2042/Alligator-8db4b043.png",
    },
    "sur_land_t28": {
        "type": "Land",
        "vehicleName": "T28",
        "image": "https://cdn.gametools.network/vehicles/bf2042/T14Armata-8890e549.png",
    },
    "sur_land_brawler": {
        "type": "Land",
        "vehicleName": "CAV-BRAWLER",
        "image": "https://cdn.gametools.network/vehicles/bf2042/VEH_Icon_ArmoredCar_Patria-17d03f44.png",
    },
    "air_plane_su25": {
        "type": "Plane",
        "vehicleName": "Su-25TM Frogfoot",
        "image": "https://cdn.gametools.network/vehicles/bf2042/RUM__SU-25TM_Frogfoot-cba9e798.png",
    },
    "air_heli_mi24": {
        "type": "Helicopter",
        "vehicleName": "Mi-24 Hind",
        "image": "https://cdn.gametools.network/vehicles/bf2042/RUM__Mi-24SuperHind-faf17714.png",
    },
    "sur_land_bmd3": {
        "type": "Land",
        "vehicleName": "BMD-3",
        "image": "https://cdn.gametools.network/vehicles/bf2042/RUM__BMD-3_Bakhcha-86f10fe1.png",
    },
    "air_heli_pondhawk": {
        "type": "Land",
        "vehicleName": "YUV-2 Pondhawk",
        "image": "https://cdn.gametools.network/vehicles/bf2042/VEH_Icon_Transport_Hoverbike-d6be6447.png",
    },
    "sur_stat_cram": {
        "type": "Stationary",
        "vehicleName": "Centurion C-RAM",
        "image": "",
    },
    "sur_stat_tow": {
        "type": "Stationary",
        "vehicleName": "M220 TOW Launcher",
        "image": "",
    },
    "sur_stat_kornet": {
        "type": "Stationary",
        "vehicleName": "9M133 Kornet",
        "image": "",
    },
    "sur_world_quadbike": {
        "type": "In-World",
        "vehicleName": "Polaris Sportsman",
        "image": "",
    },
    "sur_world_rzrbuggy": {
        "type": "In-World",
        "vehicleName": "Polaris RZR",
        "image": "",
    },
    "sur_world_tuktuk": {"type": "In-World", "vehicleName": "Tuk-Tuk", "image": ""},
    "sur_world_4x4": {"type": "In-World", "vehicleName": "4x4 Utility", "image": ""},
    "air_heli_uav1": {"type": "Helicopter", "vehicleName": "UAV-1", "image": ""},
    "sur_stat_flak38": {"type": "Stationary", "vehicleName": "Flak 38", "image": ""},
    "sur_stat_hmg": {"type": "Stationary", "vehicleName": "HMG", "image": ""},
    "sur_stat_kord": {"type": "Stationary", "vehicleName": "KORD HMG", "image": ""},
    "sur_world_quad_bc2": {
        "type": "Quadbike",
        "vehicleName": "Quadbike - BC2",
        "image": "",
    },
    "sur_world_rhib_bf3": {"type": "RHIB", "vehicleName": "RHIB - BF3", "image": ""},
    "sur_stat_40mmaa": {"type": "Stationary", "vehicleName": "40mm AA", "image": ""},
}
VEHICLE_GROUPS = {
    "air": {"groupName": "Air"},
    "air_heli": {"groupName": "Helicopter"},
    "air_plane": {"groupName": "Plane"},
    "sur": {"groupName": "Sur"},
    "sur_world": {"groupName": "In-World"},
    "sur_land": {"groupName": "Land"},
    "sur_amph": {"groupName": "Amphibious"},
}
WEAPONS = {
    "pri_pdw_pp29": {
        "type": "PDW",
        "weaponName": "PP-29",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_PP19-00f2ea5c.png",
    },
    "pri_pdw_mp9": {
        "type": "PDW",
        "weaponName": "MP9",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_MP9-6aa46b38.png",
    },
    "pri_pdw_k30": {
        "type": "PDW",
        "weaponName": "K30",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_kriss-41643e7c.png",
    },
    "pri_pdw_pbx45": {
        "type": "PDW",
        "weaponName": "PBX-45",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_SMG45-e28be5b5.png",
    },
    "pri_ba_sws10": {
        "type": "Bolt Action",
        "weaponName": "SWS-10",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_TRG_M10-ebbdfe15.png",
    },
    "pri_ba_ntw50": {
        "type": "Bolt Action",
        "weaponName": "NTW-50",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_NTW-20-76c5dc49.png",
    },
    "pri_ba_dxr1": {
        "type": "Bolt Action",
        "weaponName": "DXR-1",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_DSR1-c3413554.png",
    },
    "pri_ar_am40": {
        "type": "Assault Rifles",
        "weaponName": "AM40",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_AM17-32eab750.png",
    },
    "pri_dmr_vcar": {
        "type": "DMR",
        "weaponName": "VCAR",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_keltec-c9ee5698.png",
    },
    "pri_misc_cb_ghstmkr": {
        "type": "Crossbows",
        "weaponName": "Ghostmaker R10",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_Cobra-6ca88503.png",
    },
    "pri_dmr_vss": {
        "type": "DMR",
        "weaponName": "BSV-M",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_VSS-d4610752.png",
    },
    "sa_g57": {
        "type": "Sidearm",
        "weaponName": "G57",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_glock-237f6b21.png",
    },
    "sa_m44": {
        "type": "Sidearm",
        "weaponName": "M44",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_Taurus-4ab7a57b.png",
    },
    "pri_misc_sg_mcs880": {
        "type": "Shotguns",
        "weaponName": "MCS-880",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_remington-a054d3fb.png",
    },
    "pri_misc_sg_12mauto": {
        "type": "Shotguns",
        "weaponName": "12M Auto",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_saiga-aa338425.png",
    },
    "sa_mp28": {
        "type": "Sidearm",
        "weaponName": "MP28",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_MP17-dce205e4.png",
    },
    "pri_misc_rg_mk4": {
        "type": "Railguns",
        "weaponName": "Rorsch Mk-4",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_RailgunRifle-be9d51b7.png",
    },
    "pri_lmg_avancys": {
        "type": "LMG",
        "weaponName": "Avancys",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_Avancys-5cf323f7.png",
    },
    "pri_lmg_pkpbp": {
        "type": "LMG",
        "weaponName": "PKP-BP",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_Pecheng-69395d9b.png",
    },
    "pri_lmg_lcmg": {
        "type": "LMG",
        "weaponName": "LCMG",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_LAMG-74966966.png",
    },
    "pri_ba_m24": {
        "type": "Bolt Action",
        "weaponName": "M24 Sniper",
        "image": "https://cdn.gametools.network/weapons/bf2042/RUM__weapon_default_M24Sniper-d2b3578f.png",
    },
    "pri_ar_m16a3": {
        "type": "Assault Rifles",
        "weaponName": "M16A3",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_M16A3-13468163.png",
    },
    "pri_misc_lac_gvt4570": {
        "type": "Lever-Action Carbines",
        "weaponName": "GVT 45-70",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_marlin-2b091f63.png",
    },
    "pri_pdw_p90": {
        "type": "PDW",
        "weaponName": "P90",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_P90-833ca028.png",
    },
    "sa_pf51": {
        "type": "Sidearm",
        "weaponName": "PF51",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_PF51-569f3708.png",
    },
    "pri_ar_ac42": {
        "type": "Assault Rifles",
        "weaponName": "AC-42",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_NBR-04c26c82.png",
    },
    "pri_ar_ak24": {
        "type": "Assault Rifles",
        "weaponName": "AK-24",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_AK12-bc93fb15.png",
    },
    "pri_ar_m5a3": {
        "type": "Assault Rifles",
        "weaponName": "M5A3",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_SLX-71737176.png",
    },
    "pri_ar_sfarm": {
        "type": "Assault Rifles",
        "weaponName": "SFAR-M GL",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_SCARMK17-fbe5ac70.png",
    },
    "pri_ba_k98s": {
        "type": "Bolt Action",
        "weaponName": "K98 Sniper",
        "image": "https://cdn.gametools.network/weapons/bf2042/GRA__Weapons_default_Kar98K-Sniper-78649ce0.png",
    },
    "pri_dmr_dm7": {
        "type": "DMR",
        "weaponName": "DM7",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_DDM4-90304a0b.png",
    },
    "pri_misc_carb_aks": {
        "type": "Assault Rifles",
        "weaponName": "AKS-74u",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_AKS74u-839ebbac.png",
    },
    "pri_lmg_m240b": {
        "type": "LMG",
        "weaponName": "M240B",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_M240B-436660f8.png",
    },
    "sa_rex": {
        "type": "Sidearm",
        "weaponName": "MP412 REX",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_MP-412REX-bdaa3806.png",
    },
    "sa_mp443": {
        "type": "Sidearm",
        "weaponName": "MP443",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_MP443-5cb9a041.png",
    },
    "sa_m93r": {
        "type": "Sidearm",
        "weaponName": "M93R",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_M93R-dbc63f6c.png",
    },
    "pri_misc_sg_spas12": {
        "type": "Shotguns",
        "weaponName": "SPAS-12",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_SPAS12-d9391052.png",
    },
    "pri_lmg_m60e4": {
        "type": "LMG",
        "weaponName": "M60E4",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_M60E4-63fe87c7.png",
    },
    "pri_dmr_m39": {
        "type": "DMR",
        "weaponName": "M39 EMR",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_M39EMR-5abaffd4.png",
    },
    "pri_misc_carb_a91": {
        "type": "Carbines",
        "weaponName": "A-91",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_A91-884f4c20.png",
    },
    "pri_dmr_svd": {
        "type": "DMR",
        "weaponName": "SVD",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_SVD-5eb4de27.png",
    },
    "pri_misc_carb_acwr": {
        "type": "Carbines",
        "weaponName": "ACW-R",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_ACW-R-d7872974.png",
    },
    "pri_ba_m98b": {
        "type": "Bolt Action",
        "weaponName": "M98B",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_M98B-7afe78dc.png",
    },
    "pri_ar_m416": {
        "type": "Assault Rifles",
        "weaponName": "M416",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_M416-8f4cd9da.png",
    },
    "pri_misc_carb_scarh": {
        "type": "Assault Rifles",
        "weaponName": "SCAR-H",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_SCAR-H-a1658fa6.png",
    },
    "pri_ar_aek": {
        "type": "Assault Rifles",
        "weaponName": "AEK-971",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_AEK-971_BF3-db5476e3.png",
    },
    "sa_nvkp125": {
        "type": "",
        "weaponName": "NVK-P125",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_BullpupPistol-2371a03c.png",
    },
    "pri_misc_sg_nvks22": {
        "type": "Shotguns",
        "weaponName": "NVK-S22",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_CB12-e0c8db2a.png",
    },
    "pri_dmr_svk": {
        "type": "DMR",
        "weaponName": "SVK",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_chukavin-1f41118c.png",
    },
    "pri_pdw_xm8c": {
        "type": "PDW",
        "weaponName": "XM8 Compact",
        "image": "https://cdn.gametools.network/weapons/bf2042/RUM__weapon_default_XM8-C-48f3a3fd.png",
    },
    "pri_ar_stg": {
        "type": "Assault Rifle",
        "weaponName": "StG 44",
        "image": "https://cdn.gametools.network/weapons/bf2042/GRA__Weapons_default_STG44-050b204d.png",
    },
    "pri_ar_m2carbine": {
        "type": "Assault Rifle",
        "weaponName": "M2 Carbine",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_M2Carbine-59b11087.png",
    },
    "pri_pdw_pp2000": {
        "type": "PDW",
        "weaponName": "PP-2000",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_PP2000-4cc58b87.png",
    },
    "sa_m1911": {
        "type": "Sidearm",
        "weaponName": "M1911",
        "image": "https://cdn.gametools.network/weapons/bf2042/RUM__weapon_default_M1911-e4ea2148.png",
    },
    "pri_misc_sg_dao12": {
        "type": "Shotguns",
        "weaponName": "DAO-12",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_DAO-12-eb920cae.png",
    },
    "pri_lmg_t88": {
        "type": "LMG",
        "weaponName": "Type 88",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_Type-88-f0f49ebd.png",
    },
    "pri_lmg_m249": {
        "type": "LMG",
        "weaponName": "M249 SAW",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_M249_SAW_BF3-c07c0a9b.png",
    },
    "pri_lmg_xm8lmg": {
        "type": "LMG",
        "weaponName": "XM8 LMG",
        "image": "https://cdn.gametools.network/weapons/bf2042/RUM__weapon_default_XM8-LMG-ba39a043.png",
    },
    "pri_ba_gol": {
        "type": "Bolt Action",
        "weaponName": "GOL Sniper Magnum",
        "image": "https://cdn.gametools.network/weapons/bf2042/RUM__weapon_default_GOL-35dfe25f.png",
    },
    "pri_lmg_m60": {
        "type": "LMG",
        "weaponName": "M60",
        "image": "https://cdn.gametools.network/weapons/bf2042/RUM__weapon_default_M60-d9864992.png",
    },
    "pri_dmr_garand": {
        "type": "DMR",
        "weaponName": "M1 Garand",
        "image": "https://cdn.gametools.network/weapons/bf2042/RUM__weapon_default_M1Garand-fe29246e.png",
    },
    "pri_ba_m95": {
        "type": "Bolt Action",
        "weaponName": "M95 Sniper",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_M95-092cdbf6.png",
    },
    "pri_ar_xm8": {
        "type": "Assault Rifles",
        "weaponName": "XM8 Prototype",
        "image": "https://cdn.gametools.network/weapons/bf2042/RUM__weapon_default_XM8-0ed8134e.png",
    },
    "pri_pdw_mp40": {
        "type": "SMG-PDW",
        "weaponName": "MP 40",
        "image": "https://cdn.gametools.network/weapons/bf2042/GRA__Weapons_default_MP40-458414da.png",
    },
    "sa_p38": {
        "type": "Sidearm",
        "weaponName": "Walther P38",
        "image": "https://cdn.gametools.network/weapons/bf2042/GRA__Weapons_default_WaltherP38-28dd9754.png",
    },
    "pri_lmg_bar": {
        "type": "LMG",
        "weaponName": "BAR 1918",
        "image": "https://cdn.gametools.network/weapons/bf2042/GRA__Weapons_default_BAR1918_A2-38a25aed.png",
    },
    "pri_lmg_bren": {
        "type": "LMG",
        "weaponName": "Bren LMG",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_Bren-2f6ebe1f.png",
    },
    "pri_ar_an94": {
        "type": "Assault Rifles",
        "weaponName": "AN94",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_AN-94-9b8bea79.png",
    },
    "pri_ba_k98": {
        "type": "Bolt Action",
        "weaponName": "K98",
        "image": "https://cdn.gametools.network/weapons/bf2042/GRA__Weapons_default_Kar98K-dde47354.png",
    },
    "pri_ar_g3a3": {
        "type": "Assault Rifles",
        "weaponName": "G3A3",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_G3A3-3969e77d.png",
    },
    "pri_pdw_asval": {
        "type": "",
        "weaponName": "AS Val",
        "image": "https://cdn.gametools.network/weapons/bf2042/ALX__weapon_default_AS-Val-86b653d8.png",
    },
    "pri_dmr_garandsniper": {
        "type": "DMR",
        "weaponName": "M1 Garand Sniper",
        "image": "https://cdn.gametools.network/weapons/bf2042/RUM__weapon_default_M1Garand-fe29246e.png",
    },
    "pri_ar_m16a2": {
        "type": "Assault Rifles",
        "weaponName": "M16A2",
        "image": "https://cdn.gametools.network/weapons/bf2042/RUM__weapon_default_M16A2-a87f25c7.png",
    },
    "pri_ba_no4engineer": {
        "type": "Bolt Action",
        "weaponName": "No 4",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_LeeEnfield-No4-57cac005.png",
    },
    "pri_ba_no4": {
        "type": "Bolt Action",
        "weaponName": "No 4 Sniper",
        "image": "https://cdn.gametools.network/weapons/bf2042/GRA__Weapons_default_Sniper-No4-e2d380d5.png",
    },
    "pri_dmr_gewehrzf4": {
        "type": "DMR",
        "weaponName": "Gewerhr 43 ZF4",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_Gewehr43-ZF4-aeb3e6b8.png",
    },
    "pri_dmr_gewehr": {
        "type": "DMR",
        "weaponName": "Gewerhr 43",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_Gewehr43-37bf9ea4.png",
    },
    "pri_pdw_tommy": {
        "type": "SMG-PDW",
        "weaponName": "Thompson",
        "image": "https://cdn.gametools.network/weapons/bf2042/RUM__weapon_default_M1A1Thompson-a625fdf8.png",
    },
    "pri_lmg_rpt31": {
        "type": "LMG",
        "weaponName": "RPT-3",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_RPT-31-d4ec514a.png",
    },
    "pri_misc_carb_ac9": {
        "type": "SMG-PDW",
        "weaponName": "AC9",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_SMG45-e28be5b5.png",
    },
    "sa_super500": {
        "type": "Shotguns",
        "weaponName": "Super 500",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_SuperShorty-54bfa64f.png",
    },
    "pri_ar_rm68": {
        "type": "Assault Rifles",
        "weaponName": "RM68",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_LAMG-74966966.png",
    },
    "pri_pdw_mtar": {
        "type": "Assault Rifles",
        "weaponName": "MTAR-21",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_MTAR21-2e42c468.png",
    },
    "sa_mkvi": {
        "type": "Sidearm",
        "weaponName": "Mk VI Revolver",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_MkVI_Revolver-9f5b0bfe.png",
    },
    "pri_lmg_rpk74m": {
        "type": "LMG",
        "weaponName": "RPK-74M",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_RPK-74M-d52bf4cd.png",
    },
    "pri_ba_xceed": {
        "type": "Bolt Action",
        "weaponName": "XCE BAR",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_TTS_Xceed-b66895b3.png",
    },
    "pri_ar_g36c": {
        "type": "Assault Rifles",
        "weaponName": "GEW-46",
        "image": "https://cdn.gametools.network/weapons/bf2042/gadget_default_G36C-9adbbaef.png",
    },
    "sa_eagle": {
        "type": "Sidearm",
        "weaponName": "BFP.50",
        "image": "https://cdn.gametools.network/weapons/bf2042/gadget_default_DesertEagle-5bb177e7.png",
    },
    "pri_misc_sg_12gauto": {
        "type": "Shotguns",
        "weaponName": "12G Automatic",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_BrowningA5-9ef7afe3.png",
    },
    "pri_pdw_sten": {
        "type": "SMG-PDW",
        "weaponName": "Sten",
        "image": "https://cdn.gametools.network/weapons/bf2042/weapon_default_Sten-e97e81c6.png",
    },
    "melee": {
        "type": "Melee",
        "weaponName": "Melee",
        "image": "https://cdn.gametools.network/gadgets/bf2042/GAD_ICO_Throwable_Knife-69b21450.png",
    },
    "pri_ar_g3": {
        "type": "Assault Rifles",
        "weaponName": "G3",
        "image": "https://cdn.gametools.network/weapons/bf2042/RUM__weapon_default_G3A3-d248f2d7.png",
    },
    "pri_ar_vhxd3": {
        "type": "Assault Rifles",
        "weaponName": "VHX D3",
        "image": "https://cdn.gametools.network/weapons/bf2042/wep_itemReveal_VHSD2-bdd794b7.png",
    },
    "pri_dmr_hk417": {
        "type": "DMR",
        "weaponName": "G428",
        "image": "https://cdn.gametools.network/weapons/bf2042/wep_itemReveal_G28-54b643da.png",
    },
    "sa_laugo": {
        "type": "Sidearm",
        "weaponName": "L9CZ",
        "image": "https://cdn.gametools.network/weapons/bf2042/LaugoAlien_RCE_Default-b729f65c.png",
    },
}
WEAPON_GROUPS = {
    "pri": {"groupName": "Primary"},
    "pri_ar": {"groupName": "Assault Rifles"},
    "pri_ba": {"groupName": "Bolt Action"},
    "pri_dmr": {"groupName": "DMR"},
    "pri_lmg": {"groupName": "LMG"},
    "pri_pdw": {"groupName": "PDW"},
    "pri_misc_sg": {"groupName": "Shotguns"},
    "pri_misc_rg": {"groupName": "Railguns"},
    "pri_misc_lac": {"groupName": "Lever-Action Carbines"},
    "pri_misc_cb": {"groupName": "Crossbows"},
    "sa": {"groupName": "Sidearm"},
    "pri_misc": {"groupName": "Miscellaneous"},
}
