MAPS = {
    "MP_Abandoned": "Zavod 311",
    "MP_Damage": "Lancang Dam",
    "MP_Flooded": "Flood Zone",
    "MP_Journey": "Golmud Railway",
    "MP_Naval": "Paracel Storm",
    "MP_Prison": "Operation Locker",
    "MP_Resort": "Hainan Resort",
    "MP_Siege": "Siege of Shanghai",
    "MP_TheDish": "Rogue Transmission",
    "MP_Tremors": "Dawnbreaker",
    "XP0_Caspian": "CASPIAN BORDER 2014",
    "XP0_Firestorm": "OPERATION FIRESTORM 2014",
    "XP0_Metro": "OPERATION METRO 2014",
    "XP0_Oman": "GULF OF OMAN 2014",
    "XP1_001": "SILK ROAD",
    "XP1_002": "ALTAI RANGE",
    "XP1_003": "GUILIN PEAKS",
    "XP1_004": "DRAGON PASS",
    "XP2_001": "LOST ISLANDS",
    "XP2_002": "NANSHA STRIKE",
    "XP2_003": "WAVE BREAKER",
    "XP2_004": "OPERATION MORTAR",
    "XP3_MarketPl": "PEARL MARKET",
    "XP3_Prpganda": "PROPAGANDA",
    "XP3_UrbanGdn": "LUMPHINI GARDEN",
    "XP3_WtrFront": "SUNKEN DRAGON",
    "XP4_Arctic": "OPERATION WHITEOUT",
    "XP4_SubBase": "HAMMERHEAD",
    "XP4_Titan": "HANGAR 21",
    "XP4_WlkrFtry": "GIANTS OF KARELIA",
    "XP5_Night_01": "ZAVOD: GRAVEYARD SHIFT",
    "XP6_CMP": "OPERATION OUTBREAK",
    "XP7_Valley": "DRAGON VALLEY 2015",
}
RANK_NAME = {
    "WARSAW_ID_P_RANK00_NAME": "RECRUIT",
    "WARSAW_ID_P_RANK01_NAME": "Private First Class",
    "WARSAW_ID_P_RANK02_NAME": "Private First Class II",
    "WARSAW_ID_P_RANK03_NAME": "Private First Class III",
    "WARSAW_ID_P_RANK04_NAME": "Private First Class IV",
    "WARSAW_ID_P_RANK05_NAME": "Private First Class V",
    "WARSAW_ID_P_RANK06_NAME": "Lance Corporal",
    "WARSAW_ID_P_RANK07_NAME": "Lance Corporal II",
    "WARSAW_ID_P_RANK08_NAME": "Lance Corporal III",
    "WARSAW_ID_P_RANK09_NAME": "Lance Corporal IV",
    "WARSAW_ID_P_RANK100_NAME": "Colonel",
    "WARSAW_ID_P_XP1_RANK101_NAME": "Colonel II",
    "WARSAW_ID_P_XP1_RANK102_NAME": "Colonel III",
    "WARSAW_ID_P_XP1_RANK103_NAME": "Colonel IV",
    "WARSAW_ID_P_XP1_RANK104_NAME": "Colonel V",
    "WARSAW_ID_P_XP1_RANK105_NAME": "Colonel VI",
    "WARSAW_ID_P_XP1_RANK106_NAME": "Colonel VII",
    "WARSAW_ID_P_XP1_RANK107_NAME": "Colonel VIII",
    "WARSAW_ID_P_XP1_RANK108_NAME": "Colonel IX",
    "WARSAW_ID_P_XP1_RANK109_NAME": "Colonel X",
    "WARSAW_ID_P_XP1_RANK110_NAME": "Brigadier General",
    "WARSAW_ID_P_RANK10_NAME": "Lance Corporal V",
    "WARSAW_ID_P_RANK111_NAME": "Brigadier General II",
    "WARSAW_ID_P_RANK112_NAME": "Brigadier General III",
    "WARSAW_ID_P_RANK113_NAME": "Brigadier General IV",
    "WARSAW_ID_P_RANK114_NAME": "Brigadier General V",
    "WARSAW_ID_P_RANK115_NAME": "Brigadier General VI",
    "WARSAW_ID_P_RANK116_NAME": "Brigadier General VII",
    "WARSAW_ID_P_RANK117_NAME": "Brigadier General VIII",
    "WARSAW_ID_P_RANK118_NAME": "Brigadier General IX",
    "WARSAW_ID_P_RANK119_NAME": "Brigadier General X",
    "WARSAW_ID_P_RANK11_NAME": "Corporal",
    "WARSAW_ID_P_RANK120_NAME": "Major General",
    "WARSAW_ID_P_RANK121_NAME": "Major General II",
    "WARSAW_ID_P_RANK122_NAME": "Major General III",
    "WARSAW_ID_P_RANK123_NAME": "Major General IV",
    "WARSAW_ID_P_RANK124_NAME": "Major General V",
    "WARSAW_ID_P_RANK125_NAME": "Major General VI",
    "WARSAW_ID_P_RANK126_NAME": "Major General VII",
    "WARSAW_ID_P_RANK127_NAME": "Major General VIII",
    "WARSAW_ID_P_RANK128_NAME": "Major General IX",
    "WARSAW_ID_P_RANK129_NAME": "Major General X",
    "WARSAW_ID_P_RANK12_NAME": "Corporal II",
    "WARSAW_ID_P_RANK130_NAME": "Lieutenant General",
    "WARSAW_ID_P_RANK131_NAME": "Lieutenant General II",
    "WARSAW_ID_P_RANK132_NAME": "Lieutenant General III",
    "WARSAW_ID_P_RANK133_NAME": "Lieutenant General IV",
    "WARSAW_ID_P_RANK134_NAME": "Lieutenant General V",
    "WARSAW_ID_P_RANK135_NAME": "Lieutenant General VI",
    "WARSAW_ID_P_RANK136_NAME": "Lieutenant General VII",
    "WARSAW_ID_P_RANK137_NAME": "Lieutenant General VIII",
    "WARSAW_ID_P_RANK138_NAME": "Lieutenant General IX",
    "WARSAW_ID_P_RANK139_NAME": "Lieutenant General X",
    "WARSAW_ID_P_RANK13_NAME": "Corporal III",
    "WARSAW_ID_P_RANK140_NAME": "General",
    "WARSAW_ID_P_RANK14_NAME": "Corporal IV",
    "WARSAW_ID_P_RANK15_NAME": "Corporal V",
    "WARSAW_ID_P_RANK16_NAME": "Sergeant",
    "WARSAW_ID_P_RANK17_NAME": "Sergeant II",
    "WARSAW_ID_P_RANK18_NAME": "Sergeant III",
    "WARSAW_ID_P_RANK19_NAME": "Sergeant IV",
    "WARSAW_ID_P_RANK20_NAME": "Sergeant V",
    "WARSAW_ID_P_RANK21_NAME": "Staff Sergeant",
    "WARSAW_ID_P_RANK22_NAME": "Staff Sergeant II",
    "WARSAW_ID_P_RANK23_NAME": "Staff Sergeant III",
    "WARSAW_ID_P_RANK24_NAME": "Staff Sergeant IV",
    "WARSAW_ID_P_RANK25_NAME": "Staff Sergeant V",
    "WARSAW_ID_P_RANK26_NAME": "Gunnery Sergeant",
    "WARSAW_ID_P_RANK27_NAME": "Gunnery Sergeant II",
    "WARSAW_ID_P_RANK28_NAME": "Gunnery Sergeant III",
    "WARSAW_ID_P_RANK29_NAME": "Gunnery Sergeant IV",
    "WARSAW_ID_P_RANK30_NAME": "Gunnery Sergeant V",
    "WARSAW_ID_P_RANK31_NAME": "Master Sergeant",
    "WARSAW_ID_P_RANK32_NAME": "Master Sergeant II",
    "WARSAW_ID_P_RANK33_NAME": "Master Sergeant III",
    "WARSAW_ID_P_RANK34_NAME": "Master Sergeant IV",
    "WARSAW_ID_P_RANK35_NAME": "Master Sergeant V",
    "WARSAW_ID_P_RANK36_NAME": "First Sergeant",
    "WARSAW_ID_P_RANK37_NAME": "First Sergeant II",
    "WARSAW_ID_P_RANK38_NAME": "First Sergeant III",
    "WARSAW_ID_P_RANK39_NAME": "First Sergeant IV",
    "WARSAW_ID_P_RANK40_NAME": "First Sergeant V",
    "WARSAW_ID_P_RANK41_NAME": "Master Gunnery Sergeant",
    "WARSAW_ID_P_RANK42_NAME": "Master Gunnery Sergeant II",
    "WARSAW_ID_P_RANK43_NAME": "Master Gunnery Sergeant III",
    "WARSAW_ID_P_RANK44_NAME": "Master Gunnery Sergeant IV",
    "WARSAW_ID_P_RANK45_NAME": "Master Gunnery Sergeant V",
    "WARSAW_ID_P_RANK46_NAME": "Sergeant Major",
    "WARSAW_ID_P_RANK47_NAME": "Sergeant Major II",
    "WARSAW_ID_P_RANK48_NAME": "Sergeant Major III",
    "WARSAW_ID_P_RANK49_NAME": "Sergeant Major IV",
    "WARSAW_ID_P_RANK50_NAME": "Sergeant Major V",
    "WARSAW_ID_P_RANK51_NAME": "Warrant Officer One",
    "WARSAW_ID_P_RANK52_NAME": "Warrant Officer One II",
    "WARSAW_ID_P_RANK53_NAME": "Warrant Officer One III",
    "WARSAW_ID_P_RANK54_NAME": "Warrant Officer One IV",
    "WARSAW_ID_P_RANK55_NAME": "Warrant Officer One V",
    "WARSAW_ID_P_RANK56_NAME": "Chief Warrant Officer Two",
    "WARSAW_ID_P_RANK57_NAME": "Chief Warrant Officer Two II",
    "WARSAW_ID_P_RANK58_NAME": "Chief Warrant Officer Two III",
    "WARSAW_ID_P_RANK59_NAME": "Chief Warrant Officer Two IV",
    "WARSAW_ID_P_RANK60_NAME": "Chief Warrant Officer Two V",
    "WARSAW_ID_P_RANK61_NAME": "Chief Warrant Officer Three",
    "WARSAW_ID_P_RANK62_NAME": "Chief Warrant Officer Three II",
    "WARSAW_ID_P_RANK63_NAME": "Chief Warrant Officer Three III",
    "WARSAW_ID_P_RANK64_NAME": "Chief Warrant Officer Three IV",
    "WARSAW_ID_P_RANK65_NAME": "Chief Warrant Officer Three V",
    "WARSAW_ID_P_RANK66_NAME": "Chief Warrant Officer Four",
    "WARSAW_ID_P_RANK67_NAME": "Chief Warrant Officer Four II",
    "WARSAW_ID_P_RANK68_NAME": "Chief Warrant Officer Four III",
    "WARSAW_ID_P_RANK69_NAME": "Chief Warrant Officer Four IV",
    "WARSAW_ID_P_RANK70_NAME": "Chief Warrant Officer Four V",
    "WARSAW_ID_P_RANK71_NAME": "Chief Warrant Officer Five",
    "WARSAW_ID_P_RANK72_NAME": "Chief Warrant Officer Five II",
    "WARSAW_ID_P_RANK73_NAME": "Chief Warrant Officer Five III",
    "WARSAW_ID_P_RANK74_NAME": "Chief Warrant Officer Five IV",
    "WARSAW_ID_P_RANK75_NAME": "Chief Warrant Officer Five V",
    "WARSAW_ID_P_RANK76_NAME": "Second Lieutenant",
    "WARSAW_ID_P_RANK77_NAME": "Second Lieutenant II",
    "WARSAW_ID_P_RANK78_NAME": "Second Lieutenant III",
    "WARSAW_ID_P_RANK79_NAME": "Second Lieutenant IV",
    "WARSAW_ID_P_RANK80_NAME": "Second Lieutenant V",
    "WARSAW_ID_P_RANK81_NAME": "First Lieutenant",
    "WARSAW_ID_P_RANK82_NAME": "First Lieutenant II",
    "WARSAW_ID_P_RANK83_NAME": "First Lieutenant III",
    "WARSAW_ID_P_RANK84_NAME": "First Lieutenant IV",
    "WARSAW_ID_P_RANK85_NAME": "First Lieutenant V",
    "WARSAW_ID_P_RANK86_NAME": "Captain",
    "WARSAW_ID_P_RANK87_NAME": "Captain II",
    "WARSAW_ID_P_RANK88_NAME": "Captain III",
    "WARSAW_ID_P_RANK89_NAME": "Captain IV",
    "WARSAW_ID_P_RANK90_NAME": "Captain V",
    "WARSAW_ID_P_RANK91_NAME": "Major",
    "WARSAW_ID_P_RANK92_NAME": "Major II",
    "WARSAW_ID_P_RANK93_NAME": "Major III",
    "WARSAW_ID_P_RANK94_NAME": "Major IV",
    "WARSAW_ID_P_RANK95_NAME": "Major V",
    "WARSAW_ID_P_RANK96_NAME": "Lieutenant Colonel",
    "WARSAW_ID_P_RANK97_NAME": "Lieutenant Colonel II",
    "WARSAW_ID_P_RANK98_NAME": "Lieutenant Colonel III",
    "WARSAW_ID_P_RANK99_NAME": "Lieutenant Colonel IV",
}
SMALLMODES = {
    "CONQUEST": "CQ",
    "RUSH": "RS",
    "RUSHLARGE": "RL",
    "SQRUSH": "SR",
    "SQDM": "SD",
    "ONSLAUGHT": "OL",
    "TEAMDEATHMATCH": "TD",
    "CONQUESTLARGE": "QL",
    "CONQUESTASSAULTLARGE": "QA",
    "CONQUESTASSAULTSMALL": "QS",
    "GUNMASTER": "GM",
    "DOMINATION": "DO",
    "TEAMDEATHMATCHC": "TD",
    "TEAMDEATHMATCH_FIRETEAM": "TD",
    "COMBATMISSION": "CM",
    "SECTORCONTROL": "SC",
    "FIRETEAM_SURVIVOR": "FS",
    "SPORT": "SP",
    "TANKSUPERIORITY": "TS",
    "OBJECTIVERAID": "OR",
    "CAPTURETHEFLAG": "CF",
    "BOMBSQUAD": "BS",
    "OBLITERATION": "OR",
    "SCAVENGER": "SV",
    "AIRSUPERIORITY": "AS",
    "ELIMINATION": "EL",
    "CARRIERASSAULT": "CA",
    "CARRIERASSAULTLARGE": "CA",
    "CARRIERASSAULTSMALL": "CS",
    "CHAINLINK": "CL",
    "BLOODMONEY": "BM",
    "HEIST": "HS",
    "HOTWIRE": "HW",
    "HIT": "HT",
    "HOSTAGE": "HS",
    "TURFWARSMALL": "TS",
    "TURFWARLARGE": "TL",
    "CONQUESTLADDER": "CL",
    "SQUADOBLITERATION": "SL",
}
WEAPONS = [
    "MK11 MOD 0",
    "SKS",
    "SVD-12",
    "QBU-88",
    "M39 EMR",
    "ACE 53 SV",
    "SCAR-H SV",
    "RFB",
    "ACW-R",
    "SG553",
    "AKU-12",
    "A-91",
    "ACE 52 CQB",
    "G36C",
    "M4",
    "ACE 21 CQB",
    "TYPE-95B-1",
    "GROZA-1",
    "AK 5C",
    "MTAR-21",
    "PHANTOM",
    "TYPE 88 LMG",
    "LSAT",
    "PKP PECHENEG",
    "QBB-95-1",
    "M240B",
    "MG4",
    "U-100 MK5",
    "L86A2",
    "M249",
    "RPK",
    "RPK-12",
    "M60-E4",
    "AWS",
    "FGM-148 JAVELIN",
    "M224 MORTAR",
    "MBT LAW",
    "REPAIR TOOL",
    "XM25 AIRBURST",
    "C4 EXPLOSIVE",
    "XM25 SMOKE",
    "UCAV",
    "DS-3 DECOY",
    "M320 SMK",
    "EOD BOT",
    "PLD",
    "MOTION SENSOR",
    "AMMO BOX",
    "M2 SLAM",
    "M320 HE",
    "RADIO BEACON",
    "M320 DART",
    "DEFIBRILLATOR",
    "MAV",
    "M18 CLAYMORE",
    "XM25 DART",
    "M320 3GL",
    "MEDIC BAG",
    "AA MINE",
    "M320 LVG",
    "M26 FRAG",
    "MP-APS",
    "M26 MASS",
    "SUAV",
    "SOFLAM",
    "AMMO PACK",
    "SA-18 IGLA",
    "M26 SLUG",
    "RPG-7V2",
    "M15 AT MINE",
    "FGM-172 SRAW",
    "T-UGS",
    "M26 DART",
    "FIM-92 STINGER",
    "FIRST AID PACK",
    "M320 FB",
    "BALLISTIC SHIELD",
    "MK153 SMAW",
    "HAND FLARE",
    "M67 FRAG",
    "V40 MINI",
    "RGO IMPACT",
    "M34 INCENDIARY",
    "M18 SMOKE",
    "M84 FLASHBANG",
    "MX4",
    "PP-2000",
    "UMP-45",
    "CBJ-MS",
    "PDW-R",
    "CZ-3A1",
    "JS2",
    "GROZA-4",
    "P90",
    "UMP-9",
    "MP7",
    "AS VAL",
    "SR-2",
    "MPX",
    "870 MCS",
    "M1014",
    "HAWK 12G",
    "SAIGA 12K",
    "SPAS-12",
    "UTS 15",
    "DBV-12",
    "QBS-09",
    "DAO-12",
    "M32 MGL",
    "M60-ULT",
    "USAS-12",
    "RAWR",
    "XD-1 Accipiter",
    "AMR-2",
    "M82A3",
    "ICICLE",
    "HVM-II",
    "RORSCH MK-1",
    "M136 CS",
    "M40A5",
    "SCOUT ELITE",
    "SV-98",
    "JNG-90",
    "338-RECON",
    "M98B",
    "SRR-61",
    "CS-LR4",
    "FY-JS",
    "L115",
    "GOL Magnum",
    "SR338",
    "CS5",
    "M9",
    "QSZ-92",
    "MP443",
    "SHORTY 12G",
    "G18",
    "FN57",
    "M1911",
    "93R",
    "CZ-75",
    ".44 MAGNUM",
    "COMPACT 45",
    "P226",
    "MARE'S LEG",
    "M412 REX",
    "DEAGLE 44",
    "UNICA 6",
    "SW40",
    "BAYONET",
    "TRENCH",
    "BOWIE",
    "SHANK",
    "BJ-2",
    "SEAL",
    "IMPROVISED",
    "CARBON FIBER",
    "C100",
    "BOOT",
    "PRECISION",
    "SURVIVAL",
    "MACHETE",
    "WEAVER",
    "SCOUT",
    "DIVE",
    "NECK",
    "ACB-90",
    "TACTICAL",
    "TANTO",
    "SCAR-H",
    "M416",
    "SAR-21",
    "AEK-971",
    "FAMAS",
    "AUG A3",
    "M16A4",
    "CZ-805",
    "AK-12",
    "AN-94",
    "ACE 23",
    "QBZ-95-1",
    "F2000",
    "L85A2",
    "AR160",
    "BULLDOG",
]