WEAPONS_STATS = {
    "c_wLMGMadsS": {"weaponName": "Madsen MG Storm"},
    "c_wHSLuger": {"weaponName": "P08 Pistol"},
    "c_wXGN": {"weaponName": "Incendiary Grenade"},
    "c_wSPKb": {"weaponName": "K Bullets"},
    "c_wSMGBergT": {"weaponName": "MP 18 Trench"},
    "c_wHSM14": {"weaponName": "Taschenpistole M1914"},
    "c_wMSpik": {"weaponName": "Spiked Club"},
    "c_wLMGLew": {"weaponName": "Lewis Gun Low Weight"},
    "c_wMJam": {"weaponName": "Jambiya Knife"},
    "c_wLMGBARS": {"weaponName": "BAR M1918 Storm"},
    "c_wMCoupe": {"weaponName": "Coupe Coupe"},
    "c_wXATM": {"weaponName": "Anti-Tank Mine"},
    "c_wRSinAriP": {"weaponName": "Type 38 Arisaka Patrol"},
    "c_wShotBA5L": {"weaponName": "12g Automatic Backbored"},
    "c_wSMGB": {"weaponName": "Automatico M1918 Factory"},
    "c_wHSMM3": {"weaponName": "No. 3 Revolver"},
    "c_wSPMaxim": {"weaponName": "MG 08/15"},
    "c_wSMGBergB": {"weaponName": "MP 18 Experimental"},
    "c_wRSemWinA": {"weaponName": "M1907 SL Sweeper"},
    "c_wMYata": {"weaponName": "Yatagan Sword"},
    "c_wLMGLewR": {"weaponName": "Lewis Gun Optical"},
    "c_wRSemCeiR": {"weaponName": "Cei-Rigotti Optical"},
    "c_wXTB": {"weaponName": "Tripwire Bomb — HE"},
    "c_wRSinMos": {"weaponName": "Mosin-Nagant M91 Infantry"},
    "c_wShotBA5C": {"weaponName": "12g Automatic Hunter"},
    "c_wMCossack": {"weaponName": "Cossack Dagger"},
    "c_wLMGBART": {"weaponName": "BAR M1918 Trench"},
    "c_wRSemLugC": {"weaponName": "Selbstlader 1906 Sniper"},
    "c_wSMGBergA": {"weaponName": "MP 18 Optical"},
    "c_wRSinVet": {"weaponName": "Vetterli-Vitali M1870/87 Infantry"},
    "c_wRSemLiuS": {"weaponName": "General Liu Rifle Storm"},
    "c_wMNav": {"weaponName": "Naval Cutlass"},
    "c_wMClub": {"weaponName": "Club"},
    "c_wHSGasser": {"weaponName": "Gasser M1870"},
    "c_wHSWeb": {"weaponName": "Auto Revolver"},
    "c_wMOFM": {"weaponName": "Ottoman Flanged Mace"},
    "c_wPCA1911": {"weaponName": "M1911 Extended"},
    "c_wMKukri": {"weaponName": "Kukri"},
    "c_wXRGF": {"weaponName": "Rifle Grenade — FRG"},
    "c_wM1916": {"weaponName": "Combat Knife"},
    "c_wSMGHell": {"weaponName": "Hellriegel 1915 Factory"},
    "c_wSMGRib": {"weaponName": "Ribeyrolles 1918 Factory"},
    "c_wShotRem": {"weaponName": "Model 10-A Factory"},
    "c_wShotWinW": {"weaponName": "M97 Trench Gun Sweeper"},
    "c_wSMGCSRA": {"weaponName": "RSC SMG Optical"},
    "c_wShotWinC": {"weaponName": "M97 Trench Gun Hunter"},
    "c_wMOCS": {"weaponName": "Ottoman Kilij"},
    "c_wRSinSprL": {"weaponName": "M1903 Sniper"},
    "c_wRSemWin": {"weaponName": "M1907 SL Factory"},
    "c_wHSBer": {"weaponName": "Modello 1915"},
    "c_wRSin1917": {"weaponName": "M1917 Enfield Infantry"},
    "c_wRSiMaL": {"weaponName": "Gewehr 98 Sniper"},
    "c_wM1917": {"weaponName": "US Trench Knife"},
    "c_wLMGMadsT": {"weaponName": "Madsen MG Trench"},
    "c_wMNail": {"weaponName": "Nail Knife"},
    "c_wLMGCh": {"weaponName": "Chauchat Low Weight"},
    "c_wRSinLeb": {"weaponName": "Lebel Model 1886 Infantry"},
    "c_wRSinVetM": {"weaponName": "Vetterli-Vitali M1870/87 Carbine"},
    "c_wRSinMosC": {"weaponName": "Mosin-Nagant M91 Marksman"},
    "c_wSMGStX": {"weaponName": "Maschinenpistole M1912/P.16 Experimental"},
    "c_wShotSjoS": {"weaponName": "Sjögren Inertial Slug"},
    "c_wRSemRSCR": {"weaponName": "RSC 1917 Optical"},
    "c_wSMGCSR": {"weaponName": "RSC SMG Factory"},
    "c_wHSC93": {"weaponName": "C93"},
    "c_wRSinStyC": {"weaponName": "Gewehr M.95 Marksman"},
    "c_wXRGS": {"weaponName": "Rifle Grenade — SMK"},
    "c_wMSho": {"weaponName": "Shovel"},
    "c_wHSBodeo": {"weaponName": "Bodeo 1889"},
    "c_wRSemLiu": {"weaponName": "General Liu Rifle Factory"},
    "c_wMSwKnf": {"weaponName": "Sawtooth Knife"},
    "c_mWPry": {"weaponName": "Prybar"},
    "c_wLMGChB": {"weaponName": "Chauchat Telescopic"},
    "c_wXGG": {"weaponName": "Gas Grenade"},
    "c_wLMGParaU": {"weaponName": "Parabellum MG14/17 Suppressive"},
    "c_wLMGHotB": {"weaponName": "M1909 Benét–Mercié Telescopic"},
    "c_wXGI": {"weaponName": "Impact Grenade"},
    "c_wHSNag": {"weaponName": "Nagant Revolver"},
    "c_wRSemCei": {"weaponName": "Cei-Rigotti Factory"},
    "c_wXD": {"weaponName": "Dynamite"},
    "c_wSMGBT": {"weaponName": "Automatico M1918 Trench"},
    "c_wSPTG": {"weaponName": "Tankgewehr M1918"},
    "c_wRSemCeiT": {"weaponName": "Cei-Rigotti Trench"},
    "c_wSMGSte": {"weaponName": "Maschinenpistole M1912/P.16 Storm"},
    "c_wShot19U": {"weaponName": "Model 1900 Slug"},
    "c_wMHun": {"weaponName": "French Butcher Knife"},
    "c_wSMGMaxA": {"weaponName": "SMG 08/18 Optical"},
    "c_wSMGBS": {"weaponName": "Automatico M1918 Storm"},
    "c_wRSemRSC": {"weaponName": "RSC 1917 Factory"},
    "c_wMRAxe": {"weaponName": "Russian Axe"},
    "c_wLMGBergU": {"weaponName": "MG15 n.A. Suppressive"},
    "c_wXRCBF": {"weaponName": "Crossbow Launcher — FRG"},
    "c_wMBill": {"weaponName": "Billhook"},
    "c_wRSemR8E": {"weaponName": "Autoloading 8 .25 Extended"},
    "c_wRSemBSA": {"weaponName": "Howell Automatic Factory"},
    "c_wShotSjo": {"weaponName": "Sjögren Inertial Factory"},
    "c_wRSemFarR": {"weaponName": "Farquhar-Hill Optical"},
    "c_wRSemFedR": {"weaponName": "Fedorov Avtomat Optical"},
    "c_wRSinMH": {"weaponName": "Martini-Henry Infantry"},
    "c_wLMGBergS": {"weaponName": "MG15 n.A. Storm"},
    "c_wSMGHellA": {"weaponName": "Hellriegel 1915 Defensive"},
    "c_wRSemMonB": {"weaponName": "Mondragón Sniper"},
    "c_wRSemMauC": {"weaponName": "Selbstlader M1916 Marksman"},
    "c_wHBObrez": {"weaponName": "Obrez Pistol"},
    "c_wSPFlame": {"weaponName": "Wex"},
    "c_wShotRemU": {"weaponName": "Model 10-A Slug"},
    "c_wSPBGAA": {"weaponName": "AA Rocket Gun"},
    "c_wRSinLeeM": {"weaponName": "SMLE MKIII Carbine"},
    "c_wRSinSty": {"weaponName": "Gewehr M.95 Infantry"},
    "c_wRSinRoS": {"weaponName": "Ross MkIII Marksman"},
    "c_wMAxe": {"weaponName": "Pickaxe"},
    "c_wMBart": {"weaponName": "Bartek Bludgeon"},
    "c_wLMGBerg": {"weaponName": "MG15 n.A. Low Weight"},
    "c_wLMGPara": {"weaponName": "Parabellum MG14/17 Low Weight"},
    "c_wRSinTyp": {"weaponName": "Type 38 Arisaka Infantry"},
    "c_wMBott": {"weaponName": "Broken Bottle"},
    "c_wMBarb": {"weaponName": "Barbed Wire Bat"},
    "c_wSPRepair": {"weaponName": "Repair Tool"},
    "c_wMStClub": {"weaponName": "Raider Club"},
    "c_wMTrKnf": {"weaponName": "Trench Knife"},
    "c_wHSColtH": {"weaponName": "Hellfighter M1911"},
    "c_wHSMauser": {"weaponName": "C96"},
    "c_wSPFlare": {"weaponName": "Flare Gun — Spot"},
    "c_wLMGPer": {"weaponName": "Perino Model 1908 Low Weight"},
    "c_wLMGHotR": {"weaponName": "M1909 Benét–Mercié Optical"},
    "c_wSPDefib": {"weaponName": "Medical Syringe"},
    "c_wRSemFarS": {"weaponName": "Farquhar-Hill Storm"},
    "c_wShotWinP": {"weaponName": "Hellfighter Trench Shotgun"},
    "c_wLMG0818S": {"weaponName": "lMG 08/18 Suppressive"},
    "c_wRSemMauR": {"weaponName": "Selbstlader M1916 Optical"},
    "c_wMClvr": {"weaponName": "Meat Cleaver"},
    "c_wPCSP08": {"weaponName": "P08 Artillerie"},
    "c_wRSinMHL": {"weaponName": "Martini-Henry Sniper"},
    "c_wMScout": {"weaponName": "Survival Knife"},
    "c_wXRGHE": {"weaponName": "Rifle Grenade — HE"},
    "c_wShotWinL": {"weaponName": "M97 Trench Gun Backbored"},
    "c_wHSKoli": {"weaponName": "Kolibri"},
    "c_wXGM": {"weaponName": "Improvised Grenade"},
    "c_wLMGBroU": {"weaponName": "M1917 MG Telescopic"},
    "c_wRSinRoI": {"weaponName": "Ross MkIII Infantry"},
    "c_wXTG": {"weaponName": "Tripwire Bomb — GAS"},
    "c_wPCAFrom": {"weaponName": "Frommer Stop Auto"},
    "c_wXGF": {"weaponName": "Frag Grenade"},
    "c_wRSemFedT": {"weaponName": "Fedorov Avtomat Trench"},
    "c_wRSinWinL": {"weaponName": "Russian 1895 Sniper"},
    "c_wHSFS": {"weaponName": "Frommer Stop"},
    "c_wRSemBSAC": {"weaponName": "Howell Automatic Sniper"},
    "c_wLMGHuot": {"weaponName": "Huot Automatic Low Weight"},
    "c_wMHook": {"weaponName": "Grappling Hook"},
    "c_wRSinCarP": {"weaponName": "Carcano M91 Patrol Carbine"},
    "c_wRSemR8": {"weaponName": "Autoloading 8 .35 Factory"},
    "c_wHSM1912": {"weaponName": "Repetierpistole M1912"},
    "c_wLMGBARB": {"weaponName": "BAR M1918 Telescopic"},
    "c_wLMGMads": {"weaponName": "Madsen MG Low Weight"},
    "c_wRSinEnfS": {"weaponName": "M1917 Enfield Silenced"},
    "c_wMAmKn": {"weaponName": "Compact Trench Knife"},
    "c_wMBottUn": {"weaponName": "Wine Bottle"},
    "c_wSMGThomT": {"weaponName": "Annihilator Trench"},
    "c_wSPVP": {"weaponName": "Villar Perosa"},
    "c_wHSFN1903": {"weaponName": "Mle 1903"},
    "c_wXLM": {"weaponName": "Limpet Charge"},
    "c_wLMGHuotR": {"weaponName": "Huot Automatic Optical"},
    "c_wXGS": {"weaponName": "Smoke Grenade"},
    "c_wSMGMax": {"weaponName": "SMG 08/18 Factory"},
    "c_wMSick": {"weaponName": "Sickle"},
    "c_wXCBHE": {"weaponName": "Crossbow Launcher — HE"},
    "c_wRSinLeeP": {"weaponName": "Lawrence of Arabia's SMLE"},
    "c_wXATG": {"weaponName": "Anti-Tank Grenade"},
    "c_wShotSO": {"weaponName": "Sawed Off Shotgun"},
    "c_wRSinLebL": {"weaponName": "Lebel Model 1886 Sniper"},
    "c_wLMGHotS": {"weaponName": "M1909 Benét–Mercié Storm"},
    "c_wShotRemC": {"weaponName": "Model 10-A Hunter"},
    "c_wMBolo": {"weaponName": "Hellfighter Bolo Knife"},
    "c_wRSinLeeC": {"weaponName": "SMLE MKIII Marksman"},
    "c_wRSiMa": {"weaponName": "Gewehr 98 Infantry"},
    "c_wXGAT": {"weaponName": "Light Anti-Tank Grenade"},
    "c_wMMac": {"weaponName": "Trench Mace"},
    "c_wHSHL": {"weaponName": "1903 Hammerless"},
    "c_wPCSFN": {"weaponName": "Mle 1903 Extended"},
    "c_wPCSC93": {"weaponName": "C93 Carbine"},
    "c_wRIRLebel": {"weaponName": "Lebel Model 1886"},
    "c_wMSbr": {"weaponName": "Saber"},
    "c_wRSemMau": {"weaponName": "Selbstlader M1916 Factory"},
    "c_wShot19": {"weaponName": "Model 1900 Factory"},
    "c_wMRus": {"weaponName": "Russian Award Knife"},
    "c_wSPFlShot": {"weaponName": "Flare Gun — Flash"},
    "c_wRIR98": {"weaponName": "Gewehr 98"},
    "c_wSPMHGL": {"weaponName": "Martini-Henry Grenade Launcher"},
    "c_wXGO": {"weaponName": "Mini Grenade"},
    "c_wHSWMVI": {"weaponName": "Revolver Mk VI"},
    "c_wLMGLewU": {"weaponName": "Lewis Gun Suppressive"},
    "c_wSPBG": {"weaponName": "AT Rocket Gun"},
    "c_wRSinSprT": {"weaponName": "M1903 Experimental"},
    "c_wLMG0818": {"weaponName": "lMG 08/18 Low Weight"},
    "c_wHSMars": {"weaponName": "Mars Automatic"},
    "c_wSMGMau": {"weaponName": "M1917 Trench Carbine"},
    "c_wHSColt": {"weaponName": "M1911"},
    "c_wHSColtT": {"weaponName": "Lebel Model 1886"},
    "c_wLMGBro": {"weaponName": "M1917 MG Low Weight"},
    "c_wMGren": {"weaponName": "Dud Club"},
    "c_wPCSC96": {"weaponName": "C96 Carbine"},
    "c_wRSemLug": {"weaponName": "Selbstlader 1906 Factory"},
    "c_wSMGRibO": {"weaponName": "Ribeyrolles 1918 Optical"},
    "c_wRSemWinT": {"weaponName": "M1907 SL Trench"},
    "c_wSMGMauP": {"weaponName": "M1917 Patrol Carbine"},
    "c_wRSinSprS": {"weaponName": "M1903 Marksman"},
    "c_wMHat": {"weaponName": "Hatchet"},
    "c_wMFleur": {"weaponName": "Trench Fleur"},
    "c_wShotBA5E": {"weaponName": "12g Automatic Extended"},
    "c_wRSinCarT": {"weaponName": "Carcano M91 Carbine"},
    "c_wRSinStyM": {"weaponName": "Gewehr M.95 Carbine"},
    "c_wHSLugRB": {"weaponName": "Red Baron's P08"},
    "c_wMTot": {"weaponName": "Totokia"},
    "c_wXTI": {"weaponName": "Tripwire Bomb — INC"},
    "c_wLMGPerD": {"weaponName": "Perino Model 1908 Defensive"},
    "c_wHSLHow": {"weaponName": "Howdah Pistol"},
    "c_wHB": {"weaponName": "Obrez Pistol"},
    "c_wRSemMonR": {"weaponName": "Mondragón Optical"},
    "c_wRSinLee": {"weaponName": "SMLE MKIII Infantry"},
    "c_wHSBull": {"weaponName": "Bull Dog Revolver"},
    "c_wMCavS": {"weaponName": "Cavalry Sword"},
    "c_wRSemMonS": {"weaponName": "Mondragón Storm"},
    "c_wRSiMaC": {"weaponName": "Gewehr 98 Marksman"},
    "c_wMBeDag": {"weaponName": "Bedouin Dagger"},
    "c_wPCSPiep": {"weaponName": "Pieper M1893"},
    "c_wMCogClub": {"weaponName": "Cogwheel Club"},
    "c_wRSinWin": {"weaponName": "Russian 1895 Infantry"},
    "c_wRSemR8S": {"weaponName": "Autoloading 8 .35 Marksman"},
    "c_wRSinWinT": {"weaponName": "Russian 1895 Trench"},
    "c_wMWelsh": {"weaponName": "Welsh Blade"},
}
CLASSES_SCORE = {
    "c_md_": "sc_medic",
    "c_sp_": "sc_support",
    "c_as_": "sc_assault",
    "c_sc_": "sc_scout",
    "c_pt_": "sc_pilot",
    "c_tk_": "sc_tanker",
    "c_cv_": "sc_cavalry",
}
GAMEMODE_SCORE = {
    "mgc_roo_g": "sc_conquest",
    "mgtd_roo_g": "sc_deathmatch",
    "mgb_roo_g": "sc_operations",
    "mgr_roo_g": "sc_rush",
    "Poss_roo_g": "sc_possession",
    "mgdo_roo_g": "sc_domination",
    "_roo_g": "sc_general",
}
SMALLMODES = {
    "Conquest": "CQ",
    "Domination": "DM",
    "TugOfWar": "FL",
    "Rush": "RS",
    "BreakthroughLarge": "OP",
    "Breakthrough": "SO",
    "Possession": "WP",
    "TeamDeathMatch": "TM",
    "ZoneControl": "SD",
    "AirAssault": "AA",
}
STATS_CLASSES = {
    "c_md_": {"className": "Medic"},
    "c_sp_": {"className": "Support"},
    "c_as_": {"className": "Assault"},
    "c_sc_": {"className": "Scout"},
    "c_pt_": {"className": "Pilot"},
    "c_tk_": {"className": "Tanker"},
    "c_cv_": {"className": "Cavalry"},
}
STATS_GAMEMODE = {
    "mgc_roo_g": {"gamemodeName": "Conquest"},
    "mgtd_roo_g": {"gamemodeName": "Team deathmatch"},
    "mgb_roo_g": {"gamemodeName": "Operations"},
    "mgr_roo_g": {"gamemodeName": "Rush"},
    "Poss_roo_g": {"gamemodeName": "War pigeons"},
    "mgdo_roo_g": {"gamemodeName": "Domination"},
    "_roo_g": {"gamemodeName": "Total"},
}
WEAPONS = [
    "Wex",
    "MG 08/15",
    "Tankgewehr M1918",
    "Villar Perosa",
    "Martini-Henry Grenade Launcher",
    "Madsen MG Trench",
    "M1909 Benét–Mercié Storm",
    "Huot Automatic Low Weight",
    "Lewis Gun Low Weight",
    "M1909 Benét–Mercié Telescopic",
    "BAR M1918 Telescopic",
    "BAR M1918 Storm",
    "Lewis Gun Suppressive",
    "Madsen MG Storm",
    "Madsen MG Low Weight",
    "BAR M1918 Trench",
    "Lewis Gun Optical",
    "MG15 n.A. Suppressive",
    "MG15 n.A. Storm",
    "M1909 Benét–Mercié Optical",
    "MG15 n.A. Low Weight",
    "Chauchat Telescopic",
    "Chauchat Low Weight",
    "Huot Automatic Optical",
    "Perino Model 1908 Defensive",
    "Perino Model 1908 Low Weight",
    "Parabellum MG14/17 Low Weight",
    "Parabellum MG14/17 Suppressive",
    "M1917 MG Low Weight",
    "M1917 MG Telescopic",
    "lMG 08/18 Low Weight",
    "lMG 08/18 Suppressive",
    "Shovel",
    "Trench Mace",
    "Sawtooth Knife",
    "Club",
    "Compact Trench Knife",
    "Trench Knife",
    "Hellfighter Bolo Knife",
    "US Trench Knife",
    "Bedouin Dagger",
    "Spiked Club",
    "Bayonet Charge",
    "Hatchet",
    "Bartek Bludgeon",
    "Cavalry Sword",
    "Combat Knife",
    "Survival Knife",
    "Pickaxe",
    "Nail Knife",
    "Saber",
    "Trench Fleur",
    "Raider Club",
    "Billhook",
    "Cogwheel Club",
    "Kukri",
    "Arditi Dagger",
    "Cavalry Lance",
    "Cossack Dagger",
    "Dud Club",
    "Totokia",
    "French Butcher Knife",
    "Russian Award Knife",
    "Coupe Coupe",
    "Russian Axe",
    "Naval Cutlass",
    "Grappling Hook",
    "Ottoman Flanged Mace",
    "Barbed Wire Bat",
    "Ottoman Kilij",
    "Yatagan Sword",
    "Meat Cleaver",
    "Prybar",
    "Wine Bottle",
    "Sickle",
    "Welsh Blade",
    "M1903 Marksman",
    "Russian 1895 Sniper",
    "Lawrence of Arabia's SMLE",
    "Gewehr 98 Marksman",
    "Gewehr M.95 Infantry",
    "SMLE MKIII Marksman",
    "Martini-Henry Infantry",
    "SMLE MKIII Infantry",
    "Gewehr 98 Infantry",
    "Gewehr M.95 Carbine",
    "Gewehr M.95 Marksman",
    "Russian 1895 Trench",
    "Russian 1895 Infantry",
    "M1903 Sniper",
    "M1903 Experimental",
    "SMLE MKIII Carbine",
    "Gewehr 98 Sniper",
    "Lebel Model 1886 Infantry",
    "Lebel Model 1886",
    "Lebel Model 1886 Sniper",
    "Martini-Henry Sniper",
    "Vetterli-Vitali M1870/87 Carbine",
    "Vetterli-Vitali M1870/87 Infantry",
    "Mosin-Nagant M91 Marksman",
    "Mosin-Nagant M91 Infantry",
    "Carcano M91 Carbine",
    "Type 38 Arisaka Infantry",
    "Ross MkIII Marksman",
    "M1917 Enfield Infantry",
    "Ross MkIII Infantry",
    "M1917 Enfield Silenced",
    "Mortar — HE",
    "Bandage Pouch",
    "Crossbow Launcher — HE",
    "Trench Periscope",
    "Tripwire Bomb — GAS",
    "K Bullets",
    "Bandage Pouch",
    "Anti-Tank Grenade",
    "Flare Gun — Flash",
    "Anti-Tank Mine",
    "Medical Syringe",
    "Tripwire Bomb — HE",
    "Tripwire Bomb — INC",
    "Flare Gun — Spot",
    "Crossbow Launcher — FRG",
    "Ammo Pouch",
    "Sniper Decoy",
    "Medical Crate",
    "Trench Periscope",
    "Sniper Shield",
    "Ammo Pouch",
    "Ammo Crate",
    "AT Rocket Gun",
    "Mortar — AIR",
    "Dynamite",
    "Limpet Charge",
    "Repair Tool",
    "AA Rocket Gun",
    "Livens Projector",
    "Mondragón Storm",
    "Mondragón Optical",
    "Cei-Rigotti Factory",
    "M1907 SL Sweeper",
    "Autoloading 8 .25 Extended",
    "Selbstlader 1906 Factory",
    "M1907 SL Trench",
    "Selbstlader M1916 Factory",
    "Selbstlader M1916 Optical",
    "Mondragón Sniper",
    "Cei-Rigotti Optical",
    "Cei-Rigotti Trench",
    "Selbstlader M1916 Marksman",
    "M1907 SL Factory",
    "Autoloading 8 .35 Factory",
    "Autoloading 8 .35 Marksman",
    "RSC 1917 Factory",
    "RSC 1917 Optical",
    "Selbstlader 1906 Sniper",
    "General Liu Rifle Storm",
    "General Liu Rifle Factory",
    "Fedorov Avtomat Trench",
    "Fedorov Avtomat Optical",
    "Farquhar-Hill Optical",
    "Farquhar-Hill Storm",
    "Howell Automatic Factory",
    "Howell Automatic Sniper",
    "M1917 Patrol Carbine",
    "Carcano M91 Patrol Carbine",
    "Incendiary Grenade",
    "Rifle Grenade — FRG",
    "Impact Grenade",
    "Frag Grenade",
    "Rifle Grenade — SMK",
    "Mini Grenade",
    "Smoke Grenade",
    "Gas Grenade",
    "Light Anti-Tank Grenade",
    "Rifle Grenade — HE",
    "Russian Standard Grenade",
    "Improvised Grenade",
    "Gewehr M.95",
    "M1903",
    "Gewehr 98",
    "SMLE MKIII",
    "Russian 1895",
    "Mosin-Nagant M91",
    "Hellfighter Trench Shotgun",
    "12g Automatic Hunter",
    "Model 10-A Factory",
    "Model 10-A Hunter",
    "12g Automatic Backbored",
    "M97 Trench Gun Hunter",
    "M97 Trench Gun Backbored",
    "Model 10-A Slug",
    "12g Automatic Extended",
    "M97 Trench Gun Sweeper",
    "Sjögren Inertial Factory",
    "Model 1900 Factory",
    "Model 1900 Slug",
    "Sjögren Inertial Slug",
    "Sawed Off Shotgun",
    "Pieper M1893",
    "C96 Carbine",
    "Frommer Stop Auto",
    "P08 Artillerie",
    "M1911 Extended",
    "Mle 1903 Extended",
    "C93 Carbine",
    "MP 18 Trench",
    "MP 18 Experimental",
    "Automatico M1918 Factory",
    "MP 18 Optical",
    "Automatico M1918 Storm",
    "Automatico M1918 Trench",
    "Hellriegel 1915 Factory",
    "Ribeyrolles 1918 Factory",
    "Hellriegel 1915 Defensive",
    "SMG 08/18 Optical",
    "SMG 08/18 Factory",
    "M1917 Trench Carbine",
    "Maschinenpistole M1912/P.16 Storm",
    "RSC SMG Factory",
    "RSC SMG Optical",
    "Annihilator Trench",
    "Maschinenpistole M1912/P.16 Experimental",
    "Ribeyrolles 1918 Optical",
    "Mars Automatic",
    "Auto Revolver",
    "C96",
    "C93",
    "Bodeo 1889",
    "Bull Dog Revolver",
    "Repetierpistole M1912",
    "1903 Hammerless",
    "Hellfighter M1911",
    "Modello 1915",
    "Gasser M1870",
    "Frommer Stop",
    "No. 3 Revolver",
    "Howdah Pistol",
    "M1911",
    "Kolibri",
    "Mle 1903",
    "P08 Pistol",
    "Taschenpistole M1914",
    "Obrez Pistol",
    "Nagant Revolver",
    "Revolver Mk VI",
    "Type 38 Arisaka Patrol",
]
FACTIONS = {
    "BFFactionId_FactionAHU": {
        "image": "https://cdn.gametools.network/factions/bf1/colored/BFFactionId_FactionAHU.png",
        "key": "AHU",
        "name": "Austro-Hungarian Empire",
    },
    "BFFactionId_FactionGER": {
        "image": "https://cdn.gametools.network/factions/bf1/colored/BFFactionId_FactionGER.png",
        "key": "GER",
        "name": "German Empire",
    },
    "BFFactionId_FactionOTM": {
        "image": "https://cdn.gametools.network/factions/bf1/colored/BFFactionId_FactionOTM.png",
        "key": "OTM",
        "name": "Ottoman Empire",
    },
    "BFFactionId_FactionITA": {
        "image": "https://cdn.gametools.network/factions/bf1/colored/BFFactionId_FactionITA.png",
        "key": "ITA",
        "name": "Kingdom of Italy",
    },
    "BFFactionId_FactionUK": {
        "image": "https://cdn.gametools.network/factions/bf1/colored/BFFactionId_FactionUK.png",
        "key": "UK",
        "name": "United Kingdom",
    },
    "BFFactionId_FactionUSA": {
        "image": "https://cdn.gametools.network/factions/bf1/colored/BFFactionId_FactionUSA.png",
        "key": "USA",
        "name": "United States of America",
    },
    "BFFactionId_FactionFRA": {
        "image": "https://cdn.gametools.network/factions/bf1/colored/BFFactionId_FactionFRA.png",
        "key": "FRA",
        "name": "France",
    },
    "BFFactionId_FactionRUS": {
        "image": "https://cdn.gametools.network/factions/bf1/colored/BFFactionId_FactionRUS.png",
        "key": "RUS",
        "name": "Russian Empire",
    },
    "BFFactionId_FactionBOL": {
        "image": "https://cdn.gametools.network/factions/bf1/colored/BFFactionId_FactionBOL.png",
        "key": "BOL",
        "name": "Red Army",
    },
    "BFFactionId_FactionWA": {
        "image": "https://cdn.gametools.network/factions/bf1/colored/BFFactionId_FactionWA.png",
        "key": "WA",
        "name": "White Army",
    },
    "BFFactionId_FactionUKM": {
        "image": "https://cdn.gametools.network/factions/bf1/colored/BFFactionId_FactionUKM.png",
        "key": "UK",
        "name": "Royal Marines",
    },
}
MAP_FACTIONS = {
    "MP_Tsaritsyn": ["BFFactionId_FactionBOL", "BFFactionId_FactionRUS"],
    "MP_Amiens": ["BFFactionId_FactionGER", "BFFactionId_FactionUK"],
    "MP_Desert": ["BFFactionId_FactionUK", "BFFactionId_FactionOTM"],
    "MP_Forest": ["BFFactionId_FactionGER", "BFFactionId_FactionUSA"],
    "MP_Chateau": ["BFFactionId_FactionUSA", "BFFactionId_FactionGER"],
    "MP_MountainFort": ["BFFactionId_FactionITA", "BFFactionId_FactionAHU"],
    "MP_ShovelTown": ["BFFactionId_FactionGER", "BFFactionId_FactionFRA"],
    "MP_Giant": ["BFFactionId_FactionGER", "BFFactionId_FactionUK"],
    "MP_Suez": ["BFFactionId_FactionUK", "BFFactionId_FactionOTM"],
    "MP_Trench": ["BFFactionId_FactionGER", "BFFactionId_FactionFRA"],
    "MP_Underworld": ["BFFactionId_FactionGER", "BFFactionId_FactionFRA"],
    "MP_ItalianCoast": ["BFFactionId_FactionITA", "BFFactionId_FactionAHU"],
    "MP_Graveyard": ["BFFactionId_FactionFRA", "BFFactionId_FactionGER"],
    "MP_Scar": ["BFFactionId_FactionUK", "BFFactionId_FactionGER"],
    "MP_FaoFortress": ["BFFactionId_FactionUK", "BFFactionId_FactionOTM"],
    "MP_Islands": ["BFFactionId_FactionGER", "BFFactionId_FactionRUS"],
    "MP_Valley": ["BFFactionId_FactionWA", "BFFactionId_FactionAHU"],
    "MP_Verdun": ["BFFactionId_FactionGER", "BFFactionId_FactionFRA"],
    "MP_Hell": ["BFFactionId_FactionUK", "BFFactionId_FactionGER"],
    "MP_Bridge": ["BFFactionId_FactionWA", "BFFactionId_FactionAHU"],
    "MP_Ravines": ["BFFactionId_FactionAHU", "BFFactionId_FactionRUS"],
    "MP_Volga": ["BFFactionId_FactionBOL", "BFFactionId_FactionWA"],
    "MP_Ridge": ["BFFactionId_FactionUK", "BFFactionId_FactionOTM"],
    "MP_Fields": ["BFFactionId_FactionFRA", "BFFactionId_FactionGER"],
    "MP_Alps": ["BFFactionId_FactionGER", "BFFactionId_FactionUK"],
    "MP_River": ["BFFactionId_FactionAHU", "BFFactionId_FactionITA"],
    "MP_Offensive": ["BFFactionId_FactionUK", "BFFactionId_FactionGER"],
    "MP_Naval": ["BFFactionId_FactionUKM", "BFFactionId_FactionGER"],
    "MP_Harbor": ["BFFactionId_FactionUKM", "BFFactionId_FactionGER"],
    "MP_Beachhead": ["BFFactionId_FactionUK", "BFFactionId_FactionOTM"],
    "MP_Blitz": ["BFFactionId_FactionGER", "BFFactionId_FactionUK"],
    "MP_London": ["BFFactionId_FactionGER", "BFFactionId_FactionUK"],
}
INTERNAL_MAP_NAME = {
    "sinai desert": "MP_Desert",
    "ballroom blitz": "MP_Chateau",
    "empire's edge": "MP_ItalianCoast",
    "st quentin scar": "MP_Scar",
    "prise de tahure": "MP_Shoveltown",
    "monte grappa": "MP_MountainFort",
    "fao fortress": "MP_FaoFortress",
    "giant's shadow": "MP_Giant",
    "rupture": "MP_Graveyard",
    "amiens": "MP_Amiens",
    "suez": "MP_Suez",
    "fort de vaux": "MP_Underworld",
    "nivelle nights": "MP_Trench",
    "soissons": "MP_Fields",
    "verdun heights": "MP_Verdun",
    "albion": "MP_Islands",
    "tsaritsyn": "MP_Tsaritsyn",
    "łupków pass": "MP_Ravines",
    "achi baba": "MP_Ridge",
    "heligoland bight": "MP_Naval",
    "caporetto": "MP_River",
    "river somme": "MP_Offensive",
    "passchendaele": "MP_Hell",
    "galicia": "MP_Valley",
    "volga river": "MP_Volga",
    "brusilov keep": "MP_Bridge",
    "cape helles": "MP_Beachhead",
    "zeebrugge": "MP_Harbor",
    "argonne forest": "MP_Forest",
    "razor's edge": "MP_Alps",
    "london calling": "MP_Blitz",
    "london calling: Scourge": "MP_London",
}
